stage2fudge = {flex1 -> 2*c1^(3/2)*Sqrt[(M11*Y1)/(g*(m1 + m2 + m3))], 
     flex2 -> 2*c2^(3/2)*Sqrt[(M21*Y2)/(g*(m2 + m3))], 
     flex3 -> 2*c3^(3/2)*Sqrt[(M31*Y3)/(g*m3)], d0 -> d0 + flex1, 
     d1 -> d1 + flex2, d2 -> d2 + flex2, d3 -> d3 + flex3, d4 -> d4 + flex3, 
     l1 -> (-2*flex1)/c1 + l1, l2 -> (-2*flex2)/c2 + l2, 
     l3 -> (-2*flex3)/c3 + l3, n0 -> n0 + (flex1*si1)/c1, 
     n1 -> n1 - (flex1*si1)/c1, n2 -> n2 + (flex2*si2)/c2, 
     n3 -> n3 - (flex2*si2)/c2, n4 -> n4 + (flex3*si3)/c3, 
     n5 -> n5 - (flex3*si3)/c3}
 
g /: g::usage = "g is local gravity."
 
M11 /: M11::usage = "M11 is the moment of area of wires from blades on \
structure to top mass in direction \"1\"."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
Y1 /: Y1::usage = 
     "Y1 is Young's modulus of wires from blades on structure to top mass."
 
M21 /: M21::usage = "M21 is the moment of area of wires from blades on top \
mass to intermediate mass in direction \"1\""
 
Y2 /: Y2::usage = "Y2 is Young's modulus of wires from blades on top mass to \
intermediate mass."
 
M31 /: M31::usage = "M31 is the moment of area of wires (fibres) from \
intermediate mass to optic in direction \"1\""
 
Y3 /: Y3::usage = 
     "Y3 is Young's modulus of wires (fibres) from intermediate mass to \
optic."
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {Inxy -> 0, Inyz -> 0, Inzx -> 0, Inxz -> 0, Inzy -> 0, 
     Inyx -> 0, I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
qm = {{kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1), 0, 0, 0, 0, 
      0}, {0, kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1), 0, 0, 
      0, 0}, {0, 0, kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      0, 0, 0}, {0, 0, 0, kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - 
       (c2*g*m23)/(4*l2), 0, 0}, {0, 0, 0, 0, kblz + c2^2*kw2 + 
       (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 0}, 
     {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)}}
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)/(2*c1*l1), 0, 0, 
      -(2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)/(2*c1*l1), 0, 0, 
      (2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)/(2*c1*l1)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
kmlp = {{I1y, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0}, {0, 0, I2y, 0, 0, 0}, 
     {0, 0, 0, m2, 0, 0}, {0, 0, 0, 0, I3y, 0}, {0, 0, 0, 0, 0, m3}}
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
xmlp = {{(g*(2*d0^2 + 2*c1*d0*l1)*m13)/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 
      (d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2), -4*c2^2*kw2*si^2 + 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      (d1*g*m23)/(c2*l2), 0, 0}, {(d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2), 
      (g*m13)/(c1*l1) + (g*m23)/(c2*l2), -((d2*g*m23)/(c2*l2)), 
      -((g*m23)/(c2*l2)), 0, 0}, {-4*c2^2*kw2*si^2 + (c2*g*m23*si^2)/l2 + 
       (g*m23*(2*d1*d2 - 2*si^2))/(2*c2*l2), -((d2*g*m23)/(c2*l2)), 
      4*c2^2*kw2*si^2 - (c2*g*m23*si^2)/l2 + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 
      (d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3), -4*c3^2*kw3*sl^2 + 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/(2*c3*l3), 
      (d3*g*m3)/(c3*l3)}, {(d1*g*m23)/(c2*l2), -((g*m23)/(c2*l2)), 
      (d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3), (g*m23)/(c2*l2) + 
       (g*m3)/(c3*l3), -((d4*g*m3)/(c3*l3)), -((g*m3)/(c3*l3))}, 
     {0, 0, -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), -((d4*g*m3)/(c3*l3)), 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 
      (d4*g*m3)/(c3*l3)}, {0, 0, (d3*g*m3)/(c3*l3), -((g*m3)/(c3*l3)), 
      (d4*g*m3)/(c3*l3), (g*m3)/(c3*l3)}}
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {-(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 0, 0}, 
     {c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 0, 0}, 
     {-(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 0, 0}, 
     {c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 0, 0}}
 
amlp = {{(c1*d1^2*g^2*l1*m23^2 + c2^2*g*(4*d0^2*kblz*l2^2*m13 + 
          4*c1*d0*kblz*l1*l2^2*m13 + c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 
        4*c2^4*kw2*l2^2*(d0^2*g*m13 + c1*d0*g*l1*m13 + 
          c1*l1*(d1*g*m23 + 4*kblz*si^2)) + c2*g*l2*m23*
         (d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + d1*g*m23 + 
            4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
          c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2)))/
       (c1*c2*I1y*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      ((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2))/m1, 
      (d1*d2*g^2*m23^2 - c2^2*d1*d2*g^2*m23^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*m23*(d1*d2 - si^2) + 4*c2^3*g*l2*m23*
         (d1*d2*kw2 + kblz*si^2))/(c2*I2y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*m23 - c2^2*g*m23)), (d1*g*m23)/(c2*l2*m2), 0, 0}, 
     {((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2))/I1y, 
      ((g*m13)/(c1*l1) + (g*m23)/(c2*l2))/m1, -((d2*g*m23)/(c2*I2y*l2)), 
      -((g*m23)/(c2*l2*m2)), 0, 0}, 
     {(d1*d2*g^2*m23^2 - c2^2*d1*d2*g^2*m23^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*m23*(d1*d2 - si^2) + 4*c2^3*g*l2*m23*
         (d1*d2*kw2 + kblz*si^2))/(c2*I1y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*m23 - c2^2*g*m23)), -((d2*g*m23)/(c2*l2*m1)), 
      (8*c2^2*kw2*si^2 - (2*c2*g*m23*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (2*g*m23*(d2^2 + c2*d2*l2 + si^2))/(c2*l2) + 8*c3^2*kw3*sl^2 - 
        (2*c3*g*m3*sl^2)/l3 + (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/
       (2*I2y), ((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3))/m2, 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I3y*l3), 
      (d3*g)/(c3*l3)}, {(d1*g*m23)/(c2*I1y*l2), -((g*m23)/(c2*l2*m1)), 
      ((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3))/I2y, 
      ((g*m23)/(c2*l2) + (g*m3)/(c3*l3))/m2, -((d4*g*m3)/(c3*I3y*l3)), 
      -(g/(c3*l3))}, {0, 0, (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*
         sl^2)/(c3*I2y*l3), -((d4*g*m3)/(c3*l3*m2)), 
      (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/
       (c3*I3y*l3), (d4*g)/(c3*l3)}, {0, 0, (d3*g*m3)/(c3*I2y*l3), 
      -((g*m3)/(c3*l3*m2)), (d4*g*m3)/(c3*I3y*l3), g/(c3*l3)}}
 
cxsmlp = {{-((d0*g*m13)/(c1*l1)), 0, 0, 0, 0, 0}, {-((g*m13)/(c1*l1)), 0, 0, 
      0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmlp = {{-((d0*g*m13)/(c1*I1y*l1)), 0, 0, 0, 0, 0}, 
     {-((g*m13)/(c1*l1*m1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmtr = {{I1x, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0}, {0, 0, I2x, 0, 0, 0}, 
     {0, 0, 0, m2, 0, 0}, {0, 0, 0, 0, I3x, 0}, {0, 0, 0, 0, 0, m3}}
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmtr = {{(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
         (-(g*m23*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*m23*
         (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
             (n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + 
            g*m13*(l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*m13*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*m13*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*m23*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*
         (n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
              l1^2*m23*n2*(-n2 + n3)))))/(c1*c2*l1^3*l2^3), 
      (d1*(d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3) + 
        l2*n2*(-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3)))/(c2*l2^3), 
      (d1*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*n2*(n2 - n3))/(c2*l2^3), 0, 0}, 
     {(c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*
         (n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
              l1^2*m23*n2*(-n2 + n3)))))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(g*l2^2*m13*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*m23*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3)/(c2*l2^3), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3), 0, 
      0}, {(d1*(d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3) + 
        l2*n2*(-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3)))/(c2*l2^3), 
      (d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3)/(c2*l2^3), 
      (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
         (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
         (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
             (n2 - n3)^2) + c2*d2*l2*l3^2*(8*c2*kw2*l2*n3*(-n2 + n3) + 
            g*m23*(l2^2 + 2*(n2 - n3)*n3)) + l2^2*(g*l3^2*m23*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*m23*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3)}, 
     {(d1*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*n2*(n2 - n3))/(c2*l2^3), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (c3*l3*(g*l3^2*m23*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3)}, 
     {0, 0, (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3)}, {0, 0, (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3), (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3)}}
 
cqxmtr = {{(c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
        c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))/(2*c1*l1^2), 
      ((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 0, 0, 0, 0}, 
     {(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
        c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))/(2*c1*l1^2), 
      -((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 0, 0, 0, 0}, 
     {(-4*c2^3*kw2*l2^2*n2 + c2*d1*g*m23*(n2 - n3) - g*l2*m23*n3 + 
        c2^2*l2*(g*m23*n2 + 4*d1*kw2*(-n2 + n3)))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*m23*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(-4*c2^3*kw2*l2^2*n2 + c2*d1*g*m23*(n2 - n3) - g*l2*m23*n3 + 
        c2^2*l2*(g*m23*n2 + 4*d1*kw2*(-n2 + n3)))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*m23*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
        g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
        g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}}
 
amtr = {{((-8*(c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2)/
         (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) - 
        (8*(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2)/
         (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
            (-(g*m23*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*m23*
            (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
           c2*l2*(d0^2*l2^2*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
                (n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + g*
                m13*(l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*m13*n0*n1 + 2*
                c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*m13*n1^2 + c1*d1*l1*
                (4*d1*kw2*(n2 - n3)^2 + g*m23*(l2^2 + 2*n2*(-n2 + n3)))))))/
         (c1*c2*l1^3*l2^3))/(8*I1x), 
      ((-8*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
           2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
           c1^2*g*m13)) - (8*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*
          (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
           g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3)))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*(c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*
            n2*(n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
                 l1^2*m23*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3))/(8*m1), 
      -((16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3))))/(c2*I2x*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      (-4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
        d1*g^2*m23^2*(-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*m23*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*m23*(n2 - n3)*
           (kblz*n2 + kw2*(-n2 + n3))))/(c2*l2^3*m2*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 0}, 
     {((-8*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
           2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
           c1^2*g*m13)) - (8*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*
          (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
           g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3)))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*(c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*
            n2*(n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
                 l1^2*m23*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3))/(8*I1x), 
      (-((c1*(-2*c1*kw1*l1 + g*m13)^2*(n0 - n1)^2)/
          (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13))) + 
        (c2*l2*(g*l2^2*m13*(l1^2 - (n0 - n1)^2) + 2*c1*l1*
             (kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
          c1*g*l1^3*m23*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)))/m1, 
      (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*m23 + 4*kblz*n3*(-n2 + n3)))/(c2*I2x*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2 + 
        (c2^2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/(c2*l2^3*m2), 0, 0}, 
     {-((16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3))))/(c2*I1x*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*m23 + 4*kblz*n3*(-n2 + n3)))/(c2*l2^3*m1*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      (-((c2*d2*g*m23*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))^2/(4*c2*kblz*l2 + 
           4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
           (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
           (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
          c3*l3*(d2^2*l3^2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
               (n2 - n3)^2) + c2*d2*l2*l3^2*(8*c2*kw2*l2*n3*(-n2 + n3) + 
              g*m23*(l2^2 + 2*(n2 - n3)*n3)) + l2^2*(g*l3^2*m23*n2*n3 + 
              4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*m23*n3^2 + 
              c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                    n5))))))/(c3*l3^3))/(c2*I2x*l2^3), 
      ((-8*c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(c2*d2*g*m23*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*m23*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23) + (8*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(8*c2*l2^4*m2), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I3x*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3)}, 
     {(-4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
        d1*g^2*m23^2*(-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*m23*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*m23*(n2 - n3)*
           (kblz*n2 + kw2*(-n2 + n3))))/(c2*I1x*l2^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2 + 
        (c2^2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/(c2*l2^3*m1), 
      ((-8*c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(c2*d2*g*m23*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*m23*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23) + (8*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(8*c2*I2x*l2^4), 
      (-((c2^2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/(4*c2*kblz*l2 + 
           4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (c3*l3*(g*l3^2*m23*(l2^2 - (n2 - n3)^2) + 4*c2*l2*
             (kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
          c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c3*l3^3))/(c2*l2^3*m2), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3)}, 
     {0, 0, (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I2x*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*I3x*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3*m3)}, {0, 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*I2x*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3)}}
 
cxsmtr = {{0, (d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
        c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3), 0, 0, 0, 
      (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(c1*l1^2)}, 
     {0, (g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3), 
      0, 0, 0, -(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmtr = {{0, ((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
          c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3) + 
        ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
           2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*m13*n1)))/(4*c1*l1^4*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
          (-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/
         (4*c1*l1^4*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))))/I1x, 
      (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(4*c1^2*l1^3*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
          (-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(4*c1^2*l1^3*
          (kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/I1x, 0, 
      0, (((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
          (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(4*c1^2*l1^3*
          (kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))) + 
        (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(c1*l1^2) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*(-2*c1^3*kw1*l1^2*n1 - 
           g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(4*c1^2*l1^3*
          (kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/I1x}, 
     {0, ((g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3) + 
        ((2*c1*kw1*l1 - g*m13)^2*(n0 - n1)^2)/(2*l1^4*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/m1, 0, 0, 0, 
      (-(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2) + 
        ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*(2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
           g*m13*n1))/(2*c1*l1^3*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))))/m1}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*m13*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*m13*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*m23*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*m23*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 0}}
 
amy = {{((g*m13*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
        (g*m13*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
        (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
        (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        ((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (-((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
        (g*m23*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2))/I1z, 
      ((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (2*((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2))/I2z, 0}, 
     {((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (2*((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2))/I1z, 
      ((2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - ((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/
            (4*l2^2))^2/(kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - 
          (c2*g*m23)/(4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*m23*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
        (g*m23*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
        (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I2z, 
      ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3))/I3z}, 
     {0, ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
         (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
        (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
         (2*c3*l3))/I2z, ((2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
        (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/
         l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
        (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I3z}}
 
cxsmy = {{0, 0, 0, -((g*m13*n0*n1)/(c1*l1)), 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmy = {{0, 0, 0, -((g*m13*n0*n1)/(c1*I1z*l1)), 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
xm = {{(g*m13)/(c1*l1) + (g*m23)/(c2*l2), 0, 0, 0, (d0*g*m13)/(c1*l1) - 
       (d1*g*m23)/(c2*l2), 0, -((g*m23)/(c2*l2)), 0, 0, 0, 
      -((d2*g*m23)/(c2*l2)), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (g*m13)/(c1*l1) + (g*m23)/(c2*l2) + (kw1*(n0 - n1)^2)/l1^2 - 
       (g*m13*(n0 - n1)^2)/(2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*m13*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*m23*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*m23*(-n2 + n3)^2)/(2*c2*l2^3), -((c1*kw1*(n0 - n1))/l1) + 
       (g*m13*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*m13*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*m23*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*m23*(-n2 + n3))/(2*l2^2), 0, 0, -((d0*g*m13)/(c1*l1)) + 
       (d1*g*m23)/(c2*l2) + (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (2*l1^2) - (g*m13*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*m13*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*m23)/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*m23*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*m23*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*m23*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*m23*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*m23)/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 0, 0, 
      0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + (g*m13*(n0 - n1))/
        (2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + (g*m13*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*m23*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*m23*(-n2 + n3))/(2*l2^2), 
      2*c1^2*kw1 + 4*c2^2*kw2 + (g*m13)/(c1*l1) - (c1*g*m13)/l1 + 
       (g*m23)/(c2*l2) - (c2*g*m23)/l2, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*m23)/(c2*l2) + (c2*g*m23)/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, (g*m13*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*m13*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*m13*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*m13*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*m23*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*m23*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2), 0, 
      0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/
        (2*c2*l2), (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*m23*(n2 - n3)*si^2)/
        (2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*m23*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, 
     {(d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2), 0, 0, 
      (g*m13*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*m13*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*m23*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*m23*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2), 
      (g*(2*d0^2 + 2*c1*d0*l1)*m13)/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 
      0, (d1*g*m23)/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*m23*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/l2 + 
       (g*m23*(-n2 + n3)*si^2)/(2*l2^2), -4*c2^2*kw2*si^2 + 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 
      0, 0, 0}, {0, -((d0*g*m13)/(c1*l1)) + (d1*g*m23)/(c2*l2) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*m13*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*c1*l1^3) + 
       (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1^2) - 
       (g*m13*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*c1*l1^3) - 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*m13*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*m13*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/(4*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/(4*c2*l2), 0, 
      -((d1*g*m23)/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/
        l2^2 - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*m23*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*m23)/(c2*l2)), 0, 0, 0, (d1*g*m23)/(c2*l2), 0, 
      (g*m23)/(c2*l2) + (g*m3)/(c3*l3), 0, 0, 0, (d2*g*m23)/(c2*l2) - 
       (d3*g*m3)/(c3*l3), 0, -((g*m3)/(c3*l3)), 0, 0, 0, 
      -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*m23)/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*m23*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*m23*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*m23)/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/
        l2^2 - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m23)/(c2*l2) + (g*m3)/(c3*l3) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*m23*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*m23*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*m23*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*m23*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d2*g*m23)/(c2*l2)) + 
       (d3*g*m3)/(c3*l3) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        l2^2 - (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*m23)/(c2*l2) + (c2*g*m23)/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*m23*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*m23*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m23)/(c2*l2) - (c2*g*m23)/l2 + 
       (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/
        (2*c2*l2), (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*m23*(n2 - n3)*si^2)/
        (2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*m23*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*m23*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m23*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*m23*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0, 0, 
      0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*m23)/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*m23*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*m23*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*m23*si^2)/l2 + (g*m23*(2*d1*d2 - 2*si^2))/
        (2*c2*l2), 0, (d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3), 0, 0, 
      (g*m23*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*m23*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c2^2*kw2*si^2 - (c2*g*m23*si^2)/l2 + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 
      0, (d3*g*m3)/(c3*l3), 0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + 
       (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + 
       (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), -4*c3^2*kw3*sl^2 + 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/(2*c3*l3), 0}, 
     {0, (d2*g*m23)/(c2*l2) - (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        l2^2 + (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*m23*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      -((d2*g*m23)/(c2*l2)) + (d3*g*m3)/(c3*l3) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/(4*c2*l2) + 
       (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/(4*c2*l2) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*m13*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*m13)/(2*c1*l1) + (c1*g*m13)/(2*l1), 0, 0, 
      (g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - (g*m13*(-n0 + n1))/
        (2*l1^2), -(c1^2*kw1) - (g*m13)/(2*c1*l1) + (c1*g*m13)/(2*l1), 0, 0, 
      -(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*m23*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*m23)/(4*c2*l2) - 
       (c2*g*m23)/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*m23*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + 
       (c2*g*m23*si)/(4*l2), (g*m23*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      (g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 0}, 
     {0, -((c2*kw2*(n2 - n3))/l2) + (g*m23*(n2 - n3))/(4*l2^2), 
      c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      (g*m23*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 
      (g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 0}, 
     {0, -((c2*kw2*(-n2 + n3))/l2) + (g*m23*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 
      (g*m23*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      -(g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 
      0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*m23*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      (g*m23*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 
      -(g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 
      0, 0, 0}}
 
am = {{((g*m13)/(c1*l1) + (g*m23)/(c2*l2))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2)))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((-(I1x*I1z) + I1zx^2)*((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2)))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2)))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*m23)/(c2*l2*m2)), 0, 0, -((d2*g*(I2x*I2yz - I2xy*I2zx)*m23)/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), (d2*g*(I2x*I2z - I2zx^2)*m23)/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2), -((d2*g*(I2xy*I2z - I2yz*I2zx)*m23)/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), 0, 0, 0, 0, 0, 0}, 
     {0, ((g*m13)/(c1*l1) + (g*m23)/(c2*l2) + (2*kw1*(n0 - n1)^2)/l1^2 - 
        (g*m13*(n0 - n1)^2)/(c1*l1^3) - (c1*(-2*c1*kw1*l1 + g*m13)^2*
          (n0 - n1)^2)/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
           c1^2*g*m13)) + (4*kw2*(n2 - n3)^2)/l2^2 - (g*m23*(n2 - n3)^2)/
         (c2*l2^3) - (c2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)))/m1, 0, 
      ((-(I1xy*I1yz) + I1y*I1zx)*((-4*d0*g*m13)/(c1*l1) + 
         (4*d1*g*m23)/(c2*l2) + (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          l1^2 - (4*g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) + (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/
          l2^2 - (4*g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1xy*I1z - I1yz*I1zx)*((-4*d0*g*m13)/(c1*l1) + (4*d1*g*m23)/(c2*l2) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) + (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/
          l2^2 - (4*g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1yz^2 - I1y*I1z)*((-4*d0*g*m13)/(c1*l1) + (4*d1*g*m23)/(c2*l2) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) + (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/
          l2^2 - (4*g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 0, 
      (-4*c2^3*g*kw2*l2^3*m23 + g^2*m23^2*(-l2^2 + (n2 - n3)^2) - 
        4*c2*g*l2*m23*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d2*g^2*m23^2*(-l2^2 + (n2 - n3)^2) - 
         4*c2*d2*g*l2*m23*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         4*c2^3*kw2*l2^3*(d2*g*m23 + 4*kblz*n3*(-n2 + n3)) + 
         c2^2*l2^2*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*kblz*m23*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2xy*I2z - I2yz*I2zx)*
        (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*m23 + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2yz^2 - I2y*I2z)*
        (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*m23 + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, 0, 0, 0, 0, 0}, 
     {0, 0, (2*c1^2*kw1 + 4*c2^2*kw2 + (g*m13)/(c1*l1) - (c1*g*m13)/l1 - 
        (2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)^2/(c1*l1*(2*c1*kbuz*l1 + 
           2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + (g*m23)/(c2*l2) - 
        (c2*g*m23)/l2 - (4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)))/m1, 0, 
      0, 0, 0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, 0, 0, ((I1xy^2 - I1x*I1y)*
        (4*c2^4*g*kw2*l2^4*m13*n0*n1 + c2^3*g*l2^3*m23*(-(g*m13*n0*n1) + 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*m23^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*m13*n0*n1 - 16*c1*kblz*kw2*l1*(n2 - n3)^2*
            si^2 + c1*g^2*l1*m23^2*(n2*n3 + si^2)) + 
         c2*g*l2*m23*(g*l2^2*m13*n0*n1 + 4*c1*l1*(kw2*(n2 - n3)^2*si^2 + 
             kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2))))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I1x*I1yz - I1xy*I1zx)*(4*c2^4*g*kw2*l2^4*m13*n0*n1 + 
         c2^3*g*l2^3*m23*(-(g*m13*n0*n1) + 4*c1*kw2*l1*(n2*n3 + si^2)) + 
         c1*g^2*l1*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*m13*n0*n1 - 16*c1*kblz*kw2*l1*(n2 - n3)^2*
            si^2 + c1*g^2*l1*m23^2*(n2*n3 + si^2)) + 
         c2*g*l2*m23*(g*l2^2*m13*n0*n1 + 4*c1*l1*(kw2*(n2 - n3)^2*si^2 + 
             kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2))))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1xy*I1yz - I1y*I1zx)*
         (4*c2^4*g*kw2*l2^4*m13*n0*n1 + c2^3*g*l2^3*m23*(-(g*m13*n0*n1) + 
            4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*m23^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-4*g*kblz*l2^2*m13*n0*n1 - 16*c1*kblz*kw2*l1*(n2 - n3)^2*
             si^2 + c1*g^2*l1*m23^2*(n2*n3 + si^2)) + c2*g*l2*m23*
           (g*l2^2*m13*n0*n1 + 4*c1*l1*(kw2*(n2 - n3)^2*si^2 + 
              kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2))))))/
        (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + 
          g^2*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2yz - I2y*I2zx)*
        (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, 0, 0, 0, 0, 0}, 
     {((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(c1*d1^2*g^2*l1*m23^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*m13 + 4*c1*d0*kblz*l1*l2^2*m13 + 
           c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 4*c2^4*kw2*l2^2*
          (d0^2*g*m13 + c1*d0*g*l1*m13 + c1*l1*(d1*g*m23 + 4*kblz*si^2)) + 
         c2*g*l2*m23*(d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + d1*g*m23 + 
             4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
           c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1x*I1z - I1zx^2)*(c1*d1^2*g^2*l1*m23^2 + 
          c2^2*g*(4*d0^2*kblz*l2^2*m13 + 4*c1*d0*kblz*l1*l2^2*m13 + 
            c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 4*c2^4*kw2*l2^2*
           (d0^2*g*m13 + c1*d0*g*l1*m13 + c1*l1*(d1*g*m23 + 4*kblz*si^2)) + 
          c2*g*l2*m23*(d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + 
              d1*g*m23 + 4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
            c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2))))/
        (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I1xy*I1z - I1yz*I1zx)*(c1*d1^2*g^2*l1*m23^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*m13 + 4*c1*d0*kblz*l1*l2^2*m13 + 
           c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 4*c2^4*kw2*l2^2*
          (d0^2*g*m13 + c1*d0*g*l1*m13 + c1*l1*(d1*g*m23 + 4*kblz*si^2)) + 
         c2*g*l2*m23*(d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + d1*g*m23 + 
             4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
           c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), (d1*g*m23)/(c2*l2*m2), 0, 0, 
      -(((I2x*I2yz - I2xy*I2zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2x*I2z - I2zx^2)*(-(d1*d2*g^2*m23^2) + 
         c2^2*d1*d2*g^2*m23^2 + 16*c2^4*kblz*kw2*l2^2*si^2 + 
         4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 4*c2^3*g*l2*m23*
          (d1*d2*kw2 + kblz*si^2)))/(c2*(I2xy^2*I2z + 
         I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      -(((I2xy*I2z - I2yz*I2zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, 0, 0, 0, 0, 0}, 
     {0, -(((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) - (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23)))/m1), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((g*m13*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*m13*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2/
          (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) + 
         (g*m23*(d1^2 + c2*d1*l2 + n2*n3))/(c2*l2) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*((g*m13*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*m13*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2/
          (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) + 
         (g*m23*(d1^2 + c2*d1*l2 + n2*n3))/(c2*l2) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1yz^2 - I1y*I1z)*((g*m13*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*m13*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2/
          (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) + 
         (g*m23*(d1^2 + c2*d1*l2 + n2*n3))/(c2*l2) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      0, (-4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
        d1*g^2*m23^2*(-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*m23*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*m23*(n2 - n3)*
           (kblz*n2 + kw2*(-n2 + n3))))/(c2*l2^3*m2*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
         c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
             kw2*(n2 - n3)^2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I2xy*I2z - I2yz*I2zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      -(((I2yz^2 - I2y*I2z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^
                2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 0, 0, 0, 0, 
      0, 0}, {-((g*m23)/(c2*l2*m1)), 0, 0, (d1*g*(I1x*I1yz - I1xy*I1zx)*m23)/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(-(I1x*I1z) + I1zx^2)*m23)/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(I1xy*I1z - I1yz*I1zx)*m23)/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), ((g*m23)/(c2*l2) + (g*m3)/(c3*l3))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      ((-(I2x*I2z) + I2zx^2)*((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      ((I2xy*I2z - I2yz*I2zx)*((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      -(g/(c3*l3)), 0, 0, -((d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), (d4*g*(I3x*I3z - I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -((d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3))}, {0, (-4*c2^3*g*kw2*l2^3*m23 + 
        g^2*m23^2*(-l2^2 + (n2 - n3)^2) - 4*c2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I1xy*I1yz - I1y*I1zx)*(4*c2^3*kw2*l2^3*(d1*g*m23 + 
           4*kblz*n2*(n2 - n3)) + d1*g^2*m23^2*(l2^2 - (n2 - n3)^2) - 
         c2*g*l2*m23*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*m23*(n2 - n3)^2) + c2^2*l2^2*
          (d1*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) - 4*g*m23*(n2 - n3)*
            (kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1xy*I1z - I1yz*I1zx)*
         (4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*m23^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*m23*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*m23*(n2 - n3)^2) + c2^2*l2^2*
           (d1*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) - 4*g*m23*(n2 - n3)*
             (kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), -(((I1yz^2 - I1y*I1z)*
         (4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*m23^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*m23*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*m23*(n2 - n3)^2) + c2^2*l2^2*
           (d1*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) - 4*g*m23*(n2 - n3)*
             (kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, ((2*g*m23)/(c2*l2) + (2*g*m3)/(c3*l3) + 
        (8*kw2*(n2 - n3)^2)/l2^2 - (2*g*m23*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*kw3*(n4 - n5)^2)/l3^2 - (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*d2*g^2*l3^3*m23^2*(-l2^2 + (n2 - n3)^2) + 
          c2*g*l2*m23*(c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
                kw2*(n2 - n3)^2) + l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*(
                n4 - n5)) + d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3^2*kw3*l2^2*l3^2*n4*(n4 - n5)) + 4*c2^4*kw2*l2^4*
           (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
            c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) + 
          c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*
             m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
              16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*(g*m3*n4 + 
                4*d3*kw3*(-n4 + n5)))) + c2^2*l2^2*
           (4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*
             l3^2*n4*(n4 - n5) + c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*
                 (n2 - n3)^2) + 4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + 
                g*(l3^2*m23*n3*(-n2 + n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*d2*g^2*l3^3*m23^2*(-l2^2 + (n2 - n3)^2) + 
         c2*g*l2*m23*(c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*
                (n2 - n3)^2) + l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*
              (n4 - n5)) + d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(n4 - n5)) + 4*c2^4*kw2*l2^4*
          (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
           c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) + 
         c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*
            m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
             16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*(g*m3*n4 + 4*d3*
                kw3*(-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
            (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2yz^2 - I2y*I2z)*(c3*d2*g^2*l3^3*m23^2*
          (-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
          (c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*(n4 - n5)) + 
           d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 4*c3^2*kw3*l2^2*l3^2*n4*
            (n4 - n5)) + 4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
            (n4 - n5)) + c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
             16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*(g*m3*n4 + 4*d3*
                kw3*(-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
            (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 
        4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, 
     {0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/
       (m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 0, 0, 0, 
      0, (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m23)/(c2*l2) - (c2*g*m23)/l2 - 
        (4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)^2/(c2*l2*(4*c2*kblz*l2 + 
           4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + (g*m3)/(c3*l3) - 
        (c3*g*m3)/l3)/m2, 0, 0, 0, 0, 0, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3, 0, 0, 0}, {0, 0, 0, 
      -(((I1xy^2 - I1x*I1y)*(4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + 
          g^2*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), -(((I1x*I1yz - I1xy*I1zx)*
         (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, 0, 0, ((I2xy^2 - I2x*I2y)*
        (c3*g^2*l3^3*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
         c2^3*g*l2^3*m23*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
             kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
             l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
          (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2*g*l2*m23*
          (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*
              (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2^2*l2^2*
          (4*g*kblz*l2^2*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) - 
           c3*l3*(g^2*l3^2*m23^2*(n2*n3 + si^2) - 16*kblz*(kw2*l3^2*
                (n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2x*I2yz - I2xy*I2zx)*
        (c3*g^2*l3^3*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
         c2^3*g*l2^3*m23*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
             kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
             l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
          (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2*g*l2*m23*
          (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*
              (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2^2*l2^2*
          (4*g*kblz*l2^2*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) - 
           c3*l3*(g^2*l3^2*m23^2*(n2*n3 + si^2) - 16*kblz*(kw2*l3^2*
                (n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I2xy*I2yz - I2y*I2zx)*
         (c3*g^2*l3^3*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
          c2^3*g*l2^3*m23*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
              kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
              l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
           (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2*g*l2*m23*
           (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*(
                -((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
              kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2^2*l2^2*(4*g*kblz*l2^2*m3*
             (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) - 
            c3*l3*(g^2*l3^2*m23^2*(n2*n3 + si^2) - 16*kblz*(kw2*l3^2*
                 (n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, 0, 0, 
      -(((I3xy^2 - I3x*I3y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), -(((I3x*I3yz - I3xy*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3)), 
      ((I3xy*I3yz - I3y*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {-((d2*g*m23)/(c2*l2*m1)), 0, 0, 
      -(((I1x*I1yz - I1xy*I1zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I1x*I1z - I1zx^2)*(-(d1*d2*g^2*m23^2) + 
         c2^2*d1*d2*g^2*m23^2 + 16*c2^4*kblz*kw2*l2^2*si^2 + 
         4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 4*c2^3*g*l2*m23*
          (d1*d2*kw2 + kblz*si^2)))/(c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      -(((I1xy*I1z - I1yz*I1zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(c3*d2^2*g^2*l3*m23^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - 
           c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + c2*g*l2*m23*
          (c3*l3*(4*d2^2*kblz + d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) - 
         c2^3*g*l2*m23*(c3*l3*(-4*d2^2*kw2 + d2*g*m23 + d3*g*m3 + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) + c2^2*(c3*g*l3*(4*d2*kblz*l2^2*m23 - 
             d2^2*g*m23^2 + 4*d3*kblz*l2^2*m3) + 16*c3^3*kblz*kw3*l2^2*l3*
            sl^2 - 4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*
            (d3^2 + sl^2))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*m23 - c2^2*g*m23)), -(((I2x*I2z - I2zx^2)*(c3*d2^2*g^2*l3*m23^2 + 
          4*c2^4*kw2*l2^2*(c3*l3*(d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*m23*(c3*l3*(4*d2^2*kblz + d2*g*m23 + d3*g*m3 + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*m23*
           (c3*l3*(-4*d2^2*kw2 + d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(c3*g*l3*(4*d2*kblz*l2^2*m23 - d2^2*g*m23^2 + 4*d3*kblz*l2^
                2*m3) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 4*c3^2*g*kblz*l2^2*m3*
             sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2z - I2yz*I2zx)*(c3*d2^2*g^2*l3*m23^2 + 
         4*c2^4*kw2*l2^2*(c3*l3*(d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*m23*(c3*l3*(4*d2^2*kblz + d2*g*m23 + d3*g*m3 + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*m23*
          (c3*l3*(-4*d2^2*kw2 + d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(c3*g*l3*(4*d2*kblz*l2^2*m23 - d2^2*g*m23^2 + 
             4*d3*kblz*l2^2*m3) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), (d3*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3x*I3z - I3zx^2)*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3xy*I3z - I3yz*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, 
     {0, (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*m23 + 4*kblz*n3*(-n2 + n3)))/(c2*l2^3*m1*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I1xy*I1yz - I1y*I1zx)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
         c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
             kw2*(n2 - n3)^2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1xy*I1z - I1yz*I1zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      -(((I1yz^2 - I1y*I1z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^
                2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 0, 
      (c3*d2*g^2*l3^3*m23^2*(-l2^2 + (n2 - n3)^2) + 
        c2*g*l2*m23*(c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*
             (n4 - n5)) + d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
          4*c3^2*kw3*l2^2*l3^2*n4*(n4 - n5)) + 4*c2^4*kw2*l2^4*
         (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
          c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) + 
        c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*
           m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
            16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*
             (g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
        c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
          16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
          c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                l2^2*m3*n4*(-n4 + n5))))))/(c2*c3*l2^3*l3^3*m2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*m23^2*
           (d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
          4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
            g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l3^2*m23 + 4*kblz*l3^2*n3^2 + 4*d3^2*kw3*(n4 - n5)^
                2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(d2^2*l3^2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
              g^2*l3^2*m23^2*n3*(-n2 + n3) + 4*d2*g*kblz*l3^2*m23*(l2^2 + 
                2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
              4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2*g*l2*m23*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l2^2*l3^2*m23 + 4*d2^2*l3^2*(kblz*(l2^2 - (n2 - n3)^
                   2) + kw2*(n2 - n3)^2) + l2^2*(4*kblz*l3^2*n2*n3 + 
                4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + 
                    n5))))) - c2^3*l2^3*(4*c3^3*g*kw3*l3^3*m23*n4^2 + 
            g^2*m23*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 
            c3^2*g*l3^2*m23*n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-4*d2^2*g*kw2*l3^2*m23 + d2*l3^2*(g^2*m23^2 + 
                32*kblz*kw2*(n2 - n3)*n3) + g*m23*(4*l3^2*n3*(kblz*n3 + 
                  kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                 (l3^2 + 2*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*g^2*l3^3*m23^2*(d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
         4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*m23 + 4*kblz*l3^2*n3^2 + 4*d3^2*kw3*(n4 - n5)^2 + 
             d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(d2^2*l3^2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
             g^2*l3^2*m23^2*n3*(-n2 + n3) + 4*d2*g*kblz*l3^2*m23*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*m23*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*m23 + 4*d2^2*l3^2*(kblz*(l2^2 - (n2 - n3)^
                  2) + kw2*(n2 - n3)^2) + l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*
                kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
         c2^3*l2^3*(4*c3^3*g*kw3*l3^3*m23*n4^2 + g^2*m23*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*m23*n4*
            (g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + c3*l3*(-4*d2^2*g*kw2*l3^2*m23 + 
             d2*l3^2*(g^2*m23^2 + 32*kblz*kw2*(n2 - n3)*n3) + 
             g*m23*(4*l3^2*n3*(kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*
                (n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2yz^2 - I2y*I2z)*
        (c3*g^2*l3^3*m23^2*(d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
         4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*m23 + 4*kblz*l3^2*n3^2 + 4*d3^2*kw3*(n4 - n5)^2 + 
             d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(d2^2*l3^2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
             g^2*l3^2*m23^2*n3*(-n2 + n3) + 4*d2*g*kblz*l3^2*m23*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*m23*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*m23 + 4*d2^2*l3^2*(kblz*(l2^2 - (n2 - n3)^
                  2) + kw2*(n2 - n3)^2) + l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*
                kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
         c2^3*l2^3*(4*c3^3*g*kw3*l3^3*m23*n4^2 + g^2*m23*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*m23*n4*
            (g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + c3*l3*(-4*d2^2*g*kw2*l3^2*m23 + 
             d2*l3^2*(g^2*m23^2 + 32*kblz*kw2*(n2 - n3)*n3) + 
             g*m23*(4*l3^2*n3*(kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*
                (n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3*m3), 0, ((I3xy*I3yz - I3y*I3zx)*
        (d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + g*l3*m3*n5 - 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 0, 
      (d3*g*(I2x*I2yz - I2xy*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(-(I2x*I2z) + I2zx^2)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(I2xy*I2z - I2yz*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), g/(c3*l3), 0, 0, (d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(-(I3x*I3z) + I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
          (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3), 
      -(((I2xy*I2z - I2yz*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      -(((I2yz^2 - I2y*I2z)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 0, 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, 0, 0, 
      (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 0, 0, 0, 0, 0, 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l3^3)), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      ((I2xy*I2yz - I2y*I2zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 0, 0, ((I3xy^2 - I3x*I3y)*
        (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
           l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3), 
      ((I3x*I3yz - I3xy*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), -(((I3xy*I3yz - I3y*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3))}, {0, 0, 0, 0, 0, 0, 
      -((d4*g*m3)/(c3*l3*m2)), 0, 0, ((I2x*I2yz - I2xy*I2zx)*
        (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2x*I2z - I2zx^2)*(-(d3*d4*g*m3) + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2xy*I2z - I2yz*I2zx)*(d3*d4*g*m3 + 
         (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d4*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -(((I3x*I3z - I3zx^2)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
          (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2xy*I2z - I2yz*I2zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2yz^2 - I2y*I2z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 0, 
      -(((I3xy*I3yz - I3y*I3zx)*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
            g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}}
 
cxsm = {{-((g*m13)/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3), 
      0, 0, 0, -(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2)}, 
     {0, 0, (-2*c1^3*kw1*l1 - g*m13 + c1^2*g*m13)/(c1*l1), 0, 0, 0}, 
     {0, 0, 0, -((g*m13*n0*n1)/(c1*l1)), 0, 0}, {-((d0*g*m13)/(c1*l1)), 0, 0, 
      0, 0, 0}, {0, (d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/
       (c1*l1^3), 0, 0, 0, (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
         c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/
       (c1*l1^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bm = {{-((g*m13)/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, ((g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3) + 
        ((2*c1*kw1*l1 - g*m13)*((c1*kw1*(n0 - n1))/l1 - (g*m13*(n0 - n1))/
            (2*l1^2))*(n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))) - 
        ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*m13*(-n0 + n1))/(2*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((c1*kw1*(n0 - n1))/l1 - 
            (g*m13*(n0 - n1))/(2*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*m13*(-n0 + n1))/(2*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2) + 
        (((c1*kw1*(n0 - n1))/l1 - (g*m13*(n0 - n1))/(2*l1^2))*
          (2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
           g*m13*n1)*((c1*kw1*(-n0 + n1))/l1 - (g*m13*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/
       m1}, {0, 0, ((-2*c1^3*kw1*l1 - g*m13 + c1^2*g*m13)/(c1*l1) - 
        ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*(-(c1^2*kw1) - 
           (g*m13)/(2*c1*l1) + (c1*g*m13)/(2*l1)))/
         (c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/
       m1, 0, 0, 0}, {-((d0*g*(I1x*I1yz - I1xy*I1zx)*m13)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((-(I1xy*I1yz) + I1y*I1zx)*
        ((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
           c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*((g*m13*n1)/(2*c1*l1) + 
            (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
            (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((g*m13*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), -((g*(I1xy^2 - I1x*I1y)*m13*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        (((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) + (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
            c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(c1*l1^2) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
            g*m13*n1)*(-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2)}, 
     {-((d0*g*(-(I1x*I1z) + I1zx^2)*m13)/(c1*(I1x*I1yz^2 + I1xy^2*I1z - 
          I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1)), 
      ((I1xy*I1z - I1yz*I1zx)*
        ((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
           c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*((g*m13*n1)/(2*c1*l1) + 
            (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
            (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((g*m13*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(I1x*I1yz - I1xy*I1zx)*m13*n0*n1)/(c1*(I1x*I1yz^2 + I1xy^2*I1z - 
          I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1)), 0, 
      ((I1xy*I1z - I1yz*I1zx)*(((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) + (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
            c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(c1*l1^2) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
            g*m13*n1)*(-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2)}, 
     {-((d0*g*(I1xy*I1z - I1yz*I1zx)*m13)/(c1*(I1x*I1yz^2 + I1xy^2*I1z - 
          I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1)), 
      ((I1yz^2 - I1y*I1z)*((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 
             2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1yz^2 - I1y*I1z)*(-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
            ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
              (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(-(I1xy*I1yz) + I1y*I1zx)*m13*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1yz^2 - I1y*I1z)*
        (((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) + (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
            c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(c1*l1^2) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
            g*m13*n1)*(-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
stage2fudge = {flex1 -> 2*c1^(3/2)*Sqrt[(M11*Y1)/(g*(m1 + m2 + m3))], 
     flex2 -> 2*c2^(3/2)*Sqrt[(M21*Y2)/(g*(m2 + m3))], 
     flex3 -> 2*c3^(3/2)*Sqrt[(M31*Y3)/(g*m3)], d0 -> d0 + flex1, 
     d1 -> d1 + flex2, d2 -> d2 + flex2, d3 -> d3 + flex3, d4 -> d4 + flex3, 
     l1 -> (-2*flex1)/c1 + l1, l2 -> (-2*flex2)/c2 + l2, 
     l3 -> (-2*flex3)/c3 + l3, n0 -> n0 + (flex1*si1)/c1, 
     n1 -> n1 - (flex1*si1)/c1, n2 -> n2 + (flex2*si2)/c2, 
     n3 -> n3 - (flex2*si2)/c2, n4 -> n4 + (flex3*si3)/c3, 
     n5 -> n5 - (flex3*si3)/c3}
 
g /: g::usage = "g is local gravity."
 
M11 /: M11::usage = "M11 is the moment of area of wires from blades on \
structure to top mass in direction \"1\"."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
Y1 /: Y1::usage = 
     "Y1 is Young's modulus of wires from blades on structure to top mass."
 
M21 /: M21::usage = "M21 is the moment of area of wires from blades on top \
mass to intermediate mass in direction \"1\""
 
Y2 /: Y2::usage = "Y2 is Young's modulus of wires from blades on top mass to \
intermediate mass."
 
M31 /: M31::usage = "M31 is the moment of area of wires (fibres) from \
intermediate mass to optic in direction \"1\""
 
Y3 /: Y3::usage = 
     "Y3 is Young's modulus of wires (fibres) from intermediate mass to \
optic."
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
qm = {{kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1), 0, 0, 0, 0, 
      0}, {0, kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1), 0, 0, 
      0, 0}, {0, 0, kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      0, 0, 0}, {0, 0, 0, kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - 
       (c2*g*m23)/(4*l2), 0, 0}, {0, 0, 0, 0, kblz + c2^2*kw2 + 
       (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 0}, 
     {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)}}
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)/(2*c1*l1), 0, 0, 
      -(2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)/(2*c1*l1), 0, 0, 
      (2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)/(2*c1*l1)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
kmlp = {{I1y, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0}, {0, 0, I2y, 0, 0, 0}, 
     {0, 0, 0, m2, 0, 0}, {0, 0, 0, 0, I3y, 0}, {0, 0, 0, 0, 0, m3}}
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
xmlp = {{(g*(2*d0^2 + 2*c1*d0*l1)*m13)/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 
      (d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2), -4*c2^2*kw2*si^2 + 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      (d1*g*m23)/(c2*l2), 0, 0}, {(d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2), 
      (g*m13)/(c1*l1) + (g*m23)/(c2*l2), -((d2*g*m23)/(c2*l2)), 
      -((g*m23)/(c2*l2)), 0, 0}, {-4*c2^2*kw2*si^2 + (c2*g*m23*si^2)/l2 + 
       (g*m23*(2*d1*d2 - 2*si^2))/(2*c2*l2), -((d2*g*m23)/(c2*l2)), 
      4*c2^2*kw2*si^2 - (c2*g*m23*si^2)/l2 + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 
      (d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3), -4*c3^2*kw3*sl^2 + 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/(2*c3*l3), 
      (d3*g*m3)/(c3*l3)}, {(d1*g*m23)/(c2*l2), -((g*m23)/(c2*l2)), 
      (d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3), (g*m23)/(c2*l2) + 
       (g*m3)/(c3*l3), -((d4*g*m3)/(c3*l3)), -((g*m3)/(c3*l3))}, 
     {0, 0, -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), -((d4*g*m3)/(c3*l3)), 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 
      (d4*g*m3)/(c3*l3)}, {0, 0, (d3*g*m3)/(c3*l3), -((g*m3)/(c3*l3)), 
      (d4*g*m3)/(c3*l3), (g*m3)/(c3*l3)}}
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {-(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 0, 0}, 
     {c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 0, 0}, 
     {-(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 0, 0}, 
     {c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 0, 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 0, 0, 0}}
 
amlp = {{(c1*d1^2*g^2*l1*m23^2 + c2^2*g*(4*d0^2*kblz*l2^2*m13 + 
          4*c1*d0*kblz*l1*l2^2*m13 + c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 
        4*c2^4*kw2*l2^2*(d0^2*g*m13 + c1*d0*g*l1*m13 + 
          c1*l1*(d1*g*m23 + 4*kblz*si^2)) + c2*g*l2*m23*
         (d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + d1*g*m23 + 
            4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
          c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2)))/
       (c1*c2*I1y*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      ((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2))/m1, 
      (d1*d2*g^2*m23^2 - c2^2*d1*d2*g^2*m23^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*m23*(d1*d2 - si^2) + 4*c2^3*g*l2*m23*
         (d1*d2*kw2 + kblz*si^2))/(c2*I2y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*m23 - c2^2*g*m23)), (d1*g*m23)/(c2*l2*m2), 0, 0}, 
     {((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2))/I1y, 
      ((g*m13)/(c1*l1) + (g*m23)/(c2*l2))/m1, -((d2*g*m23)/(c2*I2y*l2)), 
      -((g*m23)/(c2*l2*m2)), 0, 0}, 
     {(d1*d2*g^2*m23^2 - c2^2*d1*d2*g^2*m23^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*m23*(d1*d2 - si^2) + 4*c2^3*g*l2*m23*
         (d1*d2*kw2 + kblz*si^2))/(c2*I1y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*m23 - c2^2*g*m23)), -((d2*g*m23)/(c2*l2*m1)), 
      (8*c2^2*kw2*si^2 - (2*c2*g*m23*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (2*g*m23*(d2^2 + c2*d2*l2 + si^2))/(c2*l2) + 8*c3^2*kw3*sl^2 - 
        (2*c3*g*m3*sl^2)/l3 + (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/
       (2*I2y), ((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3))/m2, 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I3y*l3), 
      (d3*g)/(c3*l3)}, {(d1*g*m23)/(c2*I1y*l2), -((g*m23)/(c2*l2*m1)), 
      ((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3))/I2y, 
      ((g*m23)/(c2*l2) + (g*m3)/(c3*l3))/m2, -((d4*g*m3)/(c3*I3y*l3)), 
      -(g/(c3*l3))}, {0, 0, (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*
         sl^2)/(c3*I2y*l3), -((d4*g*m3)/(c3*l3*m2)), 
      (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/
       (c3*I3y*l3), (d4*g)/(c3*l3)}, {0, 0, (d3*g*m3)/(c3*I2y*l3), 
      -((g*m3)/(c3*l3*m2)), (d4*g*m3)/(c3*I3y*l3), g/(c3*l3)}}
 
cxsmlp = {{-((d0*g*m13)/(c1*l1)), 0, 0, 0, 0, 0}, {-((g*m13)/(c1*l1)), 0, 0, 
      0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmlp = {{-((d0*g*m13)/(c1*I1y*l1)), 0, 0, 0, 0, 0}, 
     {-((g*m13)/(c1*l1*m1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmtr = {{I1x, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0}, {0, 0, I2x, 0, 0, 0}, 
     {0, 0, 0, m2, 0, 0}, {0, 0, 0, 0, I3x, 0}, {0, 0, 0, 0, 0, m3}}
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmtr = {{(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
         (-(g*m23*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*m23*
         (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
             (n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + 
            g*m13*(l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*m13*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*m13*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*m23*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*
         (n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
              l1^2*m23*n2*(-n2 + n3)))))/(c1*c2*l1^3*l2^3), 
      (d1*(d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3) + 
        l2*n2*(-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3)))/(c2*l2^3), 
      (d1*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*n2*(n2 - n3))/(c2*l2^3), 0, 0}, 
     {(c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*
         (n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
              l1^2*m23*n2*(-n2 + n3)))))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(g*l2^2*m13*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*m23*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3)/(c2*l2^3), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3), 0, 
      0}, {(d1*(d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3) + 
        l2*n2*(-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3)))/(c2*l2^3), 
      (d2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*n3)/(c2*l2^3), 
      (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
         (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
         (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
             (n2 - n3)^2) + c2*d2*l2*l3^2*(8*c2*kw2*l2*n3*(-n2 + n3) + 
            g*m23*(l2^2 + 2*(n2 - n3)*n3)) + l2^2*(g*l3^2*m23*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*m23*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3)}, 
     {(d1*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*m23)*n2*(n2 - n3))/(c2*l2^3), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (c3*l3*(g*l3^2*m23*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3)}, 
     {0, 0, (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3)}, {0, 0, (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3), (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3)}}
 
cqxmtr = {{(c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
        c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))/(2*c1*l1^2), 
      ((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 0, 0, 0, 0}, 
     {(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
        c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))/(2*c1*l1^2), 
      -((2*c1*kw1*l1 - g*m13)*(n0 - n1))/(2*l1^2), 0, 0, 0, 0}, 
     {(-4*c2^3*kw2*l2^2*n2 + c2*d1*g*m23*(n2 - n3) - g*l2*m23*n3 + 
        c2^2*l2*(g*m23*n2 + 4*d1*kw2*(-n2 + n3)))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*m23*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(-4*c2^3*kw2*l2^2*n2 + c2*d1*g*m23*(n2 - n3) - g*l2*m23*n3 + 
        c2^2*l2*(g*m23*n2 + 4*d1*kw2*(-n2 + n3)))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*m23*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
        g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
        g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n3 - g*l2*m23*n3 + c2*d2*g*m23*(-n2 + n3) + 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*m23)*(n2 - n3))/(4*l2^2), 0, 0}}
 
amtr = {{((-8*(c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2)/
         (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) - 
        (8*(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2)/
         (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
            (-(g*m23*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*m23*
            (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
           c2*l2*(d0^2*l2^2*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
                (n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + g*
                m13*(l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*m13*n0*n1 + 2*
                c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*m13*n1^2 + c1*d1*l1*
                (4*d1*kw2*(n2 - n3)^2 + g*m23*(l2^2 + 2*n2*(-n2 + n3)))))))/
         (c1*c2*l1^3*l2^3))/(8*I1x), 
      ((-8*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
           2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
           c1^2*g*m13)) - (8*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*
          (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
           g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3)))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*(c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*
            n2*(n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
                 l1^2*m23*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3))/(8*m1), 
      -((16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3))))/(c2*I2x*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      (-4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
        d1*g^2*m23^2*(-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*m23*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*m23*(n2 - n3)*
           (kblz*n2 + kw2*(-n2 + n3))))/(c2*l2^3*m2*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 0}, 
     {((-8*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
           2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
           c1^2*g*m13)) - (8*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*
          (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
           g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3)))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*(c1*d1*g*l1^3*m23*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*
            n2*(n2 - n3) + c2*l2*(d0*l2^2*(g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               4*d1*kw2*l1^2*(n2 - n3)^2 + g*(l2^2*m13*n1*(-n0 + n1) + 
                 l1^2*m23*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3))/(8*I1x), 
      (-((c1*(-2*c1*kw1*l1 + g*m13)^2*(n0 - n1)^2)/
          (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13))) + 
        (c2*l2*(g*l2^2*m13*(l1^2 - (n0 - n1)^2) + 2*c1*l1*
             (kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
          c1*g*l1^3*m23*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)))/m1, 
      (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*m23 + 4*kblz*n3*(-n2 + n3)))/(c2*I2x*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2 + 
        (c2^2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/(c2*l2^3*m2), 0, 0}, 
     {-((16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3))))/(c2*I1x*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*m23 + 4*kblz*n3*(-n2 + n3)))/(c2*l2^3*m1*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      (-((c2*d2*g*m23*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*m23*n3))^2/(4*c2*kblz*l2 + 
           4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
           (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
           (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
          c3*l3*(d2^2*l3^2*(g*m23*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
               (n2 - n3)^2) + c2*d2*l2*l3^2*(8*c2*kw2*l2*n3*(-n2 + n3) + 
              g*m23*(l2^2 + 2*(n2 - n3)*n3)) + l2^2*(g*l3^2*m23*n2*n3 + 
              4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*m23*n3^2 + 
              c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                    n5))))))/(c3*l3^3))/(c2*I2x*l2^3), 
      ((-8*c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(c2*d2*g*m23*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*m23*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23) + (8*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(8*c2*l2^4*m2), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I3x*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3)}, 
     {(-4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
        d1*g^2*m23^2*(-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*m23*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*m23*(n2 - n3)*
           (kblz*n2 + kw2*(-n2 + n3))))/(c2*I1x*l2^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      (g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*(n2 - n3)^2 + 
        (c2^2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/(c2*l2^3*m1), 
      ((-8*c2*l2*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(c2*d2*g*m23*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*m23*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*m23*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23) + (8*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g*m23*(-l2^2 + (n2 - n3)^2) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(8*c2*I2x*l2^4), 
      (-((c2^2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/(4*c2*kblz*l2 + 
           4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (c3*l3*(g*l3^2*m23*(l2^2 - (n2 - n3)^2) + 4*c2*l2*
             (kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
          c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c3*l3^3))/(c2*l2^3*m2), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3)}, 
     {0, 0, (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I2x*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*I3x*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3*m3)}, {0, 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*I2x*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3)}}
 
cxsmtr = {{0, (d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
        c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3), 0, 0, 0, 
      (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(c1*l1^2)}, 
     {0, (g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3), 
      0, 0, 0, -(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmtr = {{0, ((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
          c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3) + 
        ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
           2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*m13*n1)))/(4*c1*l1^4*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
          (-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/
         (4*c1*l1^4*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))))/I1x, 
      (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(4*c1^2*l1^3*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
          (-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(4*c1^2*l1^3*
          (kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/I1x, 0, 
      0, (((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
          (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(4*c1^2*l1^3*
          (kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))) + 
        (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(c1*l1^2) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*(-2*c1^3*kw1*l1^2*n1 - 
           g*l1*m13*n1 + c1*d0*g*m13*(-n0 + n1) + 
           c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/(4*c1^2*l1^3*
          (kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/I1x}, 
     {0, ((g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3) + 
        ((2*c1*kw1*l1 - g*m13)^2*(n0 - n1)^2)/(2*l1^4*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/m1, 0, 0, 0, 
      (-(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2) + 
        ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*(2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
           g*m13*n1))/(2*c1*l1^3*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))))/m1}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*m13*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*m13*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*m23*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*m23*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 0}}
 
amy = {{((g*m13*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
        (g*m13*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
        (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
        (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        ((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (-((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
        (g*m23*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2))/I1z, 
      ((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (2*((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2))/I2z, 0}, 
     {((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (2*((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2)))/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(-2*n2*n3 - 2*si^2))/(2*c2*l2))/I1z, 
      ((2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - ((c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/
            (4*l2^2))^2/(kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - 
          (c2*g*m23)/(4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*m23*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) - 
        (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2)) + 
        (g*m23*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
        (g*m23*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
        (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I2z, 
      ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3))/I3z}, 
     {0, ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
         (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
        (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
         (2*c3*l3))/I2z, ((2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
        (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/
         l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
        (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I3z}}
 
cxsmy = {{0, 0, 0, -((g*m13*n0*n1)/(c1*l1)), 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmy = {{0, 0, 0, -((g*m13*n0*n1)/(c1*I1z*l1)), 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
xm = {{(g*m13)/(c1*l1) + (g*m23)/(c2*l2), 0, 0, 0, (d0*g*m13)/(c1*l1) - 
       (d1*g*m23)/(c2*l2), 0, -((g*m23)/(c2*l2)), 0, 0, 0, 
      -((d2*g*m23)/(c2*l2)), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (g*m13)/(c1*l1) + (g*m23)/(c2*l2) + (kw1*(n0 - n1)^2)/l1^2 - 
       (g*m13*(n0 - n1)^2)/(2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*m13*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*m23*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*m23*(-n2 + n3)^2)/(2*c2*l2^3), -((c1*kw1*(n0 - n1))/l1) + 
       (g*m13*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*m13*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*m23*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*m23*(-n2 + n3))/(2*l2^2), 0, 0, -((d0*g*m13)/(c1*l1)) + 
       (d1*g*m23)/(c2*l2) + (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (2*l1^2) - (g*m13*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*m13*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*m23)/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*m23*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*m23*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*m23*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*m23*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*m23)/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 0, 0, 
      0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + (g*m13*(n0 - n1))/
        (2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + (g*m13*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*m23*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*m23*(-n2 + n3))/(2*l2^2), 
      2*c1^2*kw1 + 4*c2^2*kw2 + (g*m13)/(c1*l1) - (c1*g*m13)/l1 + 
       (g*m23)/(c2*l2) - (c2*g*m23)/l2, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*m23)/(c2*l2) + (c2*g*m23)/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, (g*m13*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*m13*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*m23*(-n2 + n3)^2*si^2)/
        (2*c2*l2^3) + (g*m23*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*m13*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*m13*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*m23*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*m23*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2), 0, 
      0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/
        (2*c2*l2), (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*m23*(n2 - n3)*si^2)/
        (2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*m23*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, 
     {(d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2), 0, 0, 
      (g*m13*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*m13*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*m23*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*m23*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2), 
      (g*(2*d0^2 + 2*c1*d0*l1)*m13)/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 
      0, (d1*g*m23)/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*m23*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/l2 + 
       (g*m23*(-n2 + n3)*si^2)/(2*l2^2), -4*c2^2*kw2*si^2 + 
       (c2*g*m23*si^2)/l2 + (g*m23*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 
      0, 0, 0}, {0, -((d0*g*m13)/(c1*l1)) + (d1*g*m23)/(c2*l2) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*m13*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*c1*l1^3) + 
       (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1^2) - 
       (g*m13*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*c1*l1^3) - 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*m13*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*m13*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/(4*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*m23*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/(4*c2*l2), 0, 
      -((d1*g*m23)/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/
        l2^2 - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*m23*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*m23)/(c2*l2)), 0, 0, 0, (d1*g*m23)/(c2*l2), 0, 
      (g*m23)/(c2*l2) + (g*m3)/(c3*l3), 0, 0, 0, (d2*g*m23)/(c2*l2) - 
       (d3*g*m3)/(c3*l3), 0, -((g*m3)/(c3*l3)), 0, 0, 0, 
      -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*m23)/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*m23*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*m23*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*m23)/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/
        l2^2 - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m23)/(c2*l2) + (g*m3)/(c3*l3) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*m23*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*m23*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*m23*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*m23*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d2*g*m23)/(c2*l2)) + 
       (d3*g*m3)/(c3*l3) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        l2^2 - (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*m23)/(c2*l2) + (c2*g*m23)/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*m23*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*m23*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m23)/(c2*l2) - (c2*g*m23)/l2 + 
       (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*m23*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + (g*m23*(-2*n2*n3 - 2*si^2))/
        (2*c2*l2), (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*m23*(n2 - n3)*si^2)/
        (2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*m23*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*m23*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*m23*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*m23*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*m23*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m23*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*m23*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0, 0, 
      0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*m23)/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*m23*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*m23*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*m23*si^2)/l2 + (g*m23*(2*d1*d2 - 2*si^2))/
        (2*c2*l2), 0, (d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3), 0, 0, 
      (g*m23*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*m23*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*m23*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*m23*(-n2 + n3)*si^2)/(2*l2^2) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c2^2*kw2*si^2 - (c2*g*m23*si^2)/l2 + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 
      0, (d3*g*m3)/(c3*l3), 0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + 
       (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + 
       (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), -4*c3^2*kw3*sl^2 + 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/(2*c3*l3), 0}, 
     {0, (d2*g*m23)/(c2*l2) - (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        l2^2 + (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*m23*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      -((d2*g*m23)/(c2*l2)) + (d3*g*m3)/(c3*l3) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*m23*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*m23*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/(4*c2*l2) + 
       (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*m23*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/(4*c2*l2) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*m13*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*m13)/(2*c1*l1) + (c1*g*m13)/(2*l1), 0, 0, 
      (g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - (g*m13*(-n0 + n1))/
        (2*l1^2), -(c1^2*kw1) - (g*m13)/(2*c1*l1) + (c1*g*m13)/(2*l1), 0, 0, 
      -(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*m23*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*m23)/(4*c2*l2) - 
       (c2*g*m23)/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*m23*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + 
       (c2*g*m23*si)/(4*l2), (g*m23*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      (g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 0}, 
     {0, -((c2*kw2*(n2 - n3))/l2) + (g*m23*(n2 - n3))/(4*l2^2), 
      c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*m23*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      (g*m23*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*m23*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*m23*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*m23*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 
      (g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*m23*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 0}, 
     {0, -((c2*kw2*(-n2 + n3))/l2) + (g*m23*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 
      (g*m23*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      -(g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 
      0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*m23*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*m23)/(4*c2*l2) - (c2*g*m23)/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*m23*si)/(4*c2*l2) - (c2*g*m23*si)/(4*l2), 
      (g*m23*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*m23*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*m23*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*m23)/(4*c2*l2) + (c2*g*m23)/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*m23*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*m23*si)/(4*c2*l2) + (c2*g*m23*si)/(4*l2), 
      -(g*m23*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*m23*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 
      0, 0, 0}}
 
am = {{((g*m13)/(c1*l1) + (g*m23)/(c2*l2))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2)))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((-(I1x*I1z) + I1zx^2)*((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2)))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2)))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*m23)/(c2*l2*m2)), 0, 0, -((d2*g*(I2x*I2yz - I2xy*I2zx)*m23)/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), (d2*g*(I2x*I2z - I2zx^2)*m23)/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2), -((d2*g*(I2xy*I2z - I2yz*I2zx)*m23)/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), 0, 0, 0, 0, 0, 0}, 
     {0, ((g*m13)/(c1*l1) + (g*m23)/(c2*l2) + (2*kw1*(n0 - n1)^2)/l1^2 - 
        (g*m13*(n0 - n1)^2)/(c1*l1^3) - (c1*(-2*c1*kw1*l1 + g*m13)^2*
          (n0 - n1)^2)/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
           c1^2*g*m13)) + (4*kw2*(n2 - n3)^2)/l2^2 - (g*m23*(n2 - n3)^2)/
         (c2*l2^3) - (c2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)))/m1, 0, 
      ((-(I1xy*I1yz) + I1y*I1zx)*((-4*d0*g*m13)/(c1*l1) + 
         (4*d1*g*m23)/(c2*l2) + (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          l1^2 - (4*g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) + (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/
          l2^2 - (4*g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1xy*I1z - I1yz*I1zx)*((-4*d0*g*m13)/(c1*l1) + (4*d1*g*m23)/(c2*l2) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) + (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/
          l2^2 - (4*g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1yz^2 - I1y*I1z)*((-4*d0*g*m13)/(c1*l1) + (4*d1*g*m23)/(c2*l2) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) + (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/
          l2^2 - (4*g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 0, 
      (-4*c2^3*g*kw2*l2^3*m23 + g^2*m23^2*(-l2^2 + (n2 - n3)^2) - 
        4*c2*g*l2*m23*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d2*g^2*m23^2*(-l2^2 + (n2 - n3)^2) - 
         4*c2*d2*g*l2*m23*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         4*c2^3*kw2*l2^3*(d2*g*m23 + 4*kblz*n3*(-n2 + n3)) + 
         c2^2*l2^2*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*kblz*m23*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2xy*I2z - I2yz*I2zx)*
        (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*m23 + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2yz^2 - I2y*I2z)*
        (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*m23 + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, 0, 0, 0, 0, 0}, 
     {0, 0, (2*c1^2*kw1 + 4*c2^2*kw2 + (g*m13)/(c1*l1) - (c1*g*m13)/l1 - 
        (2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)^2/(c1*l1*(2*c1*kbuz*l1 + 
           2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + (g*m23)/(c2*l2) - 
        (c2*g*m23)/l2 - (4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)))/m1, 0, 
      0, 0, 0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, 0, 0, ((I1xy^2 - I1x*I1y)*
        (4*c2^4*g*kw2*l2^4*m13*n0*n1 + c2^3*g*l2^3*m23*(-(g*m13*n0*n1) + 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*m23^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*m13*n0*n1 - 16*c1*kblz*kw2*l1*(n2 - n3)^2*
            si^2 + c1*g^2*l1*m23^2*(n2*n3 + si^2)) + 
         c2*g*l2*m23*(g*l2^2*m13*n0*n1 + 4*c1*l1*(kw2*(n2 - n3)^2*si^2 + 
             kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2))))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I1x*I1yz - I1xy*I1zx)*(4*c2^4*g*kw2*l2^4*m13*n0*n1 + 
         c2^3*g*l2^3*m23*(-(g*m13*n0*n1) + 4*c1*kw2*l1*(n2*n3 + si^2)) + 
         c1*g^2*l1*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*m13*n0*n1 - 16*c1*kblz*kw2*l1*(n2 - n3)^2*
            si^2 + c1*g^2*l1*m23^2*(n2*n3 + si^2)) + 
         c2*g*l2*m23*(g*l2^2*m13*n0*n1 + 4*c1*l1*(kw2*(n2 - n3)^2*si^2 + 
             kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2))))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1xy*I1yz - I1y*I1zx)*
         (4*c2^4*g*kw2*l2^4*m13*n0*n1 + c2^3*g*l2^3*m23*(-(g*m13*n0*n1) + 
            4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*m23^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-4*g*kblz*l2^2*m13*n0*n1 - 16*c1*kblz*kw2*l1*(n2 - n3)^2*
             si^2 + c1*g^2*l1*m23^2*(n2*n3 + si^2)) + c2*g*l2*m23*
           (g*l2^2*m13*n0*n1 + 4*c1*l1*(kw2*(n2 - n3)^2*si^2 + 
              kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2))))))/
        (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + 
          g^2*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2yz - I2y*I2zx)*
        (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, 0, 0, 0, 0, 0}, 
     {((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(c1*d1^2*g^2*l1*m23^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*m13 + 4*c1*d0*kblz*l1*l2^2*m13 + 
           c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 4*c2^4*kw2*l2^2*
          (d0^2*g*m13 + c1*d0*g*l1*m13 + c1*l1*(d1*g*m23 + 4*kblz*si^2)) + 
         c2*g*l2*m23*(d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + d1*g*m23 + 
             4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
           c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1x*I1z - I1zx^2)*(c1*d1^2*g^2*l1*m23^2 + 
          c2^2*g*(4*d0^2*kblz*l2^2*m13 + 4*c1*d0*kblz*l1*l2^2*m13 + 
            c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 4*c2^4*kw2*l2^2*
           (d0^2*g*m13 + c1*d0*g*l1*m13 + c1*l1*(d1*g*m23 + 4*kblz*si^2)) + 
          c2*g*l2*m23*(d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + 
              d1*g*m23 + 4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
            c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2))))/
        (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I1xy*I1z - I1yz*I1zx)*(c1*d1^2*g^2*l1*m23^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*m13 + 4*c1*d0*kblz*l1*l2^2*m13 + 
           c1*d1*l1*m23*(4*kblz*l2^2 - d1*g*m23)) + 4*c2^4*kw2*l2^2*
          (d0^2*g*m13 + c1*d0*g*l1*m13 + c1*l1*(d1*g*m23 + 4*kblz*si^2)) + 
         c2*g*l2*m23*(d0^2*g*m13 + c1*l1*(4*d1^2*kblz + d0*g*m13 + d1*g*m23 + 
             4*kblz*si^2)) - c2^3*g*l2*m23*(d0^2*g*m13 + 
           c1*l1*(-4*d1^2*kw2 + d0*g*m13 + d1*g*m23 + 4*kblz*si^2))))/
       (c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), (d1*g*m23)/(c2*l2*m2), 0, 0, 
      -(((I2x*I2yz - I2xy*I2zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2x*I2z - I2zx^2)*(-(d1*d2*g^2*m23^2) + 
         c2^2*d1*d2*g^2*m23^2 + 16*c2^4*kblz*kw2*l2^2*si^2 + 
         4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 4*c2^3*g*l2*m23*
          (d1*d2*kw2 + kblz*si^2)))/(c2*(I2xy^2*I2z + 
         I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      -(((I2xy*I2z - I2yz*I2zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, 0, 0, 0, 0, 0}, 
     {0, -(((d0*g*m13)/(c1*l1) - (d1*g*m23)/(c2*l2) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*m13*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*(c1*d0*g*m13*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - 
            c1^2*g*m13)) - (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*m23)*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + g*l2*m23*n3 + 
            c2*d1*g*m23*(-n2 + n3)))/(l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*m23 - c2^2*g*m23)))/m1), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((g*m13*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*m13*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2/
          (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) + 
         (g*m23*(d1^2 + c2*d1*l2 + n2*n3))/(c2*l2) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*((g*m13*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*m13*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2/
          (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) + 
         (g*m23*(d1^2 + c2*d1*l2 + n2*n3))/(c2*l2) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1yz^2 - I1y*I1z)*((g*m13*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*m13*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*m13*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + g*l1*m13*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1))^2/
          (c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*m23*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) + 
         (g*m23*(d1^2 + c2*d1*l2 + n2*n3))/(c2*l2) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*m23*n2) + 4*d1*kw2*(n2 - n3)) + 
            g*l2*m23*n3 + c2*d1*g*m23*(-n2 + n3))^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))))/
       (I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      0, (-4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
        d1*g^2*m23^2*(-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*m23*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*m23*(n2 - n3)*
           (kblz*n2 + kw2*(-n2 + n3))))/(c2*l2^3*m2*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
         c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
             kw2*(n2 - n3)^2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I2xy*I2z - I2yz*I2zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      -(((I2yz^2 - I2y*I2z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^
                2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 0, 0, 0, 0, 
      0, 0}, {-((g*m23)/(c2*l2*m1)), 0, 0, (d1*g*(I1x*I1yz - I1xy*I1zx)*m23)/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(-(I1x*I1z) + I1zx^2)*m23)/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(I1xy*I1z - I1yz*I1zx)*m23)/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), ((g*m23)/(c2*l2) + (g*m3)/(c3*l3))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      ((-(I2x*I2z) + I2zx^2)*((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      ((I2xy*I2z - I2yz*I2zx)*((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      -(g/(c3*l3)), 0, 0, -((d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), (d4*g*(I3x*I3z - I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -((d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3))}, {0, (-4*c2^3*g*kw2*l2^3*m23 + 
        g^2*m23^2*(-l2^2 + (n2 - n3)^2) - 4*c2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I1xy*I1yz - I1y*I1zx)*(4*c2^3*kw2*l2^3*(d1*g*m23 + 
           4*kblz*n2*(n2 - n3)) + d1*g^2*m23^2*(l2^2 - (n2 - n3)^2) - 
         c2*g*l2*m23*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*m23*(n2 - n3)^2) + c2^2*l2^2*
          (d1*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) - 4*g*m23*(n2 - n3)*
            (kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1xy*I1z - I1yz*I1zx)*
         (4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*m23^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*m23*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*m23*(n2 - n3)^2) + c2^2*l2^2*
           (d1*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) - 4*g*m23*(n2 - n3)*
             (kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), -(((I1yz^2 - I1y*I1z)*
         (4*c2^3*kw2*l2^3*(d1*g*m23 + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*m23^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*m23*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*m23*(n2 - n3)^2) + c2^2*l2^2*
           (d1*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) - 4*g*m23*(n2 - n3)*
             (kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, ((2*g*m23)/(c2*l2) + (2*g*m3)/(c3*l3) + 
        (8*kw2*(n2 - n3)^2)/l2^2 - (2*g*m23*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*m23)^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + 
        (8*kw3*(n4 - n5)^2)/l3^2 - (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*d2*g^2*l3^3*m23^2*(-l2^2 + (n2 - n3)^2) + 
          c2*g*l2*m23*(c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
                kw2*(n2 - n3)^2) + l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*(
                n4 - n5)) + d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3^2*kw3*l2^2*l3^2*n4*(n4 - n5)) + 4*c2^4*kw2*l2^4*
           (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
            c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) + 
          c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*
             m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
              16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*(g*m3*n4 + 
                4*d3*kw3*(-n4 + n5)))) + c2^2*l2^2*
           (4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*
             l3^2*n4*(n4 - n5) + c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*
                 (n2 - n3)^2) + 4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + 
                g*(l3^2*m23*n3*(-n2 + n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*d2*g^2*l3^3*m23^2*(-l2^2 + (n2 - n3)^2) + 
         c2*g*l2*m23*(c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*
                (n2 - n3)^2) + l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*
              (n4 - n5)) + d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(n4 - n5)) + 4*c2^4*kw2*l2^4*
          (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
           c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) + 
         c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*
            m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
             16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*(g*m3*n4 + 4*d3*
                kw3*(-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
            (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2yz^2 - I2y*I2z)*(c3*d2*g^2*l3^3*m23^2*
          (-l2^2 + (n2 - n3)^2) + c2*g*l2*m23*
          (c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*(n4 - n5)) + 
           d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 4*c3^2*kw3*l2^2*l3^2*n4*
            (n4 - n5)) + 4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
            (n4 - n5)) + c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
             16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*(g*m3*n4 + 4*d3*
                kw3*(-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
            (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                 l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 
        4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, 
     {0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))/
       (m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 0, 0, 0, 
      0, (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m23)/(c2*l2) - (c2*g*m23)/l2 - 
        (4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)^2/(c2*l2*(4*c2*kblz*l2 + 
           4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)) + (g*m3)/(c3*l3) - 
        (c3*g*m3)/l3)/m2, 0, 0, 0, 0, 0, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3, 0, 0, 0}, {0, 0, 0, 
      -(((I1xy^2 - I1x*I1y)*(4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + 
          g^2*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), -(((I1x*I1yz - I1xy*I1zx)*
         (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*g*kw2*l2^3*m23*(n2*n3 + si^2) + g^2*m23^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*m23^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*m23*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, 0, 0, ((I2xy^2 - I2x*I2y)*
        (c3*g^2*l3^3*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
         c2^3*g*l2^3*m23*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
             kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
             l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
          (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2*g*l2*m23*
          (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*
              (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2^2*l2^2*
          (4*g*kblz*l2^2*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) - 
           c3*l3*(g^2*l3^2*m23^2*(n2*n3 + si^2) - 16*kblz*(kw2*l3^2*
                (n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2x*I2yz - I2xy*I2zx)*
        (c3*g^2*l3^3*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
         c2^3*g*l2^3*m23*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
             kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
             l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
          (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2*g*l2*m23*
          (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*
              (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) + c2^2*l2^2*
          (4*g*kblz*l2^2*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) - 
           c3*l3*(g^2*l3^2*m23^2*(n2*n3 + si^2) - 16*kblz*(kw2*l3^2*
                (n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I2xy*I2yz - I2y*I2zx)*
         (c3*g^2*l3^3*m23^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
          c2^3*g*l2^3*m23*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
              kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
              l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
           (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2*g*l2*m23*
           (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*(
                -((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
              kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2^2*l2^2*(4*g*kblz*l2^2*m3*
             (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) - 
            c3*l3*(g^2*l3^2*m23^2*(n2*n3 + si^2) - 16*kblz*(kw2*l3^2*
                 (n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), 0, 0, 0, 
      -(((I3xy^2 - I3x*I3y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), -(((I3x*I3yz - I3xy*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3)), 
      ((I3xy*I3yz - I3y*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {-((d2*g*m23)/(c2*l2*m1)), 0, 0, 
      -(((I1x*I1yz - I1xy*I1zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I1x*I1z - I1zx^2)*(-(d1*d2*g^2*m23^2) + 
         c2^2*d1*d2*g^2*m23^2 + 16*c2^4*kblz*kw2*l2^2*si^2 + 
         4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 4*c2^3*g*l2*m23*
          (d1*d2*kw2 + kblz*si^2)))/(c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 
      -(((I1xy*I1z - I1yz*I1zx)*(-(d1*d2*g^2*m23^2) + c2^2*d1*d2*g^2*m23^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*m23*(-(d1*d2) + si^2) - 
          4*c2^3*g*l2*m23*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((d2*g*m23)/(c2*l2) - (d3*g*m3)/(c3*l3))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(c3*d2^2*g^2*l3*m23^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - 
           c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + c2*g*l2*m23*
          (c3*l3*(4*d2^2*kblz + d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) - 
         c2^3*g*l2*m23*(c3*l3*(-4*d2^2*kw2 + d2*g*m23 + d3*g*m3 + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) + c2^2*(c3*g*l3*(4*d2*kblz*l2^2*m23 - 
             d2^2*g*m23^2 + 4*d3*kblz*l2^2*m3) + 16*c3^3*kblz*kw3*l2^2*l3*
            sl^2 - 4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*
            (d3^2 + sl^2))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*m23 - c2^2*g*m23)), -(((I2x*I2z - I2zx^2)*(c3*d2^2*g^2*l3*m23^2 + 
          4*c2^4*kw2*l2^2*(c3*l3*(d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*m23*(c3*l3*(4*d2^2*kblz + d2*g*m23 + d3*g*m3 + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*m23*
           (c3*l3*(-4*d2^2*kw2 + d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(c3*g*l3*(4*d2*kblz*l2^2*m23 - d2^2*g*m23^2 + 4*d3*kblz*l2^
                2*m3) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 4*c3^2*g*kblz*l2^2*m3*
             sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2z - I2yz*I2zx)*(c3*d2^2*g^2*l3*m23^2 + 
         4*c2^4*kw2*l2^2*(c3*l3*(d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*m23*(c3*l3*(4*d2^2*kblz + d2*g*m23 + d3*g*m3 + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*m23*
          (c3*l3*(-4*d2^2*kw2 + d2*g*m23 + d3*g*m3 + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(c3*g*l3*(4*d2*kblz*l2^2*m23 - d2^2*g*m23^2 + 
             4*d3*kblz*l2^2*m3) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), (d3*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3x*I3z - I3zx^2)*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3xy*I3z - I3yz*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, 
     {0, (d2*g^2*m23^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*m23*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(d2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*kblz*m23*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*m23 + 4*kblz*n3*(-n2 + n3)))/(c2*l2^3*m1*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      ((I1xy*I1yz - I1y*I1zx)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
         c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
             kw2*(n2 - n3)^2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
         g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*
              (-n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 
             4*d2*(kblz*n2 - kw2*n2 + kw2*n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), -(((I1xy*I1z - I1yz*I1zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*m23*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 
      -(((I1yz^2 - I1y*I1z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*m23*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^
                2) + d2*g*m23*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) + 
          g^2*m23^2*(d1*d2*(-l2^2 + (n2 - n3)^2) + l2^2*(n2 - n3)*n3) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*m23*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*m23 + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 4*g*kblz*m23*n3*(
                -n2 + n3)) + g*m23*(n2 - n3)*(-(g*m23*n3) + 4*d2*(kblz*n2 - 
                kw2*n2 + kw2*n3)))))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23))), 0, 
      (c3*d2*g^2*l3^3*m23^2*(-l2^2 + (n2 - n3)^2) + 
        c2*g*l2*m23*(c3*l3*(-4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + l2^2*(-(g*m3*n4) + 4*d3*kw3*(n4 - n5))*
             (n4 - n5)) + d3*g*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
          4*c3^2*kw3*l2^2*l3^2*n4*(n4 - n5)) + 4*c2^4*kw2*l2^4*
         (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
          c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) + 
        c2^3*l2^3*(d3*g^2*m23*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*
           m23*n4*(-n4 + n5) - c3*l3*(4*d2*g*kw2*l3^2*m23 - 
            16*kblz*kw2*l3^2*(n2 - n3)*n3 - g*m23*(n4 - n5)*
             (g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
        c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
          16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
          c3*l3*(d2*l3^2*(g^2*m23^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(l3^2*m23*n3*(-n2 + n3) + 
                l2^2*m3*n4*(-n4 + n5))))))/(c2*c3*l2^3*l3^3*m2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - c2^2*g*m23)), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*m23^2*
           (d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
          4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
            g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l3^2*m23 + 4*kblz*l3^2*n3^2 + 4*d3^2*kw3*(n4 - n5)^
                2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(d2^2*l3^2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
              g^2*l3^2*m23^2*n3*(-n2 + n3) + 4*d2*g*kblz*l3^2*m23*(l2^2 + 
                2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
              4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2*g*l2*m23*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l2^2*l3^2*m23 + 4*d2^2*l3^2*(kblz*(l2^2 - (n2 - n3)^
                   2) + kw2*(n2 - n3)^2) + l2^2*(4*kblz*l3^2*n2*n3 + 
                4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + 
                    n5))))) - c2^3*l2^3*(4*c3^3*g*kw3*l3^3*m23*n4^2 + 
            g^2*m23*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 
            c3^2*g*l3^2*m23*n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-4*d2^2*g*kw2*l3^2*m23 + d2*l3^2*(g^2*m23^2 + 
                32*kblz*kw2*(n2 - n3)*n3) + g*m23*(4*l3^2*n3*(kblz*n3 + 
                  kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                 (l3^2 + 2*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
          c2^2*g*m23))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*g^2*l3^3*m23^2*(d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
         4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*m23 + 4*kblz*l3^2*n3^2 + 4*d3^2*kw3*(n4 - n5)^2 + 
             d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(d2^2*l3^2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
             g^2*l3^2*m23^2*n3*(-n2 + n3) + 4*d2*g*kblz*l3^2*m23*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*m23*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*m23 + 4*d2^2*l3^2*(kblz*(l2^2 - (n2 - n3)^
                  2) + kw2*(n2 - n3)^2) + l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*
                kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
         c2^3*l2^3*(4*c3^3*g*kw3*l3^3*m23*n4^2 + g^2*m23*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*m23*n4*
            (g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + c3*l3*(-4*d2^2*g*kw2*l3^2*m23 + 
             d2*l3^2*(g^2*m23^2 + 32*kblz*kw2*(n2 - n3)*n3) + 
             g*m23*(4*l3^2*n3*(kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*
                (n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), ((I2yz^2 - I2y*I2z)*
        (c3*g^2*l3^3*m23^2*(d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
         4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*m23 + 4*kblz*l3^2*n3^2 + 4*d3^2*kw3*(n4 - n5)^2 + 
             d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(d2^2*l3^2*(-(g^2*m23^2) + 16*kblz*kw2*(n2 - n3)^2) + 
             g^2*l3^2*m23^2*n3*(-n2 + n3) + 4*d2*g*kblz*l3^2*m23*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*m23*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*m23 + 4*d2^2*l3^2*(kblz*(l2^2 - (n2 - n3)^
                  2) + kw2*(n2 - n3)^2) + l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*
                kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
         c2^3*l2^3*(4*c3^3*g*kw3*l3^3*m23*n4^2 + g^2*m23*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*m23*n4*
            (g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + c3*l3*(-4*d2^2*g*kw2*l3^2*m23 + 
             d2*l3^2*(g^2*m23^2 + 32*kblz*kw2*(n2 - n3)*n3) + 
             g*m23*(4*l3^2*n3*(kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*
                (n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*m23 - 
         c2^2*g*m23)), 0, (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3*m3), 0, ((I3xy*I3yz - I3y*I3zx)*
        (d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + g*l3*m3*n5 - 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 0, 
      (d3*g*(I2x*I2yz - I2xy*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(-(I2x*I2z) + I2zx^2)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(I2xy*I2z - I2yz*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), g/(c3*l3), 0, 0, (d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(-(I3x*I3z) + I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
          (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3), 
      -(((I2xy*I2z - I2yz*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      -(((I2yz^2 - I2y*I2z)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 0, 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, 0, 0, 
      (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 0, 0, 0, 0, 0, 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l3^3)), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      ((I2xy*I2yz - I2y*I2zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 0, 0, ((I3xy^2 - I3x*I3y)*
        (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
           l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3), 
      ((I3x*I3yz - I3xy*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), -(((I3xy*I3yz - I3y*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3))}, {0, 0, 0, 0, 0, 0, 
      -((d4*g*m3)/(c3*l3*m2)), 0, 0, ((I2x*I2yz - I2xy*I2zx)*
        (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2x*I2z - I2zx^2)*(-(d3*d4*g*m3) + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2xy*I2z - I2yz*I2zx)*(d3*d4*g*m3 + 
         (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d4*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -(((I3x*I3z - I3zx^2)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
          (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2xy*I2z - I2yz*I2zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2yz^2 - I2y*I2z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 0, 
      -(((I3xy*I3yz - I3y*I3zx)*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
            g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}}
 
cxsm = {{-((g*m13)/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3), 
      0, 0, 0, -(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2)}, 
     {0, 0, (-2*c1^3*kw1*l1 - g*m13 + c1^2*g*m13)/(c1*l1), 0, 0, 0}, 
     {0, 0, 0, -((g*m13*n0*n1)/(c1*l1)), 0, 0}, {-((d0*g*m13)/(c1*l1)), 0, 0, 
      0, 0, 0}, {0, (d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/
       (c1*l1^3), 0, 0, 0, (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
         c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + g*m13*n1)))/
       (c1*l1^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bm = {{-((g*m13)/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, ((g*m13*(-l1^2 + (n0 - n1)^2) - 2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3) + 
        ((2*c1*kw1*l1 - g*m13)*((c1*kw1*(n0 - n1))/l1 - (g*m13*(n0 - n1))/
            (2*l1^2))*(n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))) - 
        ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*m13*(-n0 + n1))/(2*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((c1*kw1*(n0 - n1))/l1 - 
            (g*m13*(n0 - n1))/(2*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*m13*(-n0 + n1))/(2*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*m13)*n0*(n0 - n1))/l1^2) + 
        (((c1*kw1*(n0 - n1))/l1 - (g*m13*(n0 - n1))/(2*l1^2))*
          (2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
           (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
           g*m13*n1)*((c1*kw1*(-n0 + n1))/l1 - (g*m13*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/
       m1}, {0, 0, ((-2*c1^3*kw1*l1 - g*m13 + c1^2*g*m13)/(c1*l1) - 
        ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*(-(c1^2*kw1) - 
           (g*m13)/(2*c1*l1) + (c1*g*m13)/(2*l1)))/
         (c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - (c1*g*m13)/(2*l1))))/
       m1, 0, 0, 0}, {-((d0*g*(I1x*I1yz - I1xy*I1zx)*m13)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((-(I1xy*I1yz) + I1y*I1zx)*
        ((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
           c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*((g*m13*n1)/(2*c1*l1) + 
            (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
            (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((g*m13*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), -((g*(I1xy^2 - I1x*I1y)*m13*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        (((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) + (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
            c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(c1*l1^2) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
            g*m13*n1)*(-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2)}, 
     {-((d0*g*(-(I1x*I1z) + I1zx^2)*m13)/(c1*(I1x*I1yz^2 + I1xy^2*I1z - 
          I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1)), 
      ((I1xy*I1z - I1yz*I1zx)*
        ((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2) - 
           c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*n1)/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*((g*m13*n1)/(2*c1*l1) + 
            (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
            (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        (-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*((g*m13*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(I1x*I1yz - I1xy*I1zx)*m13*n0*n1)/(c1*(I1x*I1yz^2 + I1xy^2*I1z - 
          I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1)), 0, 
      ((I1xy*I1z - I1yz*I1zx)*(((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) + (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
            c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(c1*l1^2) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
            g*m13*n1)*(-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2)}, 
     {-((d0*g*(I1xy*I1z - I1yz*I1zx)*m13)/(c1*(I1x*I1yz^2 + I1xy^2*I1z - 
          I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1)), 
      ((I1yz^2 - I1y*I1z)*((d0*(g*m13*(l1^2 - (n0 - n1)^2) + 
             2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*m13)*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1*kw1*l1 - g*m13)*(n0 - n1)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*l1^2*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1yz^2 - I1y*I1z)*(-((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
            ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
              (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) - ((2*c1^3*kw1*l1 + g*m13 - c1^2*g*m13)*
           (-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(-(I1xy*I1yz) + I1y*I1zx)*m13*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1yz^2 - I1y*I1z)*
        (((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + g*m13*n1)*
           ((g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
             (2*l1) - (g*m13*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1))) + (n0*(-2*c1^3*kw1*l1^2*n1 - g*l1*m13*n1 + 
            c1*d0*g*m13*(-n0 + n1) + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*m13*n1)))/(c1*l1^2) - ((2*c1^3*kw1*l1*n0 - c1^2*g*m13*n0 + 
            g*m13*n1)*(-(g*m13*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*m13*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
             (4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*m13)/(2*c1*l1) - 
            (c1*g*m13)/(2*l1)))))/(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 
        2*I1xy*I1yz*I1zx + I1y*I1zx^2)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
stage2fudge = {flex1 -> 2*c1^(3/2)*Sqrt[(M11*Y1)/(g*(m1 + m2 + m3))], 
     flex2 -> 2*c2^(3/2)*Sqrt[(M21*Y2)/(g*(m2 + m3))], 
     flex3 -> 2*c3^(3/2)*Sqrt[(M31*Y3)/(g*m3)], d0 -> d0 + flex1, 
     d1 -> d1 + flex2, d2 -> d2 + flex2, d3 -> d3 + flex3, d4 -> d4 + flex3, 
     l1 -> (-2*flex1)/c1 + l1, l2 -> (-2*flex2)/c2 + l2, 
     l3 -> (-2*flex3)/c3 + l3, n0 -> n0 + (flex1*si1)/c1, 
     n1 -> n1 - (flex1*si1)/c1, n2 -> n2 + (flex2*si2)/c2, 
     n3 -> n3 - (flex2*si2)/c2, n4 -> n4 + (flex3*si3)/c3, 
     n5 -> n5 - (flex3*si3)/c3}
 
g /: g::usage = "g is local gravity."
 
M11 /: M11::usage = "M11 is the moment of area of wires from blades on \
structure to top mass in direction \"1\"."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
Y1 /: Y1::usage = 
     "Y1 is Young's modulus of wires from blades on structure to top mass."
 
M21 /: M21::usage = "M21 is the moment of area of wires from blades on top \
mass to intermediate mass in direction \"1\""
 
Y2 /: Y2::usage = "Y2 is Young's modulus of wires from blades on top mass to \
intermediate mass."
 
M31 /: M31::usage = "M31 is the moment of area of wires (fibres) from \
intermediate mass to optic in direction \"1\""
 
Y3 /: Y3::usage = 
     "Y3 is Young's modulus of wires (fibres) from intermediate mass to \
optic."
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
qm = {{kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0, 0}, 
     {0, kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0}, 
     {0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0, 0}, 
     {0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0}, {0, 0, 0, 0, 
      kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      0}, {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2)}}
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmlp = {{I1y, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0}, {0, 0, I2y, 0, 0, 0}, 
     {0, 0, 0, m2, 0, 0}, {0, 0, 0, 0, I3y, 0}, {0, 0, 0, 0, 0, m3}}
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
xmlp = {{(g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), (d1*g*(m2 + m3))/(c2*l2), 
      0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 
      -((d2*g*(m2 + m3))/(c2*l2)), -((g*(m2 + m3))/(c2*l2)), 0, 0}, 
     {-4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      -((d2*g*(m2 + m3))/(c2*l2)), 4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), (d3*g*m3)/(c3*l3)}, {(d1*g*(m2 + m3))/(c2*l2), 
      -((g*(m2 + m3))/(c2*l2)), -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 
      -((d4*g*m3)/(c3*l3)), -((g*m3)/(c3*l3))}, 
     {0, 0, -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), -((d4*g*m3)/(c3*l3)), 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 
      (d4*g*m3)/(c3*l3)}, {0, 0, (d3*g*m3)/(c3*l3), -((g*m3)/(c3*l3)), 
      (d4*g*m3)/(c3*l3), (g*m3)/(c3*l3)}}
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {-(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0, 0}, 
     {c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0, 0}, 
     {-(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0, 0}, 
     {c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0, 0}}
 
amlp = {{((2*d0*g*(d0 + c1*l1)*(m1 + m2 + m3))/(c1*l1) + 8*c2^2*kw2*si^2 - 
        (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d1^2 + c2*d1*l2 + si^2))/
         (c2*l2))/(2*I1y), (-((d1*g*(m2 + m3))/(c2*l2)) + 
        (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 
      (d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
        16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
         (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
       (c2*I2y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (d1*g*(m2 + m3))/(c2*l2*m2), 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/I1y, 
      ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 
      -((d2*g*(m2 + m3))/(c2*I2y*l2)), -((g*(m2 + m3))/(c2*l2*m2)), 0, 0}, 
     {(d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
        16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
         (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
       (c2*I1y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -((d2*g*(m2 + m3))/(c2*l2*m1)), 
      (8*c2^2*kw2*si^2 - (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d2^2 + c2*d2*l2 + si^2))/
         (c2*l2) + 8*c3^2*kw3*sl^2 - (2*c3*g*m3*sl^2)/l3 + 
        (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/(2*I2y), 
      (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/m2, 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I3y*l3), 
      (d3*g)/(c3*l3)}, {(d1*g*(m2 + m3))/(c2*I1y*l2), 
      -((g*(m2 + m3))/(c2*l2*m1)), (-((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2))/I2y, 
      ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/m2, -((d4*g*m3)/(c3*I3y*l3)), 
      -(g/(c3*l3))}, {0, 0, (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*
         sl^2)/(c3*I2y*l3), -((d4*g*m3)/(c3*l3*m2)), 
      (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/
       (c3*I3y*l3), (d4*g)/(c3*l3)}, {0, 0, (d3*g*m3)/(c3*I2y*l3), 
      -((g*m3)/(c3*l3*m2)), (d4*g*m3)/(c3*I3y*l3), g/(c3*l3)}}
 
cxsmlp = {{-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmlp = {{-((d0*g*(m1 + m2 + m3))/(c1*I1y*l1)), 0, 0, 0, 0, 0}, 
     {-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmtr = {{I1x, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0}, {0, 0, I2x, 0, 0, 0}, 
     {0, 0, 0, m2, 0, 0}, {0, 0, 0, 0, I3x, 0}, {0, 0, 0, 0, 0, m3}}
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmtr = {{(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
         (-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*(m2 + m3)*
         (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*d0*l1*l2^2*
           (4*c1*kw1*l1*n1*(-n0 + n1) + g*(m1 + m2 + m3)*
             (l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*
         (n2 - n3))/(c2*l2^3), 0, 0}, 
     {(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), 
      (c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 
      -((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2)/
        (c2*l2^3)), 0, 0}, 
     {(d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
         (n2 - n3)*n3)/(c2*l2^3), (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + 
        c2*c3^2*l2^3*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
        c2*g*l2^3*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
           (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 
              2*(n2 - n3)*n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3)}, 
     {(d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      -((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2)/
        (c2*l2^3)), (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
        4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
        c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3)}, 
     {0, 0, (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3)}, {0, 0, (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3), (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3)}}
 
cqxmtr = {{(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
        g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
          g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 
      ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 0, 0, 0, 0}, 
     {-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
         g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 
      -((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 0, 0, 0, 0}, 
     {(-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 
      ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*
        (n2 - n3))/(4*l2^2), -(c2*d2*g*(m2 + m3)*(n2 - n3) + 
         4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
         c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 0, 0}, 
     {(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*
        (n2 - n3))/(4*l2^2), -(c2*d2*g*(m2 + m3)*(n2 - n3) + 
         4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
         c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 0, 0}}
 
amtr = {{((-8*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2)/(c1*l1^3*(2*c1*kbuz*l1 + 
           2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
        (8*(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
              4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
            g*l2*(m2 + m3)*n3)^2)/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (8*(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
            (-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*(m2 + m3)*
            (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
           c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*
                l1*(n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + 
               g*(m1 + m2 + m3)*(l1^2 + 2*(n0 - n1)*n1)) + 
             l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 2*c1^3*kw1*l1*l2^2*n1^2 - 
               c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + c1*d1*l1*
                (4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 2*n2*(-n2 + 
                     n3)))))))/(c1*c2*l1^3*l2^3))/(8*I1x), 
      ((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*m1), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        ((4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*I2x*l2^3), (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*
         (n2 - n3) + (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*l2^3*m2), 0, 0}, 
     {((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*I1x), 
      (-((c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
          (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
            c1^2*g*(m1 + m2 + m3)))) + 
        (c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
          c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 
      (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3 + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*I2x*l2^3), 
      ((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2))/
         c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (4*l2^4*m2), 0, 0}, 
     {(d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        ((4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*I1x*l2^3), (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
         (n2 - n3)*n3 + (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*l2^3*m1), 
      (-((c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + 
          c2*c3^2*l2^3*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
          c2*g*l2^3*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
          c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
              4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
             (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 2*(n2 - n3)*
                 n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 4*c2^3*kw2*l2*l3^2*n3^
                2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + c2*d3*l2*(4*d3*kw3*
                 (n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + n5))))))/(c3*l3^3))/
       (c2*I2x*l2^3), ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*l2^4*m2), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I3x*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3)}, 
     {(d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*I1x*l2^3), ((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
           4*c2*kw2*l2*(n2 - n3)^2))/c2 + 
        (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (4*l2^4*m1), ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*I2x*l2^4), 
      (-((c2^2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
          (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
          c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c3*l3^3))/(c2*l2^3*m2), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3)}, 
     {0, 0, (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I2x*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*I3x*l3^3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3*m3)}, {0, 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*I2x*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3)}}
 
cxsmtr = {{0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
         (n0 - n1)*n1)/(c1*l1^3), 0, 0, 0, 
      (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
         g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmtr = {{0, ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
           (n0 - n1)*n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(2*c1*l1^4*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       I1x, 0, 0, 0, (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*(m1 + m2 + m3)*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/
         (4*c1^2*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(4*c1^2*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
           g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(c1*l1^2))/I1x}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (2*l1^4*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*(-2*c1^3*kw1*l1*n0 + 
           c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*n1))/
         (4*c1*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(4*c1*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}}
 
amy = {{((g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
        (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
        (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2))/I1z, 
      ((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I2z, 0}, {((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - (2*((c2*kw2*(n2 - n3)*si)/l2 - 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I1z, ((2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2))^2/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
        (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I2z, 
      ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3))/I3z}, 
     {0, ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
         (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
        (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
         (2*c3*l3))/I2z, ((2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
        (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/
         l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
        (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I3z}}
 
cxsmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*I1z*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
xm = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      0, 0, 0, 0, 0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
        (2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*(m1 + m2 + m3)*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/
        l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      -((c1*kw1*(n0 - n1))/l1) + (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - 
       (c1*kw1*(-n0 + n1))/l1 + (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + 
       (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 2*c1^2*kw1 + 4*c2^2*kw2 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/
        (c1*l1) - (c1*g*(m1 + m2 + m3))/l1, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, 0, 0, (g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + 
       (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 0, 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/
        l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, 0, 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, 0, 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 
      0, 0, 0, -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 0, 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), -(c1^2*kw1) - 
       (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - 
       (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + 
       (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), c2^2*kw2 + 
       (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}}
 
am = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((-(I1x*I1z) + I1zx^2)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(m2 + m3))/(c2*l2*m2)), 0, 0, 
      -((d2*g*(I2x*I2yz - I2xy*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), (d2*g*(I2x*I2z - I2zx^2)*(m2 + m3))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2), -((d2*g*(I2xy*I2z - I2yz*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), 0, 0, 0, 0, 0, 0}, 
     {0, ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
        (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(c1*l1^3) - 
        (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1xy*I1z - I1yz*I1zx)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1yz^2 - I1y*I1z)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 0, 
      (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
        4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (-(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) - 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2xy*I2z - I2yz*I2zx)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {0, 0, (2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 0, 0, 0, 0, 0, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
      ((I1xy^2 - I1x*I1y)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I1x*I1yz - I1xy*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1xy*I1yz - I1y*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
          c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
            4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
             (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
          c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
                l2^2*(n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      0, 0, 0, -(((I2xy^2 - I2x*I2y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*
           (n2*n3 + si^2) + g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
            l2^2*(n2*n3 + si^2)) - c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + 
            g^2*(m2 + m3)^2*(n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*
           (kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
              l2^2*(n2*n3 + si^2)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      -(((I2x*I2yz - I2xy*I2zx)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2yz - I2y*I2zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1x*I1z - I1zx^2)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
          c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
             (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
              d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
            c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
              4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
          2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1xy*I1z - I1yz*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), (d1*g*(m2 + m3))/(c2*l2*m2), 0, 0, 
      -(((I2x*I2yz - I2xy*I2zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I2x*I2z - I2zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {0, -((-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/m1), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), 0, (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
          4*kblz*n2*(n2 - n3)) - d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
        c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
            kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) + 
        c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I2yz^2 - I2y*I2z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2*m1)), 0, 0, (d1*g*(I1x*I1yz - I1xy*I1zx)*
        (m2 + m3))/(c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2), 
      (d1*g*(-(I1x*I1z) + I1zx^2)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(I1xy*I1z - I1yz*I1zx)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/
          (c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
        I2y*I2zx^2), ((-(I2x*I2z) + I2zx^2)*(-((d3*g*m3)/(c3*l3)) + 
         (d2*g*(m2 + m3))/(c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
        2*I2xy*I2yz*I2zx + I2y*I2zx^2), ((I2xy*I2z - I2yz*I2zx)*
        (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      -(g/(c3*l3)), 0, 0, -((d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), (d4*g*(I3x*I3z - I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -((d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3))}, {0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - 
        g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
           (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
            4*kblz*n2*(n2 - n3)) + d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
          c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) - 
          c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, ((2*g*m3)/(c3*l3) + 
        (2*g*(m2 + m3))/(c2*l2) + (8*kw2*(n2 - n3)^2)/l2^2 - 
        (2*g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
        (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*
            (l2^2 - (n2 - n3)^2)) + 4*c2^4*kw2*l2^4*
           (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
            c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - c2*g*l2*(m2 + m3)*
           (d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*kw3*l2^2*l3^2*n4*
             (-n4 + n5) + c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
                kw2*(n2 - n3)^2) + l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) - c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*
             (l3^2 - (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*
             (n4 - n5) + c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(
                n2 - n3)*n3 - g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
             (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
            c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
              4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                    (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 
        4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3)))/(m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, 0, 0, 0, 0, 0, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3, 0, 0, 0}, {0, 0, 0, 
      -(((I1xy^2 - I1x*I1y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), -(((I1x*I1yz - I1xy*I1zx)*
         (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, ((I2xy^2 - I2x*I2y)*
        (c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I2x*I2yz - I2xy*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
          c2^3*g*l2^3*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
              kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
              l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
           (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2*g*l2*(m2 + m3)*
           (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*(
                -((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
              kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
             (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
            c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 16*kblz*(
                kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 
      -(((I3xy^2 - I3x*I3y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), -(((I3x*I3yz - I3xy*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3)), 
      ((I3xy*I3yz - I3y*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {-((d2*g*(m2 + m3))/(c2*l2*m1)), 0, 0, 
      -(((I1x*I1yz - I1xy*I1zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1x*I1z - I1zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), (-((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
         4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 
      -(((I2x*I2z - I2zx^2)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
          4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
           (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
               d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
            4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (d3*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3x*I3z - I3zx^2)*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3xy*I3z - I3yz*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, 
     {0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
        c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
          4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 
      -((-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2) - 
         (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 + 
         (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*
             (n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) - (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
          l3^2 + (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3))/m2), 
      0, -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
          4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
            g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
              4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
              g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*(
                l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
              4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*(
                kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
              l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
          c2^3*l2^3*(4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
                32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                 (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 0, 
      (d3*g*(I2x*I2yz - I2xy*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(-(I2x*I2z) + I2zx^2)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(I2xy*I2z - I2yz*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), g/(c3*l3), 0, 0, (d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(-(I3x*I3z) + I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
          (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3), 
      -(((I2xy*I2z - I2yz*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      -(((I2yz^2 - I2y*I2z)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 0, 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, 0, 0, 
      (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 0, 0, 0, 0, 0, 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l3^3)), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      ((I2xy*I2yz - I2y*I2zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 0, 0, ((I3xy^2 - I3x*I3y)*
        (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
           l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3), 
      ((I3x*I3yz - I3xy*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), -(((I3xy*I3yz - I3y*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3))}, {0, 0, 0, 0, 0, 0, 
      -((d4*g*m3)/(c3*l3*m2)), 0, 0, ((I2x*I2yz - I2xy*I2zx)*
        (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2x*I2z - I2zx^2)*(-(d3*d4*g*m3) + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2xy*I2z - I2yz*I2zx)*(d3*d4*g*m3 + 
         (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d4*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -(((I3x*I3z - I3zx^2)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
          (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2xy*I2z - I2yz*I2zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2yz^2 - I2y*I2z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 0, 
      -(((I3xy*I3yz - I3y*I3zx)*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
            g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}}
 
cxsm = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, 
     {0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bm = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1}, 
     {0, 0, (-2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
        (c1*g*(m1 + m2 + m3))/l1 - ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))*(-(c1^2*kw1) - (g*(m1 + m2 + m3))/
            (2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1)))/
         (c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
             (2*l1))*(-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
            (2*l1))*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {-((d0*g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((-(I1xy*I1yz) + I1y*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1xy^2 - I1x*I1y)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(-(I1x*I1z) + I1zx^2)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1xy*I1z - I1yz*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1xy*I1z - I1yz*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(I1xy*I1z - I1yz*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1yz^2 - I1y*I1z)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(-(I1xy*I1yz) + I1y*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1yz^2 - I1y*I1z)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
stage2fudge = {d0 -> d0 + flex1, d1 -> d1 + flex2, d2 -> d2 + flex2, 
     d3 -> d3 + flex3, d4 -> d4 + flex3, l1 -> (-2*flex1)/c1 + l1, 
     l2 -> (-2*flex2)/c2 + l2, l3 -> (-2*flex3)/c3 + l3, 
     n0 -> n0 + (flex1*si1)/c1, n1 -> n1 - (flex1*si1)/c1, 
     n2 -> n2 + (flex2*si2)/c2, n3 -> n3 - (flex2*si2)/c2, 
     n4 -> n4 + (flex3*si3)/c3, n5 -> n5 - (flex3*si3)/c3}
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
qm = {{kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0, 0}, 
     {0, kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0}, 
     {0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0, 0}, 
     {0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0}, {0, 0, 0, 0, 
      kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      0}, {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2)}}
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
g /: g::usage = "g is local gravity."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmlp = {{m1, 0, 0, 0, 0, 0}, {0, I1y, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2y, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3y}}
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
xmlp = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      -((g*(m2 + m3))/(c2*l2)), -((d2*g*(m2 + m3))/(c2*l2)), 0, 0}, 
     {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 
          2*si^2))/(2*c2*l2), (d1*g*(m2 + m3))/(c2*l2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), (d1*g*(m2 + m3))/(c2*l2), 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), -((g*m3)/(c3*l3)), -((d4*g*m3)/(c3*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2)), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), (d3*g*m3)/(c3*l3), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3)}, {0, 0, -((g*m3)/(c3*l3)), (d3*g*m3)/(c3*l3), 
      (g*m3)/(c3*l3), (d4*g*m3)/(c3*l3)}, {0, 0, -((d4*g*m3)/(c3*l3)), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), (d4*g*m3)/(c3*l3), 4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3)}}
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}}
 
amlp = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 
      (-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/I1y, 
      -((g*(m2 + m3))/(c2*l2*m2)), -((d2*g*(m2 + m3))/(c2*I2y*l2)), 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 
      ((2*d0*g*(d0 + c1*l1)*(m1 + m2 + m3))/(c1*l1) + 8*c2^2*kw2*si^2 - 
        (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d1^2 + c2*d1*l2 + si^2))/
         (c2*l2))/(2*I1y), (d1*g*(m2 + m3))/(c2*l2*m2), 
      (d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
        16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
         (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
       (c2*I2y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0}, {-((g*(m2 + m3))/(c2*l2*m1)), 
      (d1*g*(m2 + m3))/(c2*I1y*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/
       m2, (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/I2y, 
      -(g/(c3*l3)), -((d4*g*m3)/(c3*I3y*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2*m1)), (d1*d2*g^2*(m2 + m3)^2 - 
        c2^2*d1*d2*g^2*(m2 + m3)^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*
         (d1*d2*kw2 + kblz*si^2))/(c2*I1y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/m2, 
      (8*c2^2*kw2*si^2 - (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d2^2 + c2*d2*l2 + si^2))/
         (c2*l2) + 8*c3^2*kw3*sl^2 - (2*c3*g*m3*sl^2)/l3 + 
        (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/(2*I2y), (d3*g)/(c3*l3), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I3y*l3)}, 
     {0, 0, -((g*m3)/(c3*l3*m2)), (d3*g*m3)/(c3*I2y*l3), g/(c3*l3), 
      (d4*g*m3)/(c3*I3y*l3)}, {0, 0, -((d4*g*m3)/(c3*l3*m2)), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I2y*l3), 
      (d4*g)/(c3*l3), (d4^2*g*m3 + c3*d4*g*l3*m3 + 
        (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/(c3*I3y*l3)}}
 
cxsmlp = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmlp = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*I1y*l1)), 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
kmtr = {{m1, 0, 0, 0, 0, 0}, {0, I1x, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2x, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3x}}
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmtr = {{(c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), -((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 0, 0}, 
     {(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), (4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + 
        c1*c2^2*l1^3*l2^2*n2*(-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + 
        c1*g*l1^3*(m2 + m3)*(d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*d0*l1*l2^2*
           (4*c1*kw1*l1*n1*(-n0 + n1) + g*(m1 + m2 + m3)*
             (l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), 0, 0}, {-((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
        4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
        c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
         (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
         (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
           (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 
              2*(n2 - n3)*n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {0, 0, (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3)}}
 
cqxmtr = {{((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
        g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
          g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      -(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
         g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}, {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}}
 
amtr = {{(-((c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
          (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
            c1^2*g*(m1 + m2 + m3)))) + 
        (c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
          c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 
      ((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*I1x), 
      ((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2))/
         c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (4*l2^4*m2), (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
         (n2 - n3)*n3 + (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*I2x*l2^3), 0, 0}, 
     {((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*m1), 
      ((-8*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2)/(c1*l1^3*(2*c1*kbuz*l1 + 
           2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
        (8*(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
              4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
            g*l2*(m2 + m3)*n3)^2)/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (8*(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
            (-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*(m2 + m3)*
            (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
           c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*
                l1*(n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + 
               g*(m1 + m2 + m3)*(l1^2 + 2*(n0 - n1)*n1)) + 
             l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 2*c1^3*kw1*l1*l2^2*n1^2 - 
               c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + c1*d1*l1*
                (4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 2*n2*(-n2 + 
                     n3)))))))/(c1*c2*l1^3*l2^3))/(8*I1x), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*l2^3*m2), (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
           (n2 - n3)*n3) + ((4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 
          4*c2^3*kw2*l2^2*n3 - g*l2*(m2 + m3)*n3 + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/(c2*I2x*l2^3), 0, 
      0}, {((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
            (n2 - n3)^2))/c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*
          (n2 - n3)^2)/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(4*l2^4*m1), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*I1x*l2^3), (-((c2^2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
          (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
          c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c3*l3^3))/(c2*l2^3*m2), 
      ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*I2x*l2^4), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3 + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*l2^3*m1), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        ((4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*I1x*l2^3), ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*l2^4*m2), 
      (-((c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + 
          c2*c3^2*l2^3*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
          c2*g*l2^3*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
          c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
              4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
             (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 2*(n2 - n3)*
                 n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 4*c2^3*kw2*l2*l3^2*n3^
                2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + c2*d3*l2*(4*d3*kw3*
                 (n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + n5))))))/(c3*l3^3))/
       (c2*I2x*l2^3), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3*m3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I3x*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m2), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*I2x*l3^3), (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*I3x*l3^3)}, {0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I2x*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*I3x*l3^3)}}
 
cxsmtr = {{0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
         2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)), 0, 0, 0, 
      -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2)}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmtr = {{0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
           2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)) + 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (2*l1^4*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*(-2*c1^3*kw1*l1*n0 + 
           c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*n1))/
         (4*c1*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(4*c1*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {0, ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
           (n0 - n1)*n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(2*c1*l1^4*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       I1x, 0, 0, 0, (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*(m1 + m2 + m3)*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/
         (4*c1^2*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(4*c1^2*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
           g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(c1*l1^2))/I1x}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}}
 
amy = {{((g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
        (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
        (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2))/I1z, 
      ((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I2z, 0}, {((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - (2*((c2*kw2*(n2 - n3)*si)/l2 - 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I1z, ((2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2))^2/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
        (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I2z, 
      ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3))/I3z}, 
     {0, ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
         (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
        (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
         (2*c3*l3))/I2z, ((2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
        (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/
         l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
        (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I3z}}
 
cxsmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*I1z*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
xm = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      0, 0, 0, 0, 0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
        (2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*(m1 + m2 + m3)*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/
        l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      -((c1*kw1*(n0 - n1))/l1) + (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - 
       (c1*kw1*(-n0 + n1))/l1 + (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + 
       (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 2*c1^2*kw1 + 4*c2^2*kw2 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/
        (c1*l1) - (c1*g*(m1 + m2 + m3))/l1, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, 0, 0, (g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + 
       (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 0, 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/
        l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, 0, 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, 0, 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 
      0, 0, 0, -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 0, 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), -(c1^2*kw1) - 
       (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - 
       (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + 
       (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), c2^2*kw2 + 
       (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}}
 
am = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((-(I1x*I1z) + I1zx^2)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(m2 + m3))/(c2*l2*m2)), 0, 0, 
      -((d2*g*(I2x*I2yz - I2xy*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), (d2*g*(I2x*I2z - I2zx^2)*(m2 + m3))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2), -((d2*g*(I2xy*I2z - I2yz*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), 0, 0, 0, 0, 0, 0}, 
     {0, ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
        (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(c1*l1^3) - 
        (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1xy*I1z - I1yz*I1zx)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1yz^2 - I1y*I1z)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 0, 
      (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
        4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (-(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) - 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2xy*I2z - I2yz*I2zx)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {0, 0, (2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 0, 0, 0, 0, 0, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
      ((I1xy^2 - I1x*I1y)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I1x*I1yz - I1xy*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1xy*I1yz - I1y*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
          c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
            4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
             (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
          c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
                l2^2*(n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      0, 0, 0, -(((I2xy^2 - I2x*I2y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*
           (n2*n3 + si^2) + g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
            l2^2*(n2*n3 + si^2)) - c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + 
            g^2*(m2 + m3)^2*(n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*
           (kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
              l2^2*(n2*n3 + si^2)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      -(((I2x*I2yz - I2xy*I2zx)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2yz - I2y*I2zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1x*I1z - I1zx^2)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
          c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
             (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
              d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
            c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
              4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
          2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1xy*I1z - I1yz*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), (d1*g*(m2 + m3))/(c2*l2*m2), 0, 0, 
      -(((I2x*I2yz - I2xy*I2zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I2x*I2z - I2zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {0, -((-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/m1), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), 0, (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
          4*kblz*n2*(n2 - n3)) - d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
        c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
            kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) + 
        c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I2yz^2 - I2y*I2z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2*m1)), 0, 0, (d1*g*(I1x*I1yz - I1xy*I1zx)*
        (m2 + m3))/(c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2), 
      (d1*g*(-(I1x*I1z) + I1zx^2)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(I1xy*I1z - I1yz*I1zx)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/
          (c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
        I2y*I2zx^2), ((-(I2x*I2z) + I2zx^2)*(-((d3*g*m3)/(c3*l3)) + 
         (d2*g*(m2 + m3))/(c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
        2*I2xy*I2yz*I2zx + I2y*I2zx^2), ((I2xy*I2z - I2yz*I2zx)*
        (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      -(g/(c3*l3)), 0, 0, -((d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), (d4*g*(I3x*I3z - I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -((d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3))}, {0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - 
        g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
           (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
            4*kblz*n2*(n2 - n3)) + d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
          c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) - 
          c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, ((2*g*m3)/(c3*l3) + 
        (2*g*(m2 + m3))/(c2*l2) + (8*kw2*(n2 - n3)^2)/l2^2 - 
        (2*g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
        (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*
            (l2^2 - (n2 - n3)^2)) + 4*c2^4*kw2*l2^4*
           (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
            c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - c2*g*l2*(m2 + m3)*
           (d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*kw3*l2^2*l3^2*n4*
             (-n4 + n5) + c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
                kw2*(n2 - n3)^2) + l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) - c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*
             (l3^2 - (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*
             (n4 - n5) + c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(
                n2 - n3)*n3 - g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
             (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
            c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
              4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                    (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 
        4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3)))/(m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, 0, 0, 0, 0, 0, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3, 0, 0, 0}, {0, 0, 0, 
      -(((I1xy^2 - I1x*I1y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), -(((I1x*I1yz - I1xy*I1zx)*
         (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, ((I2xy^2 - I2x*I2y)*
        (c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I2x*I2yz - I2xy*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
          c2^3*g*l2^3*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
              kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
              l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
           (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2*g*l2*(m2 + m3)*
           (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*(
                -((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
              kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
             (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
            c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 16*kblz*(
                kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 
      -(((I3xy^2 - I3x*I3y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), -(((I3x*I3yz - I3xy*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3)), 
      ((I3xy*I3yz - I3y*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {-((d2*g*(m2 + m3))/(c2*l2*m1)), 0, 0, 
      -(((I1x*I1yz - I1xy*I1zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1x*I1z - I1zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), (-((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
         4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 
      -(((I2x*I2z - I2zx^2)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
          4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
           (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
               d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
            4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (d3*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3x*I3z - I3zx^2)*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3xy*I3z - I3yz*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, 
     {0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
        c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
          4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 
      -((-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2) - 
         (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 + 
         (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*
             (n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) - (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
          l3^2 + (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3))/m2), 
      0, -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
          4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
            g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
              4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
              g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*(
                l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
              4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*(
                kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
              l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
          c2^3*l2^3*(4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
                32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                 (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 0, 
      (d3*g*(I2x*I2yz - I2xy*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(-(I2x*I2z) + I2zx^2)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(I2xy*I2z - I2yz*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), g/(c3*l3), 0, 0, (d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(-(I3x*I3z) + I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
          (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3), 
      -(((I2xy*I2z - I2yz*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      -(((I2yz^2 - I2y*I2z)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 0, 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, 0, 0, 
      (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 0, 0, 0, 0, 0, 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l3^3)), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      ((I2xy*I2yz - I2y*I2zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 0, 0, ((I3xy^2 - I3x*I3y)*
        (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
           l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3), 
      ((I3x*I3yz - I3xy*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), -(((I3xy*I3yz - I3y*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3))}, {0, 0, 0, 0, 0, 0, 
      -((d4*g*m3)/(c3*l3*m2)), 0, 0, ((I2x*I2yz - I2xy*I2zx)*
        (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2x*I2z - I2zx^2)*(-(d3*d4*g*m3) + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2xy*I2z - I2yz*I2zx)*(d3*d4*g*m3 + 
         (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d4*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -(((I3x*I3z - I3zx^2)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
          (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2xy*I2z - I2yz*I2zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2yz^2 - I2y*I2z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 0, 
      -(((I3xy*I3yz - I3y*I3zx)*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
            g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}}
 
cxsm = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, 
     {0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bm = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1}, 
     {0, 0, (-2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
        (c1*g*(m1 + m2 + m3))/l1 - ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))*(-(c1^2*kw1) - (g*(m1 + m2 + m3))/
            (2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1)))/
         (c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
             (2*l1))*(-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
            (2*l1))*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {-((d0*g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((-(I1xy*I1yz) + I1y*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1xy^2 - I1x*I1y)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(-(I1x*I1z) + I1zx^2)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1xy*I1z - I1yz*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1xy*I1z - I1yz*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(I1xy*I1z - I1yz*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1yz^2 - I1y*I1z)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(-(I1xy*I1yz) + I1y*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1yz^2 - I1y*I1z)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
stage2fudge = {d0 -> d0 + flex1, d1 -> d1 + flex2, d2 -> d2 + flex2, 
     d3 -> d3 + flex3, d4 -> d4 + flex3, l1 -> (-2*flex1)/c1 + l1, 
     l2 -> (-2*flex2)/c2 + l2, l3 -> (-2*flex3)/c3 + l3, 
     n0 -> n0 + (flex1*si1)/c1, n1 -> n1 - (flex1*si1)/c1, 
     n2 -> n2 + (flex2*si2)/c2, n3 -> n3 - (flex2*si2)/c2, 
     n4 -> n4 + (flex3*si3)/c3, n5 -> n5 - (flex3*si3)/c3}
 
stage2fudge /: stage2fudge::usage = "stage2fudge is a substitution list that \
tweaks exact Stage0 matrix elements to approximate the Stage2 results."
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
forcediagMOI /: forcediagMOI::usage = "forcediagMOI is a substitution list \
that zeroes off-diagonal MOI components."
 
qm = {{kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0, 0}, 
     {0, kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0}, 
     {0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0, 0}, 
     {0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0}, {0, 0, 0, 0, 
      kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      0}, {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2)}}
 
qm /: qm::usage = "qm is the stiffness matrix for floats."
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
g /: g::usage = "g is local gravity."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cqsm /: cqsm::usage = 
     "cqsm is a cross-stiffness matrix for floats against parameters."
 
kmlptr /: kmlptr::usage = 
     "kmlptr is the longitudinal-pitch-transverse-roll mass matrix."
 
xmlptr /: xmlptr::usage = "xmlptr and xm2lptr are the \
longitudinal-pitch-transverse-roll stiffness matrices for variables for \
Stage0A and Stage2."
 
cqxmlptr /: cqxmlptr::usage = "cqxmlptr and cqxm2lptr are the \
longitudinal-pitch-transverse-roll cross-stiffness matrices for floats \
against variables for Stage0A and Stage2."
 
amlptr := (xmlptr - Transpose[cqxmlptr] . Inverse[qm] . cqxmlptr) . 
     Inverse[kmlptr]
 
amlptr /: amlptr::usage = "amlptr and am2lptr are the \
longitudinal-pitch-transverse-roll A matrices (LL corner) for Stage0A and \
Stage2."
 
cxsmlptr /: cxsmlptr::usage = "cxsmlptr and cxsm2lptr are the \
longitudinal-pitch-transverse-roll cross-stiffness matrices for variables \
against parameters for Stage0A and Stage2."
 
bmlptr := Inverse[kmlptr] . (cxsmlptr - Transpose[cqxmlptr] . Inverse[qm] . 
       cqsm)
 
bmlptr /: bmlptr::usage = "bmlptr and bm2lptr are the \
longitudinal-pitch-transverse-roll B matrices (bottom half) for Stage0A and \
Stage2."
 
kmlp = {{m1, 0, 0, 0, 0, 0}, {0, I1y, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2y, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3y}}
 
kmlp /: kmlp::usage = "kmlp is the longitudinal-pitch mass matrix."
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
xmlp = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      -((g*(m2 + m3))/(c2*l2)), -((d2*g*(m2 + m3))/(c2*l2)), 0, 0}, 
     {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 
          2*si^2))/(2*c2*l2), (d1*g*(m2 + m3))/(c2*l2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), (d1*g*(m2 + m3))/(c2*l2), 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), -((g*m3)/(c3*l3)), -((d4*g*m3)/(c3*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2)), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), (d3*g*m3)/(c3*l3), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3)}, {0, 0, -((g*m3)/(c3*l3)), (d3*g*m3)/(c3*l3), 
      (g*m3)/(c3*l3), (d4*g*m3)/(c3*l3)}, {0, 0, -((d4*g*m3)/(c3*l3)), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), (d4*g*m3)/(c3*l3), 4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3)}}
 
xmlp /: xmlp::usage = "xmlp and xm2lp are the longitudinal-pitch stiffness \
matrices for variables for Stage0A and Stage2."
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}}
 
cqxmlp /: cqxmlp::usage = "cqxmlp and cqxm2lp are the longitudinal-pitch \
cross-stiffness matrices for floats against variables for Stage0A and \
Stage2."
 
amlp = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 
      (-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/I1y, 
      -((g*(m2 + m3))/(c2*l2*m2)), -((d2*g*(m2 + m3))/(c2*I2y*l2)), 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 
      ((2*d0*g*(d0 + c1*l1)*(m1 + m2 + m3))/(c1*l1) + 8*c2^2*kw2*si^2 - 
        (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d1^2 + c2*d1*l2 + si^2))/
         (c2*l2))/(2*I1y), (d1*g*(m2 + m3))/(c2*l2*m2), 
      (d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
        16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
         (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
       (c2*I2y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0}, {-((g*(m2 + m3))/(c2*l2*m1)), 
      (d1*g*(m2 + m3))/(c2*I1y*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/
       m2, (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/I2y, 
      -(g/(c3*l3)), -((d4*g*m3)/(c3*I3y*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2*m1)), (d1*d2*g^2*(m2 + m3)^2 - 
        c2^2*d1*d2*g^2*(m2 + m3)^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*
         (d1*d2*kw2 + kblz*si^2))/(c2*I1y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/m2, 
      (8*c2^2*kw2*si^2 - (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d2^2 + c2*d2*l2 + si^2))/
         (c2*l2) + 8*c3^2*kw3*sl^2 - (2*c3*g*m3*sl^2)/l3 + 
        (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/(2*I2y), (d3*g)/(c3*l3), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I3y*l3)}, 
     {0, 0, -((g*m3)/(c3*l3*m2)), (d3*g*m3)/(c3*I2y*l3), g/(c3*l3), 
      (d4*g*m3)/(c3*I3y*l3)}, {0, 0, -((d4*g*m3)/(c3*l3*m2)), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I2y*l3), 
      (d4*g)/(c3*l3), (d4^2*g*m3 + c3*d4*g*l3*m3 + 
        (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/(c3*I3y*l3)}}
 
amlp /: amlp::usage = "amlp and am2lp are the longitudinal-pitch A matrices \
(LL corner) for Stage0A and Stage2."
 
cxsmlp = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cxsmlp /: cxsmlp::usage = "cxsmlp and cxsm2lp are the longitudinal-pitch \
cross-stiffness matrices for variables against parameters for Stage0A and \
Stage2."
 
bmlp = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*I1y*l1)), 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmlp /: bmlp::usage = "bmlp and bm2lp are the longitudinal-pitch B matrices \
(bottom half) for Stage0A and Stage2."
 
kmtr = {{m1, 0, 0, 0, 0, 0}, {0, I1x, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2x, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3x}}
 
kmtr /: kmtr::usage = "kmtr is the transverse-roll mass matrix."
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmtr = {{(c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), -((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 0, 0}, 
     {(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), (4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + 
        c1*c2^2*l1^3*l2^2*n2*(-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + 
        c1*g*l1^3*(m2 + m3)*(d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*d0*l1*l2^2*
           (4*c1*kw1*l1*n1*(-n0 + n1) + g*(m1 + m2 + m3)*
             (l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), 0, 0}, {-((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
        4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
        c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
         (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
         (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
           (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 
              2*(n2 - n3)*n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {0, 0, (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3)}}
 
xmtr /: xmtr::usage = "xmtr and xm2tr are the transverse-roll stiffness \
matrices for variables for Stage0A and Stage2."
 
cqxmtr = {{((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
        g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
          g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      -(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
         g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}, {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}}
 
cqxmtr /: cqxmtr::usage = "cqxmtr and cqxm2tr are the transverse-roll \
cross-stiffness matrices for floats against variables for Stage0A and \
Stage2."
 
amtr = {{(-((c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
          (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
            c1^2*g*(m1 + m2 + m3)))) + 
        (c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
          c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 
      ((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*I1x), 
      ((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2))/
         c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (4*l2^4*m2), (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
         (n2 - n3)*n3 + (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*I2x*l2^3), 0, 0}, 
     {((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*m1), 
      ((-8*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2)/(c1*l1^3*(2*c1*kbuz*l1 + 
           2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
        (8*(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
              4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
            g*l2*(m2 + m3)*n3)^2)/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (8*(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
            (-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*(m2 + m3)*
            (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
           c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*
                l1*(n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + 
               g*(m1 + m2 + m3)*(l1^2 + 2*(n0 - n1)*n1)) + 
             l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 2*c1^3*kw1*l1*l2^2*n1^2 - 
               c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + c1*d1*l1*
                (4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 2*n2*(-n2 + 
                     n3)))))))/(c1*c2*l1^3*l2^3))/(8*I1x), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*l2^3*m2), (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
           (n2 - n3)*n3) + ((4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 
          4*c2^3*kw2*l2^2*n3 - g*l2*(m2 + m3)*n3 + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/(c2*I2x*l2^3), 0, 
      0}, {((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
            (n2 - n3)^2))/c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*
          (n2 - n3)^2)/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(4*l2^4*m1), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*I1x*l2^3), (-((c2^2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
          (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
          c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c3*l3^3))/(c2*l2^3*m2), 
      ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*I2x*l2^4), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3 + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*l2^3*m1), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        ((4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*I1x*l2^3), ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*l2^4*m2), 
      (-((c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + 
          c2*c3^2*l2^3*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
          c2*g*l2^3*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
          c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
              4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
             (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 2*(n2 - n3)*
                 n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 4*c2^3*kw2*l2*l3^2*n3^
                2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + c2*d3*l2*(4*d3*kw3*
                 (n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + n5))))))/(c3*l3^3))/
       (c2*I2x*l2^3), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3*m3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I3x*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m2), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*I2x*l3^3), (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*I3x*l3^3)}, {0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I2x*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*I3x*l3^3)}}
 
amtr /: amtr::usage = "amtr and am2tr are the transverse-roll A matrices (LL \
corner) for Stage0A and Stage2."
 
cxsmtr = {{0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
         2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)), 0, 0, 0, 
      -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2)}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
cxsmtr /: cxsmtr::usage = "cxsmtr and cxsm2tr are the transverse-roll \
cross-stiffness matrices for variables against parameters for Stage0A and \
Stage2."
 
bmtr = {{0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
           2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)) + 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (2*l1^4*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*(-2*c1^3*kw1*l1*n0 + 
           c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*n1))/
         (4*c1*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(4*c1*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {0, ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
           (n0 - n1)*n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(2*c1*l1^4*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       I1x, 0, 0, 0, (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*(m1 + m2 + m3)*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/
         (4*c1^2*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(4*c1^2*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
           g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(c1*l1^2))/I1x}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmtr /: bmtr::usage = "bmtr and bm2tr are the transverse-roll B matrices \
(bottom half) for Stage0A and Stage2."
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
kmy /: kmy::usage = "kmy is the yaw mass matrix."
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
xmy /: xmy::usage = "xmy and xm2y are the yaw stiffness matrices for \
variables for Stage0A and Stage2."
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}}
 
cqxmy /: cqxmy::usage = "cqxmy and cqxm2y are the yaw cross-stiffness \
matrices for floats against variables for Stage0A and Stage2."
 
amy = {{((g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
        (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
        (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2))/I1z, 
      ((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I2z, 0}, {((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - (2*((c2*kw2*(n2 - n3)*si)/l2 - 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I1z, ((2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2))^2/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
        (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I2z, 
      ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3))/I3z}, 
     {0, ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
         (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
        (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
         (2*c3*l3))/I2z, ((2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
        (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/
         l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
        (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I3z}}
 
amy /: amy::usage = 
     "amy and am2y are the yaw A matrices (LL corner) for Stage0A and \
Stage2."
 
cxsmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cxsmy /: cxsmy::usage = "cxsmy and cxsm2y are the yaw cross-stiffness \
matrices for variables against parameters for Stage0A and Stage2."
 
bmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*I1z*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmy /: bmy::usage = 
     "bmy and bm2y are the yaw B matrices (bottom half) for Stage0A and \
Stage2."
 
kmv = {{m1, 0, 0}, {0, m2, 0}, {0, 0, m3}}
 
kmv /: kmv::usage = "kmv is the vertical mass matrix."
 
xmv = {{2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
       (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
       (c1*g*(m1 + m2 + m3))/l1, -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 0}, {-4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - 
       (c3*g*m3)/l3 + (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3}, 
     {0, -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3}}
 
xmv /: xmv::usage = "xmv and xm2v are the vertical stiffness matrices for \
variables for Stage0A and Stage2."
 
cqxmv = {{-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0}, 
     {-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}}
 
cqxmv /: cqxmv::usage = "cqxmv and cqxm2v are the vertical cross-stiffness \
matrices for floats against variables for Stage0A and Stage2."
 
amv = {{(2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0}, {(-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3}, {0, (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3}}
 
amv /: amv::usage = "amv and am2v are the vertical A matrices (LL corner) for \
Stage0A and Stage2."
 
cxsmv = {{0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
cxsmv /: cxsmv::usage = "cxsmv and cxsm2v are the vertical cross-stiffness \
matrices for variables against parameters for Stage0A and Stage2."
 
bmv = {{0, 0, (-2*kbuz*(2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
         c1^2*g*(m1 + m2 + m3)))/(m1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
         g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))), 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmv /: bmv::usage = "bmv and bm2v are the vertical B matrices (bottom half) \
for Stage0A and Stage2."
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
km /: km::usage = "km is the full-system mass matrix."
 
xm = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      0, 0, 0, 0, 0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
        (2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*(m1 + m2 + m3)*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/
        l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      -((c1*kw1*(n0 - n1))/l1) + (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - 
       (c1*kw1*(-n0 + n1))/l1 + (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + 
       (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 2*c1^2*kw1 + 4*c2^2*kw2 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/
        (c1*l1) - (c1*g*(m1 + m2 + m3))/l1, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, 0, 0, (g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + 
       (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 0, 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/
        l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, 0, 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, 0, 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 
      0, 0, 0, -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 0, 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
xm /: xm::usage = "xm and xm2 are the full-system stiffness matrices for \
variables for Stage0A and Stage2."
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), -(c1^2*kw1) - 
       (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - 
       (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + 
       (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), c2^2*kw2 + 
       (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}}
 
cqxm /: cqxm::usage = "cqxm and cqxm are the full-system cross-stiffness \
matrices for floats against variables for Stage0A and Stage2."
 
am = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((-(I1x*I1z) + I1zx^2)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(m2 + m3))/(c2*l2*m2)), 0, 0, 
      -((d2*g*(I2x*I2yz - I2xy*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), (d2*g*(I2x*I2z - I2zx^2)*(m2 + m3))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2), -((d2*g*(I2xy*I2z - I2yz*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), 0, 0, 0, 0, 0, 0}, 
     {0, ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
        (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(c1*l1^3) - 
        (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1xy*I1z - I1yz*I1zx)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1yz^2 - I1y*I1z)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 0, 
      (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
        4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (-(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) - 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2xy*I2z - I2yz*I2zx)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {0, 0, (2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 0, 0, 0, 0, 0, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
      ((I1xy^2 - I1x*I1y)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I1x*I1yz - I1xy*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1xy*I1yz - I1y*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
          c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
            4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
             (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
          c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
                l2^2*(n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      0, 0, 0, -(((I2xy^2 - I2x*I2y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*
           (n2*n3 + si^2) + g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
            l2^2*(n2*n3 + si^2)) - c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + 
            g^2*(m2 + m3)^2*(n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*
           (kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
              l2^2*(n2*n3 + si^2)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      -(((I2x*I2yz - I2xy*I2zx)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2yz - I2y*I2zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1x*I1z - I1zx^2)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
          c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
             (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
              d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
            c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
              4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
          2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1xy*I1z - I1yz*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), (d1*g*(m2 + m3))/(c2*l2*m2), 0, 0, 
      -(((I2x*I2yz - I2xy*I2zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I2x*I2z - I2zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {0, -((-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/m1), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), 0, (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
          4*kblz*n2*(n2 - n3)) - d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
        c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
            kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) + 
        c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I2yz^2 - I2y*I2z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2*m1)), 0, 0, (d1*g*(I1x*I1yz - I1xy*I1zx)*
        (m2 + m3))/(c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2), 
      (d1*g*(-(I1x*I1z) + I1zx^2)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(I1xy*I1z - I1yz*I1zx)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/
          (c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
        I2y*I2zx^2), ((-(I2x*I2z) + I2zx^2)*(-((d3*g*m3)/(c3*l3)) + 
         (d2*g*(m2 + m3))/(c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
        2*I2xy*I2yz*I2zx + I2y*I2zx^2), ((I2xy*I2z - I2yz*I2zx)*
        (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      -(g/(c3*l3)), 0, 0, -((d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), (d4*g*(I3x*I3z - I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -((d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3))}, {0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - 
        g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
           (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
            4*kblz*n2*(n2 - n3)) + d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
          c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) - 
          c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, ((2*g*m3)/(c3*l3) + 
        (2*g*(m2 + m3))/(c2*l2) + (8*kw2*(n2 - n3)^2)/l2^2 - 
        (2*g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
        (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*
            (l2^2 - (n2 - n3)^2)) + 4*c2^4*kw2*l2^4*
           (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
            c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - c2*g*l2*(m2 + m3)*
           (d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*kw3*l2^2*l3^2*n4*
             (-n4 + n5) + c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
                kw2*(n2 - n3)^2) + l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) - c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*
             (l3^2 - (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*
             (n4 - n5) + c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(
                n2 - n3)*n3 - g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
             (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
            c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
              4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                    (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 
        4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3)))/(m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, 0, 0, 0, 0, 0, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3, 0, 0, 0}, {0, 0, 0, 
      -(((I1xy^2 - I1x*I1y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), -(((I1x*I1yz - I1xy*I1zx)*
         (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, ((I2xy^2 - I2x*I2y)*
        (c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I2x*I2yz - I2xy*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
          c2^3*g*l2^3*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
              kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
              l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
           (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2*g*l2*(m2 + m3)*
           (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*(
                -((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
              kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
             (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
            c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 16*kblz*(
                kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 
      -(((I3xy^2 - I3x*I3y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), -(((I3x*I3yz - I3xy*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3)), 
      ((I3xy*I3yz - I3y*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {-((d2*g*(m2 + m3))/(c2*l2*m1)), 0, 0, 
      -(((I1x*I1yz - I1xy*I1zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1x*I1z - I1zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), (-((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
         4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 
      -(((I2x*I2z - I2zx^2)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
          4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
           (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
               d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
            4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (d3*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3x*I3z - I3zx^2)*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3xy*I3z - I3yz*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, 
     {0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
        c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
          4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 
      -((-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2) - 
         (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 + 
         (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*
             (n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) - (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
          l3^2 + (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3))/m2), 
      0, -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
          4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
            g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
              4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
              g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*(
                l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
              4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*(
                kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
              l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
          c2^3*l2^3*(4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
                32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                 (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 0, 
      (d3*g*(I2x*I2yz - I2xy*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(-(I2x*I2z) + I2zx^2)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(I2xy*I2z - I2yz*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), g/(c3*l3), 0, 0, (d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(-(I3x*I3z) + I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
          (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3), 
      -(((I2xy*I2z - I2yz*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      -(((I2yz^2 - I2y*I2z)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 0, 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, 0, 0, 
      (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 0, 0, 0, 0, 0, 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l3^3)), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      ((I2xy*I2yz - I2y*I2zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 0, 0, ((I3xy^2 - I3x*I3y)*
        (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
           l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3), 
      ((I3x*I3yz - I3xy*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), -(((I3xy*I3yz - I3y*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3))}, {0, 0, 0, 0, 0, 0, 
      -((d4*g*m3)/(c3*l3*m2)), 0, 0, ((I2x*I2yz - I2xy*I2zx)*
        (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2x*I2z - I2zx^2)*(-(d3*d4*g*m3) + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2xy*I2z - I2yz*I2zx)*(d3*d4*g*m3 + 
         (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d4*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -(((I3x*I3z - I3zx^2)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
          (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2xy*I2z - I2yz*I2zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2yz^2 - I2y*I2z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 0, 
      -(((I3xy*I3yz - I3y*I3zx)*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
            g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}}
 
am /: am::usage = "am and am2 are the full-system A matrices (LL corner) for \
Stage0A and Stage2."
 
cxsm = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, 
     {0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cxsm /: cxsm::usage = "cxsm and cxsm2 are the full-system cross-stiffness \
matrices for variables against parameters for Stage0A and Stage2."
 
bm = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1}, 
     {0, 0, (-2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
        (c1*g*(m1 + m2 + m3))/l1 - ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))*(-(c1^2*kw1) - (g*(m1 + m2 + m3))/
            (2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1)))/
         (c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
             (2*l1))*(-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
            (2*l1))*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {-((d0*g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((-(I1xy*I1yz) + I1y*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1xy^2 - I1x*I1y)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(-(I1x*I1z) + I1zx^2)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1xy*I1z - I1yz*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1xy*I1z - I1yz*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(I1xy*I1z - I1yz*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1yz^2 - I1y*I1z)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(-(I1xy*I1yz) + I1y*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1yz^2 - I1y*I1z)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bm /: bm::usage = "bm and bm2 are the full-system B matrices (bottom half) \
for Stage0A and Stage2."
stage2fudge = {d0 -> d0 + flex1, d1 -> d1 + flex2, d2 -> d2 + flex2, 
     d3 -> d3 + flex3, d4 -> d4 + flex3, l1 -> (-2*flex1)/c1 + l1, 
     l2 -> (-2*flex2)/c2 + l2, l3 -> (-2*flex3)/c3 + l3, 
     n0 -> n0 + (flex1*si1)/c1, n1 -> n1 - (flex1*si1)/c1, 
     n2 -> n2 + (flex2*si2)/c2, n3 -> n3 - (flex2*si2)/c2, 
     n4 -> n4 + (flex3*si3)/c3, n5 -> n5 - (flex3*si3)/c3}
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
qm = {{kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0, 0}, 
     {0, kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0}, 
     {0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0, 0}, 
     {0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0}, {0, 0, 0, 0, 
      kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      0}, {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2)}}
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
g /: g::usage = "g is local gravity."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmlptr = {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I2y, I2xy, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I2xy, I2x, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3xy, I3x}}
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmlptr = {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 0, 0, 
      0}, {0, 0, 0, 0, 0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
        (2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*(m1 + m2 + m3)*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/
        l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 0, 
      (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0}, {0, 0, 0, 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 
          2*si^2))/(2*c2*l2), 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      0, (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0}, 
     {0, 0, 0, 0, -((g*(m2 + m3))/(c2*l2)), 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 0, 
      -((d4*g*m3)/(c3*l3)), 0}, {0, 0, 0, 0, 0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, -4*c2^2*kw2*si^2 + 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      0, -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, 0, 0, 0, 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, (d4*g*m3)/(c3*l3), 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), 0, -((d4*g*m3)/(c3*l3)) + 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 - 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 4*c3^2*kw3*sl^2 - 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 
      0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlptr = {{0, 0, 0, 0, 0, (c1*kw1*(n0 - n1))/l1 - 
       (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2), 0, 
      (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), -(c2^2*kw2*si) - 
       (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0}, {0, 0, 0, 0, 0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/
        (4*l2^2), -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/
        (8*c2*l2) + (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0}, {0, 0, 0, 0, 0, -((c2*kw2*(-n2 + n3))/l2) + 
       (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0}}
 
amlptr = {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 
       -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
       -((g*(m2 + m3))/(c2*l2)), 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 0, 0, 
       0}, {0, 0, 0, 0, 0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
         (c1*l1) + (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
         (c1*l1^3) - (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))), 0, ((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/4, 0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - 
         g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
         4*c2*d2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + 
           kw2*(n2 - n3)^2) - c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 
             16*kblz*kw2*(n2 - n3)^2) - 4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 
         4*c2^3*kw2*l2^3*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, 0, 0, 0}, {0, 0, 0, 0, 
       -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
       ((2*d0*g*(d0 + c1*l1)*(m1 + m2 + m3))/(c1*l1) + 8*c2^2*kw2*si^2 - 
         (2*c2*g*(m2 + m3)*si^2)/l2 - 
         (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
          (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d1^2 + c2*d1*l2 + si^2))/
          (c2*l2))/2, 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
       (d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
         16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
        (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
       ((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/4, 0, 
       (g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
        (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
        (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
        (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
        (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
        (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3)^2/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/(c2*l2), 0, 
       (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) - 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) + c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, (-16*c2^4*kblz*kw2*l2^4*n2*n3 - 
         c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
             kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
           4*kblz*l2^2*n2*n3) + g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + 
           l2^2*n3*(-n2 + n3)) + 4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + 
           g*(m2 + m3)*n3*(kblz*n2 - kw2*n2 + kw2*n3) + 
           d1*kw2*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))) - 
         c2^2*l2^2*(d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, 0, 0, 0}, {0, 0, 0, 0, 
       -((g*(m2 + m3))/(c2*l2)), 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
       (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, -((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 0, 
       -((d4*g*m3)/(c3*l3)), 0}, {0, 0, 0, 0, 0, 
       (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
         4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, 
       (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) - 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) + c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, ((2*g*m3)/(c3*l3) + (2*g*(m2 + m3))/
          (c2*l2) + (8*kw2*(n2 - n3)^2)/l2^2 - (2*g*(m2 + m3)*(n2 - n3)^2)/
          (c2*l2^3) - (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
         (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/2, 0, (d3*g*m3)/(c3*l3) - 
        (d2*g*(m2 + m3))/(c2*l2) + (4*kw2*(n2 - n3)*(c2*l2*n3 + 
           d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(n2 - n3)*
          (c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) - 
        ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
         l3^2 - (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3), 0, 
       (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 0, 
       (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
      {0, 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 
       (d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
         16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
        (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, -((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2), 0, (8*c2^2*kw2*si^2 - 
         (2*c2*g*(m2 + m3)*si^2)/l2 - 
         (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
          (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d2^2 + c2*d2*l2 + si^2))/
          (c2*l2) + 8*c3^2*kw3*sl^2 - (2*c3*g*m3*sl^2)/l3 + 
         (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/2, 0, (d3*g*m3)/(c3*l3), 
       0, (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*l3), 
       0}, {0, 0, 0, 0, 0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
         4*c2*d2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + 
           kw2*(n2 - n3)^2) - c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 
             16*kblz*kw2*(n2 - n3)^2) - 4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 
         4*c2^3*kw2*l2^3*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, (-16*c2^4*kblz*kw2*l2^4*n2*n3 - 
         c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
             kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
           4*kblz*l2^2*n2*n3) + g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + 
           l2^2*n3*(-n2 + n3)) + 4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + 
           g*(m2 + m3)*n3*(kblz*n2 - kw2*n2 + kw2*n3) + 
           d1*kw2*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))) - 
         c2^2*l2^2*(d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3))), 0, (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/
         (c2*l2) + (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) - 
        ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
         l3^2 - (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3), 0, 
       (g*(m2 + m3)*(d2^2 + c2*d2*l2 + n2*n3))/(c2*l2) + 
        (4*kw2*(c2*l2*n3 + d2*(-n2 + n3))^2)/l2^2 - 
        (g*(m2 + m3)*(c2*l2*n3 + d2*(-n2 + n3))^2)/(c2*l2^3) - 
        (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))^
          2/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (4*kw3*(c3*l3*n4 + d3*(n4 - n5))^2)/l3^2 - 
        (g*m3*(c3*l3*n4 + d3*(n4 - n5))^2)/(c3*l3^3) + 
        (g*m3*(d3^2 + c3*d3*l3 + n4*n5))/(c3*l3), 0, 
       (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 0, 
       (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3)}, 
      {0, 0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, (d3*g*m3)/(c3*l3), 0, 
       (g*m3)/(c3*l3), 0, (d4*g*m3)/(c3*l3), 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 
       (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 0, 
       (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 0, 
       (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 0, 
       (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
      {0, 0, 0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 
       (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*l3), 0, 
       (d4*g*m3)/(c3*l3), 0, (d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/(c3*l3), 0}, 
      {0, 0, 0, 0, 0, 0, 0, 0, 0, 
       (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 0, 
       (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 0, 
       (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 0, 
       (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
        (c3*l3^3)}} . Inverse[{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I2y, I2xy, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I2xy, I2x, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3y, I3xy}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3xy, I3x}}]
 
cxsmlptr = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 
      0}, {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
         (n0 - n1)*n1)/(c1*l1^3), 0, 0, 0, 
      (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
         g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmlptr = Inverse[{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I2y, I2xy, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I2xy, I2x, 0, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3y, I3xy}, 
       {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3xy, I3x}}] . 
     {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, 0, 0}, {-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
      {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))), 
       -((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))), 0, 0, 
       -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1)))}, 
      {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
      {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
             (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
           (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
           (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
           (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
           (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))), 
       -((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
           (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
           (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))), 0, 0, 
       -((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
           g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
           (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
           (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1)))}, {0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
      {0, 0, 0, 0, 0, 0}}
 
kmlp = {{m1, 0, 0, 0, 0, 0}, {0, I1y, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2y, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3y}}
 
xmlp = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      -((g*(m2 + m3))/(c2*l2)), -((d2*g*(m2 + m3))/(c2*l2)), 0, 0}, 
     {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 
          2*si^2))/(2*c2*l2), (d1*g*(m2 + m3))/(c2*l2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), (d1*g*(m2 + m3))/(c2*l2), 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), -((g*m3)/(c3*l3)), -((d4*g*m3)/(c3*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2)), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), (d3*g*m3)/(c3*l3), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3)}, {0, 0, -((g*m3)/(c3*l3)), (d3*g*m3)/(c3*l3), 
      (g*m3)/(c3*l3), (d4*g*m3)/(c3*l3)}, {0, 0, -((d4*g*m3)/(c3*l3)), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), (d4*g*m3)/(c3*l3), 4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3)}}
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}}
 
amlp = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 
      (-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/I1y, 
      -((g*(m2 + m3))/(c2*l2*m2)), -((d2*g*(m2 + m3))/(c2*I2y*l2)), 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 
      ((2*d0*g*(d0 + c1*l1)*(m1 + m2 + m3))/(c1*l1) + 8*c2^2*kw2*si^2 - 
        (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d1^2 + c2*d1*l2 + si^2))/
         (c2*l2))/(2*I1y), (d1*g*(m2 + m3))/(c2*l2*m2), 
      (d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
        16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
         (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
       (c2*I2y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0}, {-((g*(m2 + m3))/(c2*l2*m1)), 
      (d1*g*(m2 + m3))/(c2*I1y*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/
       m2, (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/I2y, 
      -(g/(c3*l3)), -((d4*g*m3)/(c3*I3y*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2*m1)), (d1*d2*g^2*(m2 + m3)^2 - 
        c2^2*d1*d2*g^2*(m2 + m3)^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*
         (d1*d2*kw2 + kblz*si^2))/(c2*I1y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/m2, 
      (8*c2^2*kw2*si^2 - (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d2^2 + c2*d2*l2 + si^2))/
         (c2*l2) + 8*c3^2*kw3*sl^2 - (2*c3*g*m3*sl^2)/l3 + 
        (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/(2*I2y), (d3*g)/(c3*l3), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I3y*l3)}, 
     {0, 0, -((g*m3)/(c3*l3*m2)), (d3*g*m3)/(c3*I2y*l3), g/(c3*l3), 
      (d4*g*m3)/(c3*I3y*l3)}, {0, 0, -((d4*g*m3)/(c3*l3*m2)), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I2y*l3), 
      (d4*g)/(c3*l3), (d4^2*g*m3 + c3*d4*g*l3*m3 + 
        (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/(c3*I3y*l3)}}
 
cxsmlp = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmlp = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*I1y*l1)), 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
kmtr = {{m1, 0, 0, 0, 0, 0}, {0, I1x, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2x, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3x}}
 
xmtr = {{(c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), -((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 0, 0}, 
     {(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), (4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + 
        c1*c2^2*l1^3*l2^2*n2*(-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + 
        c1*g*l1^3*(m2 + m3)*(d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*d0*l1*l2^2*
           (4*c1*kw1*l1*n1*(-n0 + n1) + g*(m1 + m2 + m3)*
             (l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), 0, 0}, {-((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
        4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
        c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
         (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
         (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
           (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 
              2*(n2 - n3)*n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {0, 0, (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3)}}
 
cqxmtr = {{((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
        g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
          g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      -(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
         g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}, {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}}
 
amtr = {{(-((c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
          (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
            c1^2*g*(m1 + m2 + m3)))) + 
        (c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
          c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 
      ((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*I1x), 
      ((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2))/
         c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (4*l2^4*m2), (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
         (n2 - n3)*n3 + (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*I2x*l2^3), 0, 0}, 
     {((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*m1), 
      ((-8*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2)/(c1*l1^3*(2*c1*kbuz*l1 + 
           2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
        (8*(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
              4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
            g*l2*(m2 + m3)*n3)^2)/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (8*(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
            (-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*(m2 + m3)*
            (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
           c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*
                l1*(n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + 
               g*(m1 + m2 + m3)*(l1^2 + 2*(n0 - n1)*n1)) + 
             l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 2*c1^3*kw1*l1*l2^2*n1^2 - 
               c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + c1*d1*l1*
                (4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 2*n2*(-n2 + 
                     n3)))))))/(c1*c2*l1^3*l2^3))/(8*I1x), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*l2^3*m2), (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
           (n2 - n3)*n3) + ((4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 
          4*c2^3*kw2*l2^2*n3 - g*l2*(m2 + m3)*n3 + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/(c2*I2x*l2^3), 0, 
      0}, {((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
            (n2 - n3)^2))/c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*
          (n2 - n3)^2)/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(4*l2^4*m1), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*I1x*l2^3), (-((c2^2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
          (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
          c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c3*l3^3))/(c2*l2^3*m2), 
      ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*I2x*l2^4), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3 + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*l2^3*m1), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        ((4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*I1x*l2^3), ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*l2^4*m2), 
      (-((c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + 
          c2*c3^2*l2^3*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
          c2*g*l2^3*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
          c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
              4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
             (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 2*(n2 - n3)*
                 n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 4*c2^3*kw2*l2*l3^2*n3^
                2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + c2*d3*l2*(4*d3*kw3*
                 (n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + n5))))))/(c3*l3^3))/
       (c2*I2x*l2^3), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3*m3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I3x*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m2), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*I2x*l3^3), (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*I3x*l3^3)}, {0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I2x*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*I3x*l3^3)}}
 
cxsmtr = {{0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
         2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)), 0, 0, 0, 
      -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2)}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmtr = {{0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
           2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)) + 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (2*l1^4*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*(-2*c1^3*kw1*l1*n0 + 
           c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*n1))/
         (4*c1*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(4*c1*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {0, ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
           (n0 - n1)*n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(2*c1*l1^4*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       I1x, 0, 0, 0, (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*(m1 + m2 + m3)*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/
         (4*c1^2*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(4*c1^2*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
           g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(c1*l1^2))/I1x}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}}
 
amy = {{((g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
        (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
        (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2))/I1z, 
      ((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I2z, 0}, {((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - (2*((c2*kw2*(n2 - n3)*si)/l2 - 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I1z, ((2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2))^2/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
        (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I2z, 
      ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3))/I3z}, 
     {0, ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
         (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
        (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
         (2*c3*l3))/I2z, ((2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
        (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/
         l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
        (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I3z}}
 
cxsmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*I1z*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmv = {{m1, 0, 0}, {0, m2, 0}, {0, 0, m3}}
 
xmv = {{2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
       (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
       (c1*g*(m1 + m2 + m3))/l1, -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 0}, {-4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - 
       (c3*g*m3)/l3 + (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3}, 
     {0, -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3}}
 
cqxmv = {{-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0}, 
     {-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}}
 
amv = {{(2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0}, {(-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3}, {0, (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3}}
 
cxsmv = {{0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmv = {{0, 0, (-2*kbuz*(2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
         c1^2*g*(m1 + m2 + m3)))/(m1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
         g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))), 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
xm = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      0, 0, 0, 0, 0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
        (2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*(m1 + m2 + m3)*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/
        l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      -((c1*kw1*(n0 - n1))/l1) + (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - 
       (c1*kw1*(-n0 + n1))/l1 + (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + 
       (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 2*c1^2*kw1 + 4*c2^2*kw2 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/
        (c1*l1) - (c1*g*(m1 + m2 + m3))/l1, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, 0, 0, (g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + 
       (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 0, 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/
        l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, 0, 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, 0, 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 
      0, 0, 0, -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 0, 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), -(c1^2*kw1) - 
       (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - 
       (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + 
       (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), c2^2*kw2 + 
       (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}}
 
am = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((-(I1x*I1z) + I1zx^2)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(m2 + m3))/(c2*l2*m2)), 0, 0, 
      -((d2*g*(I2x*I2yz - I2xy*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), (d2*g*(I2x*I2z - I2zx^2)*(m2 + m3))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2), -((d2*g*(I2xy*I2z - I2yz*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), 0, 0, 0, 0, 0, 0}, 
     {0, ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
        (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(c1*l1^3) - 
        (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1xy*I1z - I1yz*I1zx)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1yz^2 - I1y*I1z)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 0, 
      (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
        4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (-(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) - 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2xy*I2z - I2yz*I2zx)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {0, 0, (2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 0, 0, 0, 0, 0, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
      ((I1xy^2 - I1x*I1y)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I1x*I1yz - I1xy*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1xy*I1yz - I1y*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
          c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
            4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
             (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
          c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
                l2^2*(n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      0, 0, 0, -(((I2xy^2 - I2x*I2y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*
           (n2*n3 + si^2) + g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
            l2^2*(n2*n3 + si^2)) - c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + 
            g^2*(m2 + m3)^2*(n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*
           (kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
              l2^2*(n2*n3 + si^2)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      -(((I2x*I2yz - I2xy*I2zx)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2yz - I2y*I2zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1x*I1z - I1zx^2)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
          c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
             (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
              d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
            c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
              4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
          2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1xy*I1z - I1yz*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), (d1*g*(m2 + m3))/(c2*l2*m2), 0, 0, 
      -(((I2x*I2yz - I2xy*I2zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I2x*I2z - I2zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {0, -((-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/m1), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), 0, (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
          4*kblz*n2*(n2 - n3)) - d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
        c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
            kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) + 
        c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I2yz^2 - I2y*I2z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2*m1)), 0, 0, (d1*g*(I1x*I1yz - I1xy*I1zx)*
        (m2 + m3))/(c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2), 
      (d1*g*(-(I1x*I1z) + I1zx^2)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(I1xy*I1z - I1yz*I1zx)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/
          (c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
        I2y*I2zx^2), ((-(I2x*I2z) + I2zx^2)*(-((d3*g*m3)/(c3*l3)) + 
         (d2*g*(m2 + m3))/(c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
        2*I2xy*I2yz*I2zx + I2y*I2zx^2), ((I2xy*I2z - I2yz*I2zx)*
        (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      -(g/(c3*l3)), 0, 0, -((d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), (d4*g*(I3x*I3z - I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -((d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3))}, {0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - 
        g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
           (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
            4*kblz*n2*(n2 - n3)) + d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
          c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) - 
          c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, ((2*g*m3)/(c3*l3) + 
        (2*g*(m2 + m3))/(c2*l2) + (8*kw2*(n2 - n3)^2)/l2^2 - 
        (2*g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
        (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*
            (l2^2 - (n2 - n3)^2)) + 4*c2^4*kw2*l2^4*
           (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
            c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - c2*g*l2*(m2 + m3)*
           (d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*kw3*l2^2*l3^2*n4*
             (-n4 + n5) + c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
                kw2*(n2 - n3)^2) + l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) - c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*
             (l3^2 - (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*
             (n4 - n5) + c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(
                n2 - n3)*n3 - g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
             (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
            c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
              4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                    (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 
        4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3)))/(m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, 0, 0, 0, 0, 0, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3, 0, 0, 0}, {0, 0, 0, 
      -(((I1xy^2 - I1x*I1y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), -(((I1x*I1yz - I1xy*I1zx)*
         (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, ((I2xy^2 - I2x*I2y)*
        (c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I2x*I2yz - I2xy*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
          c2^3*g*l2^3*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
              kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
              l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
           (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2*g*l2*(m2 + m3)*
           (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*(
                -((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
              kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
             (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
            c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 16*kblz*(
                kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 
      -(((I3xy^2 - I3x*I3y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), -(((I3x*I3yz - I3xy*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3)), 
      ((I3xy*I3yz - I3y*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {-((d2*g*(m2 + m3))/(c2*l2*m1)), 0, 0, 
      -(((I1x*I1yz - I1xy*I1zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1x*I1z - I1zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), (-((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
         4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 
      -(((I2x*I2z - I2zx^2)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
          4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
           (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
               d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
            4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (d3*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3x*I3z - I3zx^2)*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3xy*I3z - I3yz*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, 
     {0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
        c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
          4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 
      -((-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2) - 
         (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 + 
         (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*
             (n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) - (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
          l3^2 + (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3))/m2), 
      0, -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
          4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
            g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
              4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
              g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*(
                l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
              4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*(
                kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
              l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
          c2^3*l2^3*(4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
                32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                 (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 0, 
      (d3*g*(I2x*I2yz - I2xy*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(-(I2x*I2z) + I2zx^2)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(I2xy*I2z - I2yz*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), g/(c3*l3), 0, 0, (d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(-(I3x*I3z) + I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
          (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3), 
      -(((I2xy*I2z - I2yz*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      -(((I2yz^2 - I2y*I2z)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 0, 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, 0, 0, 
      (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 0, 0, 0, 0, 0, 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l3^3)), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      ((I2xy*I2yz - I2y*I2zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 0, 0, ((I3xy^2 - I3x*I3y)*
        (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
           l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3), 
      ((I3x*I3yz - I3xy*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), -(((I3xy*I3yz - I3y*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3))}, {0, 0, 0, 0, 0, 0, 
      -((d4*g*m3)/(c3*l3*m2)), 0, 0, ((I2x*I2yz - I2xy*I2zx)*
        (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2x*I2z - I2zx^2)*(-(d3*d4*g*m3) + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2xy*I2z - I2yz*I2zx)*(d3*d4*g*m3 + 
         (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d4*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -(((I3x*I3z - I3zx^2)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
          (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2xy*I2z - I2yz*I2zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2yz^2 - I2y*I2z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 0, 
      -(((I3xy*I3yz - I3y*I3zx)*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
            g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}}
 
cxsm = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, 
     {0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bm = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1}, 
     {0, 0, (-2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
        (c1*g*(m1 + m2 + m3))/l1 - ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))*(-(c1^2*kw1) - (g*(m1 + m2 + m3))/
            (2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1)))/
         (c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
             (2*l1))*(-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
            (2*l1))*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {-((d0*g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((-(I1xy*I1yz) + I1y*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1xy^2 - I1x*I1y)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(-(I1x*I1z) + I1zx^2)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1xy*I1z - I1yz*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1xy*I1z - I1yz*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(I1xy*I1z - I1yz*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1yz^2 - I1y*I1z)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(-(I1xy*I1yz) + I1y*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1yz^2 - I1y*I1z)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
stage2fudge = {d0 -> d0 + flex1, d1 -> d1 + flex2, d2 -> d2 + flex2, 
     d3 -> d3 + flex3, d4 -> d4 + flex3, l1 -> (-2*flex1)/c1 + l1, 
     l2 -> (-2*flex2)/c2 + l2, l3 -> (-2*flex3)/c3 + l3, 
     n0 -> n0 + (flex1*si1)/c1, n1 -> n1 - (flex1*si1)/c1, 
     n2 -> n2 + (flex2*si2)/c2, n3 -> n3 - (flex2*si2)/c2, 
     n4 -> n4 + (flex3*si3)/c3, n5 -> n5 - (flex3*si3)/c3}
 
stage2fudge /: stage2fudge::usage = "stage2fudge is a substitution list that \
tweaks exact Stage0 matrix elements to approximate the Stage2 results."
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
forcediagMOI /: forcediagMOI::usage = "forcediagMOI is a substitution list \
that zeroes off-diagonal MOI components."
 
qm = {{kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0, 0}, 
     {0, kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0}, 
     {0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0, 0}, 
     {0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0}, {0, 0, 0, 0, 
      kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      0}, {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2)}}
 
qm /: qm::usage = "qm is the stiffness matrix for floats."
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
g /: g::usage = "g is local gravity."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cqsm /: cqsm::usage = 
     "cqsm is a cross-stiffness matrix for floats against parameters."
 
kmlptr = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0}, {0, 0, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, m2, 0, 0, 0, 0, 
      0, 0, 0}, {0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, I2y, I2xy, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, I2xy, I2x, 
      0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      I3y, I3xy}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3xy, I3x}}
 
kmlptr /: kmlptr::usage = 
     "kmlptr is the longitudinal-pitch-transverse-roll mass matrix."
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmlptr = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 0, 0, 
      0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(2*c1*l1^3) + 
       (kw1*(-n0 + n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(-n0 + n1)^2)/
        (2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/
        (2*c2*l2^3), 0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/
        (c1*l1), 0, (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      0, (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 0, 
      -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {-((d2*g*(m2 + m3))/(c2*l2)), 0, -4*c2^2*kw2*si^2 + 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      0, -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, (d3*g*m3)/(c3*l3), 0, (g*m3)/(c3*l3), 
      0, (d4*g*m3)/(c3*l3), 0}, {0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - 
       (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), 0, -((d4*g*m3)/(c3*l3)) + 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 - 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, -4*c3^2*kw3*sl^2 + 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/(2*c3*l3), 0, 
      (d4*g*m3)/(c3*l3), 0, 4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
xmlptr /: xmlptr::usage = "xmlptr and xm2lptr are the \
longitudinal-pitch-transverse-roll stiffness matrices for variables for \
Stage0A and Stage2."
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlptr = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/
        (2*l1^2), 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/
        (8*c2*l2) + (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0}, 
     {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/
        (4*l2^2), c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - 
       (c2*g*(m2 + m3)*si)/(4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/
        (8*c2*l2) + (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0}}
 
cqxmlptr /: cqxmlptr::usage = "cqxmlptr and cqxm2lptr are the \
longitudinal-pitch-transverse-roll cross-stiffness matrices for floats \
against variables for Stage0A and Stage2."
 
amlptr = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 
      (I1x*(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1)))/
       (-I1xy^2 + I1x*I1y), (I1xy*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2 - I1x*I1y), 
      -((g*(m2 + m3))/(c2*l2*m2)), 0, (d2*g*I2x*(m2 + m3))/
       (c2*(I2xy^2 - I2x*I2y)*l2), -((d2*g*I2xy*(m2 + m3))/
        (c2*(I2xy^2 - I2x*I2y)*l2)), 0, 0, 0, 0}, 
     {0, ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
        (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(c1*l1^3) - 
        (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, (I1xy*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2 - I1x*I1y)), 
      (I1y*((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(-I1xy^2 + I1x*I1y)), 0, 
      (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
        4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (I2xy*(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
         4*c2*d2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + 
           kw2*(n2 - n3)^2) - c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 
             16*kblz*kw2*(n2 - n3)^2) - 4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 
         4*c2^3*kw2*l2^3*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (I2y*(-(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) - 
         4*c2*d2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + 
           kw2*(n2 - n3)^2) + c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 
             16*kblz*kw2*(n2 - n3)^2) - 4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - 
         4*c2^3*kw2*l2^3*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 0, 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 
      -((I1x*(c1*d1^2*g^2*l1*(m2 + m3)^2 + c2^2*g*
           (4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
             (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
              d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
            c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
              4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2))))/(c1*c2*(I1xy^2 - I1x*I1y)*l1*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I1xy*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2 - I1x*I1y)*l1*l2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (d1*g*(m2 + m3))/(c2*l2*m2), 0, 
      (I2x*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
         16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I2xy^2 - I2x*I2y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -((I2xy*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2 - I2x*I2y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 0, 0, 0, 0}, 
     {0, -((-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/m1), 
      (I1xy*((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2 - I1x*I1y), 
      (I1y*((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(-I1xy^2 + I1x*I1y), 0, 
      (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) - 
        d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + c2*g*l2*(m2 + m3)*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*(m2 + m3)*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -((I2xy*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I2y*(16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2*m1)), 0, (d1*g*I1x*(m2 + m3))/
       (c2*(-I1xy^2 + I1x*I1y)*l2), (d1*g*I1xy*(m2 + m3))/
       (c2*(I1xy^2 - I1x*I1y)*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/
       m2, 0, (I2x*(-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2)))/
       (-I2xy^2 + I2x*I2y), (I2xy*(-((d3*g*m3)/(c3*l3)) + 
         (d2*g*(m2 + m3))/(c2*l2)))/(I2xy^2 - I2x*I2y), -(g/(c3*l3)), 0, 
      (d4*g*I3x*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3), 
      -((d4*g*I3xy*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3))}, 
     {0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*
         (l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 
      -((I1xy*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
           (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I1y*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 
      ((2*g*m3)/(c3*l3) + (2*g*(m2 + m3))/(c2*l2) + (8*kw2*(n2 - n3)^2)/
         l2^2 - (2*g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
        (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 
      (I2xy*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2 - I2x*I2y)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -((I2y*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
          4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
               (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
          c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
            4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
            c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
              l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
          c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
            4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
            c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*
               n3 - g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
          c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
            16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
            c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
              4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                    (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2 - I2x*I2y)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 
      (I3xy*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3), (I3y*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
            (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2 - I3x*I3y)*l3^3)}, {-((d2*g*(m2 + m3))/(c2*l2*m1)), 0, 
      (I1x*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
         16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I1xy^2 - I1x*I1y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -((I1xy*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2 - I1x*I1y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/m2, 0, 
      -((I2x*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
           (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
           (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
               d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
            4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2 - I2x*I2y)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I2xy*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2 - I2x*I2y)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), (d3*g)/(c3*l3), 0, 
      (I3x*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2 - I3x*I3y)*l3), 
      (I3xy*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2 - I3x*I3y)*l3)}, 
     {0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
        c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
          4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -((I1xy*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I1y*(16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 
      -((-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2) - 
         (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 + 
         (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*
             (n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) - (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
          l3^2 + (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3))/m2), 
      (I2xy*((g*(m2 + m3)*(d2^2 + c2*d2*l2 + n2*n3))/(c2*l2) + 
         (4*kw2*(c2*l2*n3 + d2*(-n2 + n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n3 + d2*(-n2 + n3))^2)/(c2*l2^3) - 
         (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
         (4*kw3*(c3*l3*n4 + d3*(n4 - n5))^2)/l3^2 - 
         (g*m3*(c3*l3*n4 + d3*(n4 - n5))^2)/(c3*l3^3) + 
         (g*m3*(d3^2 + c3*d3*l3 + n4*n5))/(c3*l3)))/(I2xy^2 - I2x*I2y), 
      (I2y*((g*(m2 + m3)*(d2^2 + c2*d2*l2 + n2*n3))/(c2*l2) + 
         (4*kw2*(c2*l2*n3 + d2*(-n2 + n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n3 + d2*(-n2 + n3))^2)/(c2*l2^3) - 
         (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
         (4*kw3*(c3*l3*n4 + d3*(n4 - n5))^2)/l3^2 - 
         (g*m3*(c3*l3*n4 + d3*(n4 - n5))^2)/(c3*l3^3) + 
         (g*m3*(d3^2 + c3*d3*l3 + n4*n5))/(c3*l3)))/(-I2xy^2 + I2x*I2y), 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3), 
      (I3xy*(d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3), (I3y*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + g*l3*m3*n5 - 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3)}, {0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 
      -((d3*g*I2x*m3)/(c3*I2xy^2*l3 - c3*I2x*I2y*l3)), 
      (d3*g*I2xy*m3)/(c3*I2xy^2*l3 - c3*I2x*I2y*l3), g/(c3*l3), 0, 
      -((d4*g*I3x*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3)), 
      (d4*g*I3xy*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3)}, 
     {0, 0, 0, 0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m2), -((I2xy*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2 - I2x*I2y)*l3^3)), 
      (I2y*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)))/(c3*(I2xy^2 - I2x*I2y)*
        l3^3), 0, (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m3), (I3xy*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2 - I3x*I3y)*l3^3), 
      (I3y*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3)}, {0, 0, 0, 0, -((d4*g*m3)/(c3*l3*m2)), 0, 
      (I2x*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2 - I2x*I2y)*l3), 
      (I2xy*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2 - I2x*I2y)*l3), (d4*g)/(c3*l3), 0, 
      -((I3x*(d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
           sl^2))/(c3*(I3xy^2 - I3x*I3y)*l3)), 
      (I3xy*(d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2 - I3x*I3y)*l3)}, {0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (I2xy*(d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I2xy^2 - I2x*I2y)*
        l3^3), (I2y*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + g*l3*m3*n5 - 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I2xy^2 - I2x*I2y)*
        l3^3), 0, (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3*m3), (I3xy*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
           g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/(c3*(I3xy^2 - I3x*I3y)*l3^3), 
      -((I3y*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
          l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
          c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/(c3*(I3xy^2 - I3x*I3y)*l3^3))}}
 
amlptr /: amlptr::usage = "amlptr and am2lptr are the \
longitudinal-pitch-transverse-roll A matrices (LL corner) for Stage0A and \
Stage2."
 
cxsmlptr = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 
      0}, {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
         (n0 - n1)*n1)/(c1*l1^3), 0, 0, 0, 
      (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
         g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
cxsmlptr /: cxsmlptr::usage = "cxsmlptr and cxsm2lptr are the \
longitudinal-pitch-transverse-roll cross-stiffness matrices for variables \
against parameters for Stage0A and Stage2."
 
bmlptr = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1}, 
     {-((d0*g*I1x*(m1 + m2 + m3))/(c1*(-I1xy^2 + I1x*I1y)*l1)), 
      (I1xy*((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1xy^2 - I1x*I1y), 
      (I1xy*(-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1xy^2 - I1x*I1y), 0, 0, 
      (I1xy*(-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
             g*(m1 + m2 + m3)*n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1xy^2 - I1x*I1y)}, {-((d0*g*I1xy*(m1 + m2 + m3))/
        (c1*(I1xy^2 - I1x*I1y)*l1)), 
      (I1y*((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (-I1xy^2 + I1x*I1y), 
      (I1y*(-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (-I1xy^2 + I1x*I1y), 0, 0, 
      (I1y*(-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
             g*(m1 + m2 + m3)*n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (-I1xy^2 + I1x*I1y)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmlptr /: bmlptr::usage = "bmlptr and bm2lptr are the \
longitudinal-pitch-transverse-roll B matrices (bottom half) for Stage0A and \
Stage2."
 
kmlp = {{m1, 0, 0, 0, 0, 0}, {0, I1y, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2y, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3y}}
 
kmlp /: kmlp::usage = "kmlp is the longitudinal-pitch mass matrix."
 
xmlp = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      -((g*(m2 + m3))/(c2*l2)), -((d2*g*(m2 + m3))/(c2*l2)), 0, 0}, 
     {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 
          2*si^2))/(2*c2*l2), (d1*g*(m2 + m3))/(c2*l2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), (d1*g*(m2 + m3))/(c2*l2), 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), -((g*m3)/(c3*l3)), -((d4*g*m3)/(c3*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2)), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), (d3*g*m3)/(c3*l3), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3)}, {0, 0, -((g*m3)/(c3*l3)), (d3*g*m3)/(c3*l3), 
      (g*m3)/(c3*l3), (d4*g*m3)/(c3*l3)}, {0, 0, -((d4*g*m3)/(c3*l3)), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), (d4*g*m3)/(c3*l3), 4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3)}}
 
xmlp /: xmlp::usage = "xmlp and xm2lp are the longitudinal-pitch stiffness \
matrices for variables for Stage0A and Stage2."
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}}
 
cqxmlp /: cqxmlp::usage = "cqxmlp and cqxm2lp are the longitudinal-pitch \
cross-stiffness matrices for floats against variables for Stage0A and \
Stage2."
 
amlp := (xmlp - Transpose[cqxmlp] . Inverse[qm] . cqxmlp) . Inverse[kmlp]
 
amlp /: amlp::usage = "amlp and am2lp are the longitudinal-pitch A matrices \
(LL corner) for Stage0A and Stage2."
 
cxsmlp = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cxsmlp /: cxsmlp::usage = "cxsmlp and cxsm2lp are the longitudinal-pitch \
cross-stiffness matrices for variables against parameters for Stage0A and \
Stage2."
 
bmlp := Inverse[kmlp] . (cxsmlp - Transpose[cqxmlp] . Inverse[qm] . cqsm)
 
bmlp /: bmlp::usage = "bmlp and bm2lp are the longitudinal-pitch B matrices \
(bottom half) for Stage0A and Stage2."
 
kmtr = {{m1, 0, 0, 0, 0, 0}, {0, I1x, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2x, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3x}}
 
kmtr /: kmtr::usage = "kmtr is the transverse-roll mass matrix."
 
xmtr = {{(c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), -((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 0, 0}, 
     {(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), (4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + 
        c1*c2^2*l1^3*l2^2*n2*(-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + 
        c1*g*l1^3*(m2 + m3)*(d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*d0*l1*l2^2*
           (4*c1*kw1*l1*n1*(-n0 + n1) + g*(m1 + m2 + m3)*
             (l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), 0, 0}, {-((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
        4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
        c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
         (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
         (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
           (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 
              2*(n2 - n3)*n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {0, 0, (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3)}}
 
xmtr /: xmtr::usage = "xmtr and xm2tr are the transverse-roll stiffness \
matrices for variables for Stage0A and Stage2."
 
cqxmtr = {{((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
        g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
          g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      -(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
         g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}, {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}}
 
cqxmtr /: cqxmtr::usage = "cqxmtr and cqxm2tr are the transverse-roll \
cross-stiffness matrices for floats against variables for Stage0A and \
Stage2."
 
amtr := (xmtr - Transpose[cqxmtr] . Inverse[qm] . cqxmtr) . Inverse[kmtr]
 
amtr /: amtr::usage = "amtr and am2tr are the transverse-roll A matrices (LL \
corner) for Stage0A and Stage2."
 
cxsmtr = {{0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
         2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)), 0, 0, 0, 
      -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2)}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
cxsmtr /: cxsmtr::usage = "cxsmtr and cxsm2tr are the transverse-roll \
cross-stiffness matrices for variables against parameters for Stage0A and \
Stage2."
 
bmtr := Inverse[kmtr] . (cxsmtr - Transpose[cqxmtr] . Inverse[qm] . cqsm)
 
bmtr /: bmtr::usage = "bmtr and bm2tr are the transverse-roll B matrices \
(bottom half) for Stage0A and Stage2."
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
kmy /: kmy::usage = "kmy is the yaw mass matrix."
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
xmy /: xmy::usage = "xmy and xm2y are the yaw stiffness matrices for \
variables for Stage0A and Stage2."
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}}
 
cqxmy /: cqxmy::usage = "cqxmy and cqxm2y are the yaw cross-stiffness \
matrices for floats against variables for Stage0A and Stage2."
 
amy := (xmy - Transpose[cqxmy] . Inverse[qm] . cqxmy) . Inverse[kmy]
 
amy /: amy::usage = 
     "amy and am2y are the yaw A matrices (LL corner) for Stage0A and \
Stage2."
 
cxsmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cxsmy /: cxsmy::usage = "cxsmy and cxsm2y are the yaw cross-stiffness \
matrices for variables against parameters for Stage0A and Stage2."
 
bmy := Inverse[kmy] . (cxsmy - Transpose[cqxmy] . Inverse[qm] . cqsm)
 
bmy /: bmy::usage = 
     "bmy and bm2y are the yaw B matrices (bottom half) for Stage0A and \
Stage2."
 
kmv = {{m1, 0, 0}, {0, m2, 0}, {0, 0, m3}}
 
kmv /: kmv::usage = "kmv is the vertical mass matrix."
 
xmv = {{2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
       (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
       (c1*g*(m1 + m2 + m3))/l1, -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 0}, {-4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - 
       (c3*g*m3)/l3 + (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3}, 
     {0, -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3}}
 
xmv /: xmv::usage = "xmv and xm2v are the vertical stiffness matrices for \
variables for Stage0A and Stage2."
 
cqxmv = {{-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0}, 
     {-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}}
 
cqxmv /: cqxmv::usage = "cqxmv and cqxm2v are the vertical cross-stiffness \
matrices for floats against variables for Stage0A and Stage2."
 
amv := (xmv - Transpose[cqxmv] . Inverse[qm] . cqxmv) . Inverse[kmv]
 
amv /: amv::usage = "amv and am2v are the vertical A matrices (LL corner) for \
Stage0A and Stage2."
 
cxsmv = {{0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
cxsmv /: cxsmv::usage = "cxsmv and cxsm2v are the vertical cross-stiffness \
matrices for variables against parameters for Stage0A and Stage2."
 
bmv := Inverse[kmv] . (cxsmv - Transpose[cqxmv] . Inverse[qm] . cqsm)
 
bmv /: bmv::usage = "bmv and bm2v are the vertical B matrices (bottom half) \
for Stage0A and Stage2."
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
km /: km::usage = "km is the full-system mass matrix."
 
xm = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      0, 0, 0, 0, 0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
        (2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*(m1 + m2 + m3)*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/
        l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      -((c1*kw1*(n0 - n1))/l1) + (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - 
       (c1*kw1*(-n0 + n1))/l1 + (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + 
       (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 2*c1^2*kw1 + 4*c2^2*kw2 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/
        (c1*l1) - (c1*g*(m1 + m2 + m3))/l1, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, 0, 0, (g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + 
       (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 0, 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/
        l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, 0, 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, 0, 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 
      0, 0, 0, -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 0, 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
xm /: xm::usage = "xm and xm2 are the full-system stiffness matrices for \
variables for Stage0A and Stage2."
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), -(c1^2*kw1) - 
       (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - 
       (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + 
       (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), c2^2*kw2 + 
       (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}}
 
cqxm /: cqxm::usage = "cqxm and cqxm are the full-system cross-stiffness \
matrices for floats against variables for Stage0A and Stage2."
 
am := (xm - Transpose[cqxm] . Inverse[qm] . cqxm) . Inverse[km]
 
am /: am::usage = "am and am2 are the full-system A matrices (LL corner) for \
Stage0A and Stage2."
 
cxsm = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, 
     {0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
cxsm /: cxsm::usage = "cxsm and cxsm2 are the full-system cross-stiffness \
matrices for variables against parameters for Stage0A and Stage2."
 
bm := Inverse[km] . (cxsm - Transpose[cqxm] . Inverse[qm] . cqsm)
 
bm /: bm::usage = "bm and bm2 are the full-system B matrices (bottom half) \
for Stage0A and Stage2."
stage2fudge = {d0 -> d0 + flex1, d1 -> d1 + flex2, d2 -> d2 + flex2, 
     d3 -> d3 + flex3, d4 -> d4 + flex3, l1 -> (-2*flex1)/c1 + l1, 
     l2 -> (-2*flex2)/c2 + l2, l3 -> (-2*flex3)/c3 + l3, 
     n0 -> n0 + (flex1*si1)/c1, n1 -> n1 - (flex1*si1)/c1, 
     n2 -> n2 + (flex2*si2)/c2, n3 -> n3 - (flex2*si2)/c2, 
     n4 -> n4 + (flex3*si3)/c3, n5 -> n5 - (flex3*si3)/c3}
 
d0 /: d0::usage = "d0 is the the height of the wire attachment points above \
the COM of mass U for the wires leading down from the blades on the \
structure."
 
d1 /: d1::usage = "d1 is the the height of the wire attachment points below \
the COM of mass U for the wires leading down to mass I."
 
d2 /: d2::usage = "d2 is the height of the wire attachment points above the \
COM of mass I for the wires leading down from the mass U."
 
d3 /: d3::usage = "d3 is the height of the wire attachment points below the \
COM of mass I for the wires leading down to the optic."
 
d4 /: d4::usage = "d4 is the the height of the wire attachment points above \
the COM of the optic for the wires leading down from mass I."
 
l1 /: l1::usage = "l1 is part of the specification of the model and \
represents the wire length from the blades on the structure to the top mass. \
It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l2 /: l2::usage = "l2 is part of the specification of the model and \
represents the wire length from the blades on the top mass to intermediate \
mass. It is interpreted as either a stretched length or an unstretched length \
depending on the value of the switch constant unstretched."
 
l3 /: l3::usage = "l3 is part of the specification of the model and \
represents the wire (fibre) length from intermediate mass to optic. It is \
interpreted as either a stretched length or an unstretched length depending \
on the value of the switch constant unstretched."
 
n0 /: n0::usage = "n0 is the y-direction separation of the wire attachment \
points on the upper blade springs for the wires leading down to the top \
mass."
 
n1 /: n1::usage = "n1 is the y-direction separation of the wire attachment \
points on the top mass for the wires leading down from the upper blade \
springs (on the structure)."
 
n2 /: n2::usage = "n2 is the y-direction separation of the wire attachment \
points on the lower blade springs for the wires leading down to mass I."
 
n3 /: n3::usage = "n3 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down from the lower blade springs."
 
n4 /: n4::usage = "n4 is the y-direction separation of the wire attachment \
points on mass I for the wires leading down to the optic."
 
n5 /: n5::usage = "n5 is the y-direction separation of the wire attachment \
points on the optic for the wires leading down from mass I."
 
forcediagMOI = {I1xy -> 0, I1yz -> 0, I1zx -> 0, I1xz -> 0, I1zy -> 0, 
     I1yx -> 0, I2xy -> 0, I2yz -> 0, I2zx -> 0, I2xz -> 0, I2zy -> 0, 
     I2yx -> 0, I3xy -> 0, I3yz -> 0, I3zx -> 0, I3xz -> 0, I3zy -> 0, 
     I3yx -> 0}
 
qm = {{kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0, 0}, 
     {0, kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 0, 0}, 
     {0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0, 0}, 
     {0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), 0, 0}, {0, 0, 0, 0, 
      kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      0}, {0, 0, 0, 0, 0, kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2)}}
 
kbuz /: kbuz::usage = 
     "kbuz is the net vertical elasticity of the upper blades (on \
structure)."
 
kw1 /: kw1::usage = "kw1 is net longitudinal elasticity of wires from blades \
on structure to top mass."
 
g /: g::usage = "g is local gravity."
 
m1 /: m1::usage = "m1 is mass of second top mass (mass U)."
 
m2 /: m2::usage = "m2 is mass of intermediate mass (mass I)."
 
m3 /: m3::usage = "m3 is mass of optic."
 
kblz /: kblz::usage = 
     "kblz is the net vertical elasticity of the lower blades (on top mass)."
 
kw2 /: kw2::usage = "kw2 is net longitudinal elasticity of wires from blades \
on top mass to intermediate mass."
 
cqsm = {{0, -((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, 
     {0, ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))/(2*c1*l1), 
      0, 0, (2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
        g*(m1 + m2 + m3)*n1)/(2*c1*l1)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmlptr = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, m1, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0}, {0, 0, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, m2, 0, 0, 0, 0, 
      0, 0, 0}, {0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, I2y, I2xy, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, I2xy, I2x, 
      0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      I3y, I3xy}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3xy, I3x}}
 
I1y /: I1y::usage = "I1y is y-axis MOI of second top mass (mass U)."
 
I1x /: I1x::usage = "I1x is x-axis MOI of second top mass (mass U)."
 
I2y /: I2y::usage = "I2y is y-axis MOI of intermediate mass (mass I)."
 
I2x /: I2x::usage = "I2x is x-axis MOI of intermediate mass (mass I)."
 
I3y /: I3y::usage = "I3y is y-axis MOI of optic."
 
I3x /: I3x::usage = "I3x is x-axis MOI of optic."
 
xmlptr = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 0, 0, 
      0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(2*c1*l1^3) + 
       (kw1*(-n0 + n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(-n0 + n1)^2)/
        (2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/
        (2*c2*l2^3), 0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/
        (c1*l1), 0, (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      0, (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 0, 
      -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {-((d2*g*(m2 + m3))/(c2*l2)), 0, -4*c2^2*kw2*si^2 + 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      0, -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, (d3*g*m3)/(c3*l3), 0, (g*m3)/(c3*l3), 
      0, (d4*g*m3)/(c3*l3), 0}, {0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - 
       (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), 0, -((d4*g*m3)/(c3*l3)) + 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 - 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, -4*c3^2*kw3*sl^2 + 
       (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/(2*c3*l3), 0, 
      (d4*g*m3)/(c3*l3), 0, 4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
si /: si::usage = "si is x-direction separation of wires from second top mass \
to intermediate mass."
 
kw3 /: kw3::usage = "kw3 is net longitudinal elasticity of wires (fibres) \
from intermediate mass to optic."
 
sl /: sl::usage = "sl is x-direction separation of wires (fibres) from \
intermediate mass to optic."
 
cqxmlptr = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/
        (2*l1^2), 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/
        (8*c2*l2) + (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0}, 
     {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/
        (4*l2^2), c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - 
       (c2*g*(m2 + m3)*si)/(4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/
        (8*c2*l2) + (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0}}
 
amlptr = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 
      (I1x*(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1)))/
       (-I1xy^2 + I1x*I1y), (I1xy*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2 - I1x*I1y), 
      -((g*(m2 + m3))/(c2*l2*m2)), 0, (d2*g*I2x*(m2 + m3))/
       (c2*(I2xy^2 - I2x*I2y)*l2), -((d2*g*I2xy*(m2 + m3))/
        (c2*(I2xy^2 - I2x*I2y)*l2)), 0, 0, 0, 0}, 
     {0, ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
        (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(c1*l1^3) - 
        (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, (I1xy*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2 - I1x*I1y)), 
      (I1y*((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(-I1xy^2 + I1x*I1y)), 0, 
      (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
        4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (I2xy*(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
         4*c2*d2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + 
           kw2*(n2 - n3)^2) - c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 
             16*kblz*kw2*(n2 - n3)^2) - 4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 
         4*c2^3*kw2*l2^3*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (I2y*(-(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) - 
         4*c2*d2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + 
           kw2*(n2 - n3)^2) + c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 
             16*kblz*kw2*(n2 - n3)^2) - 4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - 
         4*c2^3*kw2*l2^3*(d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 0, 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 
      -((I1x*(c1*d1^2*g^2*l1*(m2 + m3)^2 + c2^2*g*
           (4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
             (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
              d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
            c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
              4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2))))/(c1*c2*(I1xy^2 - I1x*I1y)*l1*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I1xy*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2 - I1x*I1y)*l1*l2*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (d1*g*(m2 + m3))/(c2*l2*m2), 0, 
      (I2x*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
         16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I2xy^2 - I2x*I2y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -((I2xy*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2 - I2x*I2y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 0, 0, 0, 0}, 
     {0, -((-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/m1), 
      (I1xy*((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2 - I1x*I1y), 
      (I1y*((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(-I1xy^2 + I1x*I1y), 0, 
      (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) - 
        d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + c2*g*l2*(m2 + m3)*
         (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
          g*(m2 + m3)*(n2 - n3)^2) + c2^2*l2^2*
         (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -((I2xy*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I2y*(16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I2xy^2 - I2x*I2y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2*m1)), 0, (d1*g*I1x*(m2 + m3))/
       (c2*(-I1xy^2 + I1x*I1y)*l2), (d1*g*I1xy*(m2 + m3))/
       (c2*(I1xy^2 - I1x*I1y)*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/
       m2, 0, (I2x*(-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2)))/
       (-I2xy^2 + I2x*I2y), (I2xy*(-((d3*g*m3)/(c3*l3)) + 
         (d2*g*(m2 + m3))/(c2*l2)))/(I2xy^2 - I2x*I2y), -(g/(c3*l3)), 0, 
      (d4*g*I3x*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3), 
      -((d4*g*I3xy*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3))}, 
     {0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*
         (l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 
      -((I1xy*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
           (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I1y*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 
      ((2*g*m3)/(c3*l3) + (2*g*(m2 + m3))/(c2*l2) + (8*kw2*(n2 - n3)^2)/
         l2^2 - (2*g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
        (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 
      (I2xy*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2 - I2x*I2y)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -((I2y*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
          4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
               (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
          c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
            4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
            c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
              l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
          c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
            4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
            c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*
               n3 - g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
          c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
            16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
            c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
              4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                    (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2 - I2x*I2y)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 
      (I3xy*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3), (I3y*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
            (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2 - I3x*I3y)*l3^3)}, {-((d2*g*(m2 + m3))/(c2*l2*m1)), 0, 
      (I1x*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
         16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I1xy^2 - I1x*I1y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -((I1xy*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2 - I1x*I1y)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/m2, 0, 
      -((I2x*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
           (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
           (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
               d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
            4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2 - I2x*I2y)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I2xy*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2 - I2x*I2y)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), (d3*g)/(c3*l3), 0, 
      (I3x*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2 - I3x*I3y)*l3), 
      (I3xy*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2 - I3x*I3y)*l3)}, 
     {0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
        c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
          4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -((I1xy*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
          g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      (I1y*(16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I1xy^2 - I1x*I1y)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 0, 
      -((-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2) - 
         (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 + 
         (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*
             (n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) - (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
          l3^2 + (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3))/m2), 
      (I2xy*((g*(m2 + m3)*(d2^2 + c2*d2*l2 + n2*n3))/(c2*l2) + 
         (4*kw2*(c2*l2*n3 + d2*(-n2 + n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n3 + d2*(-n2 + n3))^2)/(c2*l2^3) - 
         (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
         (4*kw3*(c3*l3*n4 + d3*(n4 - n5))^2)/l3^2 - 
         (g*m3*(c3*l3*n4 + d3*(n4 - n5))^2)/(c3*l3^3) + 
         (g*m3*(d3^2 + c3*d3*l3 + n4*n5))/(c3*l3)))/(I2xy^2 - I2x*I2y), 
      (I2y*((g*(m2 + m3)*(d2^2 + c2*d2*l2 + n2*n3))/(c2*l2) + 
         (4*kw2*(c2*l2*n3 + d2*(-n2 + n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n3 + d2*(-n2 + n3))^2)/(c2*l2^3) - 
         (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
            g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
         (4*kw3*(c3*l3*n4 + d3*(n4 - n5))^2)/l3^2 - 
         (g*m3*(c3*l3*n4 + d3*(n4 - n5))^2)/(c3*l3^3) + 
         (g*m3*(d3^2 + c3*d3*l3 + n4*n5))/(c3*l3)))/(-I2xy^2 + I2x*I2y), 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3), 
      (I3xy*(d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3), (I3y*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + g*l3*m3*n5 - 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3)}, {0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 
      -((d3*g*I2x*m3)/(c3*I2xy^2*l3 - c3*I2x*I2y*l3)), 
      (d3*g*I2xy*m3)/(c3*I2xy^2*l3 - c3*I2x*I2y*l3), g/(c3*l3), 0, 
      -((d4*g*I3x*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3)), 
      (d4*g*I3xy*m3)/(c3*I3xy^2*l3 - c3*I3x*I3y*l3)}, 
     {0, 0, 0, 0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m2), -((I2xy*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2 - I2x*I2y)*l3^3)), 
      (I2y*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)))/(c3*(I2xy^2 - I2x*I2y)*
        l3^3), 0, (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m3), (I3xy*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2 - I3x*I3y)*l3^3), 
      (I3y*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/(c3*(I3xy^2 - I3x*I3y)*
        l3^3)}, {0, 0, 0, 0, -((d4*g*m3)/(c3*l3*m2)), 0, 
      (I2x*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2 - I2x*I2y)*l3), 
      (I2xy*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2 - I2x*I2y)*l3), (d4*g)/(c3*l3), 0, 
      -((I3x*(d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
           sl^2))/(c3*(I3xy^2 - I3x*I3y)*l3)), 
      (I3xy*(d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2 - I3x*I3y)*l3)}, {0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (I2xy*(d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I2xy^2 - I2x*I2y)*
        l3^3), (I2y*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + g*l3*m3*n5 - 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/(c3*(I2xy^2 - I2x*I2y)*
        l3^3), 0, (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*
           (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*l3^3*m3), (I3xy*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
           g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/(c3*(I3xy^2 - I3x*I3y)*l3^3), 
      -((I3y*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
          l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
          c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/(c3*(I3xy^2 - I3x*I3y)*l3^3))}}
 
cxsmlptr = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 
      0}, {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
         (n0 - n1)*n1)/(c1*l1^3), 0, 0, 0, 
      (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
         g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmlptr = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1}, 
     {-((d0*g*I1x*(m1 + m2 + m3))/(c1*(-I1xy^2 + I1x*I1y)*l1)), 
      (I1xy*((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1xy^2 - I1x*I1y), 
      (I1xy*(-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1xy^2 - I1x*I1y), 0, 0, 
      (I1xy*(-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
             g*(m1 + m2 + m3)*n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1xy^2 - I1x*I1y)}, {-((d0*g*I1xy*(m1 + m2 + m3))/
        (c1*(I1xy^2 - I1x*I1y)*l1)), 
      (I1y*((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (-I1xy^2 + I1x*I1y), 
      (I1y*(-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (-I1xy^2 + I1x*I1y), 0, 0, 
      (I1y*(-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
             g*(m1 + m2 + m3)*n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (-I1xy^2 + I1x*I1y)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmlp = {{m1, 0, 0, 0, 0, 0}, {0, I1y, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2y, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3y}}
 
xmlp = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      -((g*(m2 + m3))/(c2*l2)), -((d2*g*(m2 + m3))/(c2*l2)), 0, 0}, 
     {-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 
      (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 4*c2^2*kw2*si^2 - 
       (c2*g*(m2 + m3)*si^2)/l2 + (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 
          2*si^2))/(2*c2*l2), (d1*g*(m2 + m3))/(c2*l2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), (d1*g*(m2 + m3))/(c2*l2), 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), -((d3*g*m3)/(c3*l3)) + 
       (d2*g*(m2 + m3))/(c2*l2), -((g*m3)/(c3*l3)), -((d4*g*m3)/(c3*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2)), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/
        l2 + (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 
      4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), (d3*g*m3)/(c3*l3), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3)}, {0, 0, -((g*m3)/(c3*l3)), (d3*g*m3)/(c3*l3), 
      (g*m3)/(c3*l3), (d4*g*m3)/(c3*l3)}, {0, 0, -((d4*g*m3)/(c3*l3)), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), (d4*g*m3)/(c3*l3), 4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3)}}
 
cqxmlp = {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, c2^2*kw2*si + (g*(m2 + m3)*si)/
        (4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}, 
     {0, c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/
        (4*l2), 0, -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + 
       (c2*g*(m2 + m3)*si)/(4*l2), 0, 0}}
 
amlp = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 
      (-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/I1y, 
      -((g*(m2 + m3))/(c2*l2*m2)), -((d2*g*(m2 + m3))/(c2*I2y*l2)), 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 
      ((2*d0*g*(d0 + c1*l1)*(m1 + m2 + m3))/(c1*l1) + 8*c2^2*kw2*si^2 - 
        (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d1^2 + c2*d1*l2 + si^2))/
         (c2*l2))/(2*I1y), (d1*g*(m2 + m3))/(c2*l2*m2), 
      (d1*d2*g^2*(m2 + m3)^2 - c2^2*d1*d2*g^2*(m2 + m3)^2 - 
        16*c2^4*kblz*kw2*l2^2*si^2 + 4*c2*g*kblz*l2*(m2 + m3)*
         (d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2))/
       (c2*I2y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0}, {-((g*(m2 + m3))/(c2*l2*m1)), 
      (d1*g*(m2 + m3))/(c2*I1y*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/
       m2, (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/I2y, 
      -(g/(c3*l3)), -((d4*g*m3)/(c3*I3y*l3))}, 
     {-((d2*g*(m2 + m3))/(c2*l2*m1)), (d1*d2*g^2*(m2 + m3)^2 - 
        c2^2*d1*d2*g^2*(m2 + m3)^2 - 16*c2^4*kblz*kw2*l2^2*si^2 + 
        4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) + 4*c2^3*g*l2*(m2 + m3)*
         (d1*d2*kw2 + kblz*si^2))/(c2*I1y*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2))/m2, 
      (8*c2^2*kw2*si^2 - (2*c2*g*(m2 + m3)*si^2)/l2 - 
        (2*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2*si^2)/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (2*g*(m2 + m3)*(d2^2 + c2*d2*l2 + si^2))/
         (c2*l2) + 8*c3^2*kw3*sl^2 - (2*c3*g*m3*sl^2)/l3 + 
        (2*g*m3*(d3^2 + c3*d3*l3 + sl^2))/(c3*l3))/(2*I2y), (d3*g)/(c3*l3), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I3y*l3)}, 
     {0, 0, -((g*m3)/(c3*l3*m2)), (d3*g*m3)/(c3*I2y*l3), g/(c3*l3), 
      (d4*g*m3)/(c3*I3y*l3)}, {0, 0, -((d4*g*m3)/(c3*l3*m2)), 
      (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2)/(c3*I2y*l3), 
      (d4*g)/(c3*l3), (d4^2*g*m3 + c3*d4*g*l3*m3 + 
        (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2)/(c3*I3y*l3)}}
 
cxsmlp = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmlp = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*I1y*l1)), 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
kmtr = {{m1, 0, 0, 0, 0, 0}, {0, I1x, 0, 0, 0, 0}, {0, 0, m2, 0, 0, 0}, 
     {0, 0, 0, I2x, 0, 0}, {0, 0, 0, 0, m3, 0}, {0, 0, 0, 0, 0, I3x}}
 
xmtr = {{(c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
          2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
        c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3), 
      (c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), -((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 0, 0}, 
     {(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
            g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*(n2 - 
                n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + c1*d1*g*l1^3*(m2 + m3)*
         (l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*l2^2*n2*(n2 - n3))/
       (c1*c2*l1^3*l2^3), (4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + 
        c1*c2^2*l1^3*l2^2*n2*(-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + 
        c1*g*l1^3*(m2 + m3)*(d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
        c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) + c1*d0*l1*l2^2*
           (4*c1*kw1*l1*n1*(-n0 + n1) + g*(m1 + m2 + m3)*
             (l1^2 + 2*(n0 - n1)*n1)) + l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            2*c1^3*kw1*l1*l2^2*n1^2 - c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + 
            c1*d1*l1*(4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 
                2*n2*(-n2 + n3))))))/(c1*c2*l1^3*l2^3), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), 0, 0}, {-((g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
         4*c2*kw2*l2*(n2 - n3)^2)/(c2*l2^3)), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3))/(c2*l2^3), 
      (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
        c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c2*c3*l2^3*l3^3), 
      (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 4*c2*c3^2*kw3*l2^3*l3^2*n4*
         (n4 - n5) + c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3)/(c2*l2^3), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*l2^3), (c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
        4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
        c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 
            4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
              l2^2*m3*n4*(-n4 + n5)))))/(c2*c3*l2^3*l3^3), 
      (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + c2*c3^2*l2^3*l3^2*n4*
         (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + c2*g*l2^3*m3*
         (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
        c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
           (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 
              2*(n2 - n3)*n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 
            4*c2^3*kw2*l2*l3^2*n3^2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + 
            c2*d3*l2*(4*d3*kw3*(n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + 
                  n5))))))/(c2*c3*l2^3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3), 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3)}, 
     {0, 0, (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*l3^3)}}
 
cqxmtr = {{((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
        g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
          g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1))/(2*l1^2), 
      -(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
         g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1^2), 0, 0, 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {-((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (-4*c2^3*kw2*l2^2*n2 + c2*d1*g*(m2 + m3)*(n2 - n3) - 
        g*l2*(m2 + m3)*n3 + c2^2*l2*(g*(m2 + m3)*n2 + 4*d1*kw2*(-n2 + n3)))/
       (4*c2*l2^2), ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
        c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/(4*c2*l2^2), 0, 0}, 
     {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}, {((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
          4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
        g*l2*(m2 + m3)*n3)/(4*c2*l2^2), 
      -((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3))/(4*l2^2), 
      -(c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
         g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3))/
       (4*c2*l2^2), 0, 0}}
 
amtr = {{(-((c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
          (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
            c1^2*g*(m1 + m2 + m3)))) + 
        (c2*l2*(g*l2^2*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*l1*(kw1*l2^2*(n0 - n1)^2 + 2*kw2*l1^2*(n2 - n3)^2)) + 
          c1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2))/(c1*c2*l1^3*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 
      ((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*I1x), 
      ((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2))/
         c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (4*l2^4*m2), (d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
          4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
         (n2 - n3)*n3 + (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*I2x*l2^3), 0, 0}, 
     {((-8*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
           g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
        (8*(c2*l2*(d0*l2^2*(-(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2)) - 2*c1*
                kw1*l1*(n0 - n1)^2) + c1*l1*(2*c1*kw1*l1*l2^2*(n0 - n1)*n1 + 
               g*(-(l2^2*(m1 + m2 + m3)*(n0 - n1)*n1) - l1^2*(m2 + m3)*n2*
                  (n2 - n3)) + 4*d1*kw2*l1^2*(n2 - n3)^2)) + 
           c1*d1*g*l1^3*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c1*c2^2*kw2*l1^3*
            l2^2*n2*(n2 - n3)))/(c1*c2*l1^3*l2^3) - 
        (8*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/(8*m1), 
      ((-8*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2)/(c1*l1^3*(2*c1*kbuz*l1 + 
           2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
        (8*(4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
              4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
            g*l2*(m2 + m3)*n3)^2)/(c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (8*(4*c1*c2^3*kw2*l1^3*l2^3*n2^2 + c1*c2^2*l1^3*l2^2*n2*
            (-(g*(m2 + m3)*n2) + 8*d1*kw2*(n2 - n3)) + c1*g*l1^3*(m2 + m3)*
            (d1^2*(l2^2 - (n2 - n3)^2) + l2^2*n2*n3) + 
           c2*l2*(d0^2*l2^2*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*
                l1*(n0 - n1)^2) + c1*d0*l1*l2^2*(4*c1*kw1*l1*n1*(-n0 + n1) + 
               g*(m1 + m2 + m3)*(l1^2 + 2*(n0 - n1)*n1)) + 
             l1^2*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 2*c1^3*kw1*l1*l2^2*n1^2 - 
               c1^2*g*l2^2*(m1 + m2 + m3)*n1^2 + c1*d1*l1*
                (4*d1*kw2*(n2 - n3)^2 + g*(m2 + m3)*(l2^2 + 2*n2*(-n2 + 
                     n3)))))))/(c1*c2*l1^3*l2^3))/(8*I1x), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*l2^3*m2), (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*kw2*l2*(n2 - n3)^2) - c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*
           (n2 - n3)*n3) + ((4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 
          4*c2^3*kw2*l2^2*n3 - g*l2*(m2 + m3)*n3 + 
          c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/(c2*I2x*l2^3), 0, 
      0}, {((-4*l2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*
            (n2 - n3)^2))/c2 + (4*c2*l2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*
          (n2 - n3)^2)/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(4*l2^4*m1), 
      (d1*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*n2*(n2 - n3) + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
           c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
           c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (c2*I1x*l2^3), (-((c2^2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
          (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))) + 
        (c3*l3*(g*l3^2*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
            4*c2*l2*(kw2*l3^2*(n2 - n3)^2 + kw3*l2^2*(n4 - n5)^2)) + 
          c2*g*l2^3*m3*(l3^2 - (n4 - n5)^2))/(c3*l3^3))/(c2*l2^3*m2), 
      ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*I2x*l2^4), 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*I3x*l3^3)}, 
     {(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
        c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3 + 
        (c2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))/(c2*l2^3*m1), 
      (d1*(d2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 4*c2*kw2*l2*(n2 - n3)^2) - 
          c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*n3) + 
        ((4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 
             4*d1*kw2*(n2 - n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + 
           g*l2*(m2 + m3)*n3)*(c2*d2*g*(m2 + m3)*(n2 - n3) + 
           4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
           c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)) + 
        l2*n2*(-(c2*d2*g*(m2 + m3)*(n2 - n3)) - 4*c2^3*kw2*l2^2*n3 - 
          g*l2*(m2 + m3)*n3 + c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
       (c2*I1x*l2^3), ((-4*c2*l2*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*
          (c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
           g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
             g*(m2 + m3)*n3)))/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)) + (4*l2*(c2*d3*g*l2^3*m3*(l3^2 - (n4 - n5)^2) + 
           4*c2*c3^2*kw3*l2^3*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(-(g*(m2 + m3)*(l2^2 - (n2 - n3)^2)) - 4*c2*kw2*l2*
                (n2 - n3)^2) + c2*l2*(4*c2*kw2*l2*l3^2*(n2 - n3)*n3 + 4*d3*
                kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*(n2 - n3)*n3) + 
                 l2^2*m3*n4*(-n4 + n5))))))/(c3*l3^3))/(4*c2*l2^4*m2), 
      (-((c2*d2*g*(m2 + m3)*(n2 - n3) + 4*c2^3*kw2*l2^2*n3 + 
            g*l2*(m2 + m3)*n3 - c2^2*l2*(4*d2*kw2*(n2 - n3) + 
              g*(m2 + m3)*n3))^2/(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) + (4*c2*c3^3*kw3*l2^3*l3^3*n4^2 + 
          c2*c3^2*l2^3*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
          c2*g*l2^3*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
          c3*l3*(d2^2*l3^2*(g*(m2 + m3)*(l2^2 - (n2 - n3)^2) + 
              4*c2*kw2*l2*(n2 - n3)^2) + c2*d2*l2*l3^2*
             (8*c2*kw2*l2*n3*(-n2 + n3) + g*(m2 + m3)*(l2^2 + 2*(n2 - n3)*
                 n3)) + l2^2*(g*l3^2*(m2 + m3)*n2*n3 + 4*c2^3*kw2*l2*l3^2*n3^
                2 - c2^2*g*l3^2*(m2 + m3)*n3^2 + c2*d3*l2*(4*d3*kw3*
                 (n4 - n5)^2 + g*m3*(l3^2 + 2*n4*(-n4 + n5))))))/(c3*l3^3))/
       (c2*I2x*l2^3), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*l3^3*m3), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I3x*l3^3)}, 
     {0, 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m2), (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/
       (c3*I2x*l3^3), (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/
       (c3*l3^3*m3), (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
          4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/
       (c3*I3x*l3^3)}, {0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 
      (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
          c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
        l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
          c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5)))/(c3*I2x*l3^3), 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 
      (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
        l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
        c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + g*m3*(l3^2 + 2*(n4 - n5)*n5)))/
       (c3*I3x*l3^3)}}
 
cxsmtr = {{0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
         2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)), 0, 0, 0, 
      -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2)}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmtr = {{0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
           2*c1*kw1*l1*(n0 - n1)^2)/(c1*l1^3)) + 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (2*l1^4*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*(-2*c1^3*kw1*l1*n0 + 
           c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*n1))/
         (4*c1*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(4*c1*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {0, ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 
            2*c1*kw1*l1*(n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*
           (n0 - n1)*n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          (n0 - n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(2*c1*l1^4*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       I1x, 0, 0, 0, (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1)*(c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 
            2*c1^3*kw1*l1^2*n1 + g*l1*(m1 + m2 + m3)*n1 - 
            c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/
         (4*c1^2*l1^3*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
           g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(4*c1^2*l1^3*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) + 
        (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
           g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
             g*(m1 + m2 + m3)*n1)))/(c1*l1^2))/I1x}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmy = {{I1z, 0, 0}, {0, I2z, 0}, {0, 0, I3z}}
 
I1z /: I1z::usage = "I1z is z-axis MOI of second top mass (mass U)."
 
I2z /: I2z::usage = "I2z is z-axis MOI of intermediate mass (mass I)."
 
I3z /: I3z::usage = "I3z is z-axis MOI of optic."
 
xmy = {{(g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 0}, 
     {(-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3)}, 
     {0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3)}}
 
cqxmy = {{0, 0, 0}, {0, 0, 0}, {-((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 0}, 
     {-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}, 
     {(c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 0}}
 
amy = {{((g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
        (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
        (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2))/I1z, 
      ((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2*si^2)/
         (2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) - 
        (2*((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I2z, 0}, {((-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - (2*((c2*kw2*(n2 - n3)*si)/l2 - 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))*
          (-((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (2*((c2*kw2*(-n2 + n3)*si)/l2 - 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))*
          (-((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/
            (4*l2^2)))/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) + (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/
         (2*c2*l2))/I1z, ((2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + 
        (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/
         (2*c2*l2^3) - ((c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/
            (4*l2^2))^2/(kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
          (c2*g*(m2 + m3))/(4*l2)) - (-((c2*kw2*(n2 - n3)*si)/l2) + 
           (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) - 
        ((c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/
         (kblz + c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/
           (4*l2)) - (-((c2*kw2*(-n2 + n3)*si)/l2) + 
           (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2))^2/(kblz + c2^2*kw2 + 
          (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2)) + 
        (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
        (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
        (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I2z, 
      ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - 
        (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + (g*m3*(-n4 + n5)^2*sl^2)/
         (2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/(2*c3*l3))/I3z}, 
     {0, ((-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + (g*m3*(n4 - n5)^2*sl^2)/
         (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
        (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
         (2*c3*l3))/I2z, ((2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
        (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/
         l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
        (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
        (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3))/I3z}}
 
cxsmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bmy = {{0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*I1z*l1)), 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
kmv = {{m1, 0, 0}, {0, m2, 0}, {0, 0, m3}}
 
xmv = {{2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
       (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
       (c1*g*(m1 + m2 + m3))/l1, -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 0}, {-4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + 
       (c2*g*(m2 + m3))/l2, 4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - 
       (c3*g*m3)/l3 + (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3}, 
     {0, -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3}}
 
cqxmv = {{-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + 
       (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0}, 
     {-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}, {c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + 
       (c2*g*(m2 + m3))/(4*l2), 0}}
 
amv = {{(2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0}, {(-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3}, {0, (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3}}
 
cxsmv = {{0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
 
bmv = {{0, 0, (-2*kbuz*(2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
         c1^2*g*(m1 + m2 + m3)))/(m1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
         g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))), 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
km = {{m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, m1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1z, I1yz, I1zx, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1yz, I1y, I1xy, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, I1zx, I1xy, I1x, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, m2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2z, I2yz, I2zx, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2yz, I2y, I2xy, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, I2zx, I2xy, I2x, 0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3z, I3yz, I3zx}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3yz, I3y, I3xy}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, I3zx, I3xy, I3x}}
 
xm = {{(g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1), 0, 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 
      -((g*(m2 + m3))/(c2*l2)), 0, 0, 0, -((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      0, 0, 0, 0, 0}, {0, (g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/
        (c1*l1) + (kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/
        (2*c1*l1^3) + (kw1*(-n0 + n1)^2)/l1^2 - 
       (g*(m1 + m2 + m3)*(-n0 + n1)^2)/(2*c1*l1^3) + (2*kw2*(n2 - n3)^2)/
        l2^2 - (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + 
       (2*kw2*(-n2 + n3)^2)/l2^2 - (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      -((c1*kw1*(n0 - n1))/l1) + (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - 
       (c1*kw1*(-n0 + n1))/l1 + (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - 
       (2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      -((g*(m2 + m3))/(c2*l2)) - (2*kw2*(n2 - n3)^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2)/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), (2*c2*kw2*(n2 - n3))/l2 - 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + (2*c2*kw2*(-n2 + n3))/l2 - 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      0, 0, 0, 0, 0, 0}, {0, -((c1*kw1*(n0 - n1))/l1) + 
       (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2) - (c1*kw1*(-n0 + n1))/l1 + 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2) - (2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 2*c1^2*kw1 + 4*c2^2*kw2 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/
        (c1*l1) - (c1*g*(m1 + m2 + m3))/l1, 0, 0, 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, 0, 0, (g*(m1 + m2 + m3)*(2*(n0 - n1)*n1 + 2*n1^2))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(2*n1^2 - 2*n1*(-n0 + n1)))/(4*c1*l1) + 
       (2*kw2*(n2 - n3)^2*si^2)/l2^2 - (g*(m2 + m3)*(n2 - n3)^2*si^2)/
        (2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*n2^2 - 2*n2*(n2 - n3) + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n2^2 + 2*n2*(-n2 + n3) + 2*si^2))/(4*c2*l2), 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, 0, 0, 0}, {-((d1*g*(m2 + m3))/(c2*l2)) + 
       (d0*g*(m1 + m2 + m3))/(c1*l1), 0, 0, 
      (g*(m1 + m2 + m3)*(2*d0*(n0 - n1) + 2*d0*n1))/(4*c1*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*n1 + 2*d0*(-n0 + n1)))/(4*c1*l1) + 
       (g*(m2 + m3)*(-2*d1*n2 + 2*d1*(n2 - n3)))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*d1*n2 + 2*d1*(-n2 + n3)))/(4*c2*l2) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), (g*(2*d0^2 + 2*c1*d0*l1)*(m1 + m2 + m3))/(2*c1*l1) + 
       4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*si^2))/(2*c2*l2), 0, 
      (d1*g*(m2 + m3))/(c2*l2), 0, 0, (-2*c2*kw2*(n2 - n3)*si^2)/l2 + 
       (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - (2*c2*kw2*(-n2 + n3)*si^2)/
        l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/(2*l2^2), 
      -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 0, 0, 0, 0, 0, 0}, 
     {0, (d1*g*(m2 + m3))/(c2*l2) - (d0*g*(m1 + m2 + m3))/(c1*l1) + 
       (kw1*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1^2) - 
       (g*(m1 + m2 + m3)*(n0 - n1)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/
        (4*c1*l1^3) + (kw1*(-n0 + n1)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/
        (2*l1^2) - (g*(m1 + m2 + m3)*(-n0 + n1)*(-2*c1*l1*n1 - 
          2*d0*(-n0 + n1)))/(4*c1*l1^3) - (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 + (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) - (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 + (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -(c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2) - 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) + 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1)^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*(n0 - n1)*n1 + 2*n1^2))/
        (4*c1*l1) + (kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(4*l1^2) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1))^2)/(8*c1*l1^3) + 
       (g*(m1 + m2 + m3)*(2*d0^2 + 2*c1*d0*l1 + 2*n1^2 - 2*n1*(-n0 + n1)))/
        (4*c1*l1) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 - 2*n2*(n2 - n3)))/
        (4*c2*l2) + (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1^2 + 2*c2*d1*l2 + 2*n2^2 + 2*n2*(-n2 + n3)))/
        (4*c2*l2), 0, -((d1*g*(m2 + m3))/(c2*l2)) + 
       (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/l2^2 - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(n2 - n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2)), 0, 0, 0, (d1*g*(m2 + m3))/(c2*l2), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2), 0, 0, 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, -((g*m3)/(c3*l3)), 
      0, 0, 0, -((d4*g*m3)/(c3*l3)), 0}, {0, -((g*(m2 + m3))/(c2*l2)) - 
       (2*kw2*(n2 - n3)^2)/l2^2 + (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) - 
       (2*kw2*(-n2 + n3)^2)/l2^2 + (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3), 
      (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 0, 0, 
      -((d1*g*(m2 + m3))/(c2*l2)) + (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/l2^2 - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (n2 - n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(2*c2*l2*n2 - 
          2*d1*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*c2*l2^3), 0, 
      (g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2) + (2*kw2*(n2 - n3)^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2)/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)^2)/(2*c2*l2^3) + (2*kw3*(n4 - n5)^2)/l3^2 - 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (-2*c2*kw2*(n2 - n3))/l2 + 
       (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - (2*c2*kw2*(-n2 + n3))/l2 + 
       (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - (2*c3*kw3*(n4 - n5))/l3 + 
       (g*m3*(n4 - n5))/(2*l3^2) - (2*c3*kw3*(-n4 + n5))/l3 + 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, (d3*g*m3)/(c3*l3) - 
       (d2*g*(m2 + m3))/(c2*l2) + (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/l2^2 - (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 
          2*c2*l2*n3))/(4*c2*l2^3) + (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 
          2*d2*(-n2 + n3)))/l2^2 - (g*(m2 + m3)*(-n2 + n3)*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      (d4*g*m3)/(c3*l3) - (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 + (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, (2*c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(2*l2^2), 
      -4*c2^2*kw2 - (g*(m2 + m3))/(c2*l2) + (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/l2) + 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(4*l2^2) - 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(4*l2^2), 0, 
      (-2*c2*kw2*(n2 - n3))/l2 + (g*(m2 + m3)*(n2 - n3))/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3))/l2 + (g*(m2 + m3)*(-n2 + n3))/(2*l2^2) - 
       (2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
       (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2, 0, 0, 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (2*c3*kw3*(n4 - n5))/l3 - (g*m3*(n4 - n5))/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5))/l3 - (g*m3*(-n4 + n5))/(2*l3^2), 
      -4*c3^2*kw3 - (g*m3)/(c3*l3) + (c3*g*m3)/l3, 0, 0, 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, (-2*kw2*(n2 - n3)^2*si^2)/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) - (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 + (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(-2*n2*n3 - 2*si^2))/(2*c2*l2), 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), 0, 0, 0, 0, (2*kw2*(n2 - n3)^2*si^2)/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)^2*si^2)/(2*c2*l2^3) + (2*kw2*(-n2 + n3)^2*si^2)/
        l2^2 - (g*(m2 + m3)*(-n2 + n3)^2*si^2)/(2*c2*l2^3) + 
       (g*(m2 + m3)*(2*(n2 - n3)*n3 + 2*n3^2 + 2*si^2))/(4*c2*l2) + 
       (g*(m2 + m3)*(2*n3^2 - 2*n3*(-n2 + n3) + 2*si^2))/(4*c2*l2) + 
       (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + 
       (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - (g*m3*(-n4 + n5)^2*sl^2)/
        (2*c3*l3^3) + (g*m3*(2*n4^2 - 2*n4*(n4 - n5) + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n4^2 + 2*n4*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0}, {-((d2*g*(m2 + m3))/(c2*l2)), 0, 0, 
      (-2*c2*kw2*(n2 - n3)*si^2)/l2 + (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) - 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 + (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2), -4*c2^2*kw2*si^2 + (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d1*d2 - 2*si^2))/(2*c2*l2), 0, 
      -((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2), 0, 0, 
      (g*(m2 + m3)*(2*d2*(n2 - n3) + 2*d2*n3))/(4*c2*l2) + 
       (g*(m2 + m3)*(-2*d2*n3 + 2*d2*(-n2 + n3)))/(4*c2*l2) + 
       (g*m3*(-2*d3*n4 + 2*d3*(n4 - n5)))/(4*c3*l3) + 
       (g*m3*(2*d3*n4 + 2*d3*(-n4 + n5)))/(4*c3*l3) + 
       (2*c2*kw2*(n2 - n3)*si^2)/l2 - (g*(m2 + m3)*(n2 - n3)*si^2)/(2*l2^2) + 
       (2*c2*kw2*(-n2 + n3)*si^2)/l2 - (g*(m2 + m3)*(-n2 + n3)*si^2)/
        (2*l2^2) + (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) + (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 4*c2^2*kw2*si^2 - (c2*g*(m2 + m3)*si^2)/l2 + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*si^2))/(2*c2*l2) + 
       4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*sl^2))/(2*c3*l3), 0, (d3*g*m3)/(c3*l3), 
      0, 0, (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0}, {0, (d2*g*(m2 + m3))/(c2*l2) - 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 + 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) - 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 + 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3), 
      (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2 - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2), 0, 0, 
      (kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2^2) - (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3))*
         (-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d1*d2 - 2*n2*n3))/(2*c2*l2) + 
       (kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2^2) - (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3))*
         (-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*c2*l2^3), 0, 
      (d3*g*m3)/(c3*l3) - (d2*g*(m2 + m3))/(c2*l2) + 
       (kw2*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2^2 - 
       (g*(m2 + m3)*(n2 - n3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*c2*l2^3) + 
       (kw2*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2^2 - 
       (g*(m2 + m3)*(-n2 + n3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*c2*l2^3) - 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/l2) + 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(4*l2^2) - 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/l2 + 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(4*l2^2) + 
       (c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) + 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3)^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*(n2 - n3)*n3 + 2*n3^2))/
        (4*c2*l2) + (kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(2*l2^2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3))^2)/(8*c2*l2^3) + 
       (g*(m2 + m3)*(2*d2^2 + 2*c2*d2*l2 + 2*n3^2 - 2*n3*(-n2 + n3)))/
        (4*c2*l2) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 - 2*n4*(n4 - n5)))/(4*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d3^2 + 2*c3*d3*l3 + 2*n4^2 + 2*n4*(-n4 + n5)))/(4*c3*l3), 0, 
      -((d3*g*m3)/(c3*l3)) + (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/
        l3^2 - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)), 0, 0, 0, (d3*g*m3)/(c3*l3), 0, 
      (g*m3)/(c3*l3), 0, 0, 0, (d4*g*m3)/(c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3)) - (2*kw3*(n4 - n5)^2)/l3^2 + 
       (g*m3*(n4 - n5)^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2)/(2*c3*l3^3), (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, -((d3*g*m3)/(c3*l3)) + 
       (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/l3^2 - 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(n4 - n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*c3*l3^3), 0, 
      (g*m3)/(c3*l3) + (2*kw3*(n4 - n5)^2)/l3^2 - (g*m3*(n4 - n5)^2)/
        (2*c3*l3^3) + (2*kw3*(-n4 + n5)^2)/l3^2 - (g*m3*(-n4 + n5)^2)/
        (2*c3*l3^3), (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 0, 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3)}, 
     {0, 0, 0, 0, 0, 0, 0, (2*c3*kw3*(n4 - n5))/l3 - 
       (g*m3*(n4 - n5))/(2*l3^2) + (2*c3*kw3*(-n4 + n5))/l3 - 
       (g*m3*(-n4 + n5))/(2*l3^2), -4*c3^2*kw3 - (g*m3)/(c3*l3) + 
       (c3*g*m3)/l3, 0, 0, -((c3*kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/l3) + 
       (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5)))/(4*l3^2) - 
       (c3*kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/l3 + 
       (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5)))/(4*l3^2), 0, 
      (-2*c3*kw3*(n4 - n5))/l3 + (g*m3*(n4 - n5))/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5))/l3 + (g*m3*(-n4 + n5))/(2*l3^2), 
      4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3, 0, 0, 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2)}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, (-2*kw3*(n4 - n5)^2*sl^2)/l3^2 + 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) - (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 + 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + (g*m3*(-2*n4*n5 - 2*sl^2))/
        (2*c3*l3), (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/
        (2*l3^2) - (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/
        (2*l3^2), 0, 0, 0, 0, (2*kw3*(n4 - n5)^2*sl^2)/l3^2 - 
       (g*m3*(n4 - n5)^2*sl^2)/(2*c3*l3^3) + (2*kw3*(-n4 + n5)^2*sl^2)/l3^2 - 
       (g*m3*(-n4 + n5)^2*sl^2)/(2*c3*l3^3) + 
       (g*m3*(2*(n4 - n5)*n5 + 2*n5^2 + 2*sl^2))/(4*c3*l3) + 
       (g*m3*(2*n5^2 - 2*n5*(-n4 + n5) + 2*sl^2))/(4*c3*l3), 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 0}, 
     {0, 0, 0, 0, 0, 0, -((d4*g*m3)/(c3*l3)), 0, 0, 
      (-2*c3*kw3*(n4 - n5)*sl^2)/l3 + (g*m3*(n4 - n5)*sl^2)/(2*l3^2) - 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 + (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      -4*c3^2*kw3*sl^2 + (c3*g*m3*sl^2)/l3 + (g*m3*(2*d3*d4 - 2*sl^2))/
        (2*c3*l3), 0, (d4*g*m3)/(c3*l3), 0, 0, 
      (g*m3*(2*d4*(n4 - n5) + 2*d4*n5))/(4*c3*l3) + 
       (g*m3*(-2*d4*n5 + 2*d4*(-n4 + n5)))/(4*c3*l3) + 
       (2*c3*kw3*(n4 - n5)*sl^2)/l3 - (g*m3*(n4 - n5)*sl^2)/(2*l3^2) + 
       (2*c3*kw3*(-n4 + n5)*sl^2)/l3 - (g*m3*(-n4 + n5)*sl^2)/(2*l3^2), 
      4*c3^2*kw3*sl^2 - (c3*g*m3*sl^2)/l3 + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*sl^2))/(2*c3*l3), 0}, 
     {0, 0, 0, 0, 0, 0, 0, (d4*g*m3)/(c3*l3) - 
       (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3^2 + 
       (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) - 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 + 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      (c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3 - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) + 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        (2*l3^2) - (g*m3*(-2*c3*l3*n4 - 2*d3*(n4 - n5))*(-2*d4*(n4 - n5) + 
          2*c3*l3*n5))/(8*c3*l3^3) + (g*m3*(2*d3*d4 - 2*n4*n5))/(2*c3*l3) + 
       (kw3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/
        (2*l3^2) - (g*m3*(2*c3*l3*n4 - 2*d3*(-n4 + n5))*
         (-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(8*c3*l3^3), 0, 
      -((d4*g*m3)/(c3*l3)) + (kw3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/
        l3^2 - (g*m3*(n4 - n5)*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*c3*l3^3) + 
       (kw3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3^2 - 
       (g*m3*(-n4 + n5)*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*c3*l3^3), 
      -((c3*kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/l3) + 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5))/(4*l3^2) - 
       (c3*kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/l3 + 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5)))/(4*l3^2), 0, 0, 
      (kw3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(2*l3^2) - 
       (g*m3*(-2*d4*(n4 - n5) + 2*c3*l3*n5)^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*(n4 - n5)*n5 + 2*n5^2))/(4*c3*l3) + 
       (kw3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(2*l3^2) - 
       (g*m3*(-2*c3*l3*n5 - 2*d4*(-n4 + n5))^2)/(8*c3*l3^3) + 
       (g*m3*(2*d4^2 + 2*c3*d4*l3 + 2*n5^2 - 2*n5*(-n4 + n5)))/(4*c3*l3)}}
 
cqxm = {{0, (c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2), 
      -(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
        (2*l1), 0, 0, (g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, (c1*kw1*(-n0 + n1))/l1 - 
       (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2), -(c1^2*kw1) - 
       (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1), 0, 0, 
      -(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
       (c1*kw1*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(2*l1) - 
       (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*(-n0 + n1)))/(4*l1^2), 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + 
       (g*(m2 + m3)*(n2 - n3))/(4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), -((c2*kw2*(n2 - n3)*si)/l2) + 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), -(c2^2*kw2*si) - 
       (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(n2 - n3)*si)/l2 - (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/
        (2*l2) - (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 
      0, 0, 0, 0}, {0, -((c2*kw2*(n2 - n3))/l2) + (g*(m2 + m3)*(n2 - n3))/
        (4*l2^2), c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - 
       (c2*g*(m2 + m3))/(4*l2), (c2*kw2*(n2 - n3)*si)/l2 - 
       (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), c2^2*kw2*si + 
       (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(-2*n2 + 2*(n2 - n3)))/(8*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n2 - 2*d1*(n2 - n3)))/(8*l2^2), 0, 
      (c2*kw2*(n2 - n3))/l2 - (g*(m2 + m3)*(n2 - n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(n2 - n3)*si)/l2) + (g*(m2 + m3)*(n2 - n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(2*l2) - 
       (g*(m2 + m3)*(-2*d2*(n2 - n3) + 2*c2*l2*n3))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}, {0, -((c2*kw2*(-n2 + n3))/l2) + (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      c2^2*kw2 + (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      -(g*(m2 + m3)*n3)/(4*c2*l2) + (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/
        (2*l2) - (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 
      0, 0, 0, 0, 0}, {0, -((c2*kw2*(-n2 + n3))/l2) + 
       (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), c2^2*kw2 + 
       (g*(m2 + m3))/(4*c2*l2) - (c2*g*(m2 + m3))/(4*l2), 
      (c2*kw2*(-n2 + n3)*si)/l2 - (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      c2^2*kw2*si + (g*(m2 + m3)*si)/(4*c2*l2) - (c2*g*(m2 + m3)*si)/(4*l2), 
      (g*(m2 + m3)*(2*n2 + 2*(-n2 + n3)))/(8*c2*l2) + 
       (c2*kw2*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(2*c2*l2*n2 - 2*d1*(-n2 + n3)))/(8*l2^2), 0, 
      (c2*kw2*(-n2 + n3))/l2 - (g*(m2 + m3)*(-n2 + n3))/(4*l2^2), 
      -(c2^2*kw2) - (g*(m2 + m3))/(4*c2*l2) + (c2*g*(m2 + m3))/(4*l2), 
      -((c2*kw2*(-n2 + n3)*si)/l2) + (g*(m2 + m3)*(-n2 + n3)*si)/(4*l2^2), 
      -(c2^2*kw2*si) - (g*(m2 + m3)*si)/(4*c2*l2) + (c2*g*(m2 + m3)*si)/
        (4*l2), -(g*(m2 + m3)*n3)/(4*c2*l2) + 
       (c2*kw2*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(2*l2) - 
       (g*(m2 + m3)*(-2*c2*l2*n3 - 2*d2*(-n2 + n3)))/(8*l2^2), 0, 0, 0, 0, 0, 
      0}}
 
am = {{((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((-(I1x*I1z) + I1zx^2)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      ((I1xy*I1z - I1yz*I1zx)*(-((d1*g*(m2 + m3))/(c2*l2)) + 
         (d0*g*(m1 + m2 + m3))/(c1*l1)))/(I1xy^2*I1z + 
        I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2), 
      -((g*(m2 + m3))/(c2*l2*m2)), 0, 0, 
      -((d2*g*(I2x*I2yz - I2xy*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), (d2*g*(I2x*I2z - I2zx^2)*(m2 + m3))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2), -((d2*g*(I2xy*I2z - I2yz*I2zx)*(m2 + m3))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2)), 0, 0, 0, 0, 0, 0}, 
     {0, ((g*(m2 + m3))/(c2*l2) + (g*(m1 + m2 + m3))/(c1*l1) + 
        (2*kw1*(n0 - n1)^2)/l1^2 - (g*(m1 + m2 + m3)*(n0 - n1)^2)/(c1*l1^3) - 
        (c1*(-2*c1*kw1*l1 + g*(m1 + m2 + m3))^2*(n0 - n1)^2)/
         (l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))) + (4*kw2*(n2 - n3)^2)/l2^2 - 
        (g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m1, 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((4*d1*g*(m2 + m3))/(c2*l2) - (4*d0*g*(m1 + m2 + m3))/(c1*l1) + 
         (8*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - 
         (4*g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/
          (c1*l1^3) - (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1xy*I1z - I1yz*I1zx)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 
      ((I1yz^2 - I1y*I1z)*((4*d1*g*(m2 + m3))/(c2*l2) - 
         (4*d0*g*(m1 + m2 + m3))/(c1*l1) + (8*kw1*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/l1^2 - (4*g*(m1 + m2 + m3)*(n0 - n1)*
           (c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) - 
         (4*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (16*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 - 
         (4*g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) - 
         (4*(4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3)))))/(4*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)), 0, 
      (-4*c2^3*g*kw2*l2^3*(m2 + m3) - g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
        4*c2*g*l2*(m2 + m3)*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (-(d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) - 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2xy*I2z - I2yz*I2zx)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
          (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
         c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
           4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
          (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {0, 0, (2*c1^2*kw1 + 4*c2^2*kw2 + (g*(m2 + m3))/(c2*l2) - 
        (c2*g*(m2 + m3))/l2 + (g*(m1 + m2 + m3))/(c1*l1) - 
        (c1*g*(m1 + m2 + m3))/l1 - (4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))^2/(c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
           g*(m2 + m3) - c2^2*g*(m2 + m3))) - 
        (2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))^2/
         (c1*l1*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))))/m1, 0, 0, 0, 0, 0, 
      (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))/
       (m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
      ((I1xy^2 - I1x*I1y)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I1x*I1yz - I1xy*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
         c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
           4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
            (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
         c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
           4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + l2^2*
                (n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
         I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
        (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1xy*I1yz - I1y*I1zx)*(4*c2^4*g*kw2*l2^4*(m1 + m2 + m3)*n0*n1 - 
          c2^3*g*l2^3*(m2 + m3)*(g*(m1 + m2 + m3)*n0*n1 - 
            4*c1*kw2*l1*(n2*n3 + si^2)) + c1*g^2*l1*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-4*g*kblz*l2^2*(m1 + m2 + m3)*n0*n1 - 16*c1*kblz*kw2*l1*
             (n2 - n3)^2*si^2 + c1*g^2*l1*(m2 + m3)^2*(n2*n3 + si^2)) + 
          c2*g*l2*(m2 + m3)*(g*l2^2*(m1 + m2 + m3)*n0*n1 + 
            4*c1*l1*(kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
                l2^2*(n2*n3 + si^2))))))/(c1*c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      0, 0, 0, -(((I2xy^2 - I2x*I2y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*
           (n2*n3 + si^2) + g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
            l2^2*(n2*n3 + si^2)) - c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + 
            g^2*(m2 + m3)^2*(n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*
           (kw2*(n2 - n3)^2*si^2 + kblz*(-((n2 - n3)^2*si^2) + 
              l2^2*(n2*n3 + si^2)))))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      -(((I2x*I2yz - I2xy*I2zx)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2yz - I2y*I2zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 0}, 
     {(-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1))/m1, 0, 0, 
      ((I1x*I1yz - I1xy*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I1x*I1z - I1zx^2)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
          c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
             (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
              d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
            c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
              4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
            c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
              4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
          2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 
          4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1xy*I1z - I1yz*I1zx)*(c1*d1^2*g^2*l1*(m2 + m3)^2 + 
         c2^2*g*(4*d0^2*kblz*l2^2*(m1 + m2 + m3) + 4*c1*d0*kblz*l1*l2^2*
            (m1 + m2 + m3) - c1*d1*l1*(m2 + m3)*(-4*kblz*l2^2 + 
             d1*g*(m2 + m3))) + 4*c2^4*kw2*l2^2*(d0^2*g*(m1 + m2 + m3) + 
           c1*d0*g*l1*(m1 + m2 + m3) + c1*l1*(d1*g*(m2 + m3) + 
             4*kblz*si^2)) + c2*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(4*d1^2*kblz + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2)) - c2^3*g*l2*(m2 + m3)*(d0^2*g*(m1 + m2 + m3) + 
           c1*l1*(-4*d1^2*kw2 + d1*g*(m2 + m3) + d0*g*(m1 + m2 + m3) + 
             4*kblz*si^2))))/(c1*c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l1*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + 
         g*(m2 + m3) - c2^2*g*(m2 + m3))), (d1*g*(m2 + m3))/(c2*l2*m2), 0, 0, 
      -(((I2x*I2yz - I2xy*I2zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I2xy^2*I2z + 
          I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I2x*I2z - I2zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {0, -((-((d1*g*(m2 + m3))/(c2*l2)) + (d0*g*(m1 + m2 + m3))/(c1*l1) - 
         (2*kw1*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/l1^2 + 
         (g*(m1 + m2 + m3)*(n0 - n1)*(c1*l1*n1 + d0*(-n0 + n1)))/(c1*l1^3) + 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(l1^3*(2*c1*kbuz*l1 + 2*c1^3*kw1*l1 + 
            g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) - 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/l2^2 + 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))*(n2 - n3))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(4*c2^3*kw2*l2^2*n2 + 
            c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - n3)) - 
            c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))))/m1), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        ((g*(m1 + m2 + m3)*(d0^2 + c1*d0*l1 + n0*n1))/(c1*l1) + 
         (2*kw1*(c1*l1*n1 + d0*(-n0 + n1))^2)/l1^2 - 
         (g*(m1 + m2 + m3)*(c1*l1*n1 + d0*(-n0 + n1))^2)/(c1*l1^3) - 
         (c1*d0*g*(m1 + m2 + m3)*(n0 - n1) + 2*c1^3*kw1*l1^2*n1 + 
            g*l1*(m1 + m2 + m3)*n1 - c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1))^2/(c1*l1^3*(2*c1*kbuz*l1 + 
            2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))) + 
         (4*kw2*(c2*l2*n2 + d1*(n2 - n3))^2)/l2^2 - 
         (g*(m2 + m3)*(c2*l2*n2 + d1*(n2 - n3))^2)/(c2*l2^3) - 
         (4*c2^3*kw2*l2^2*n2 + c2^2*l2*(-(g*(m2 + m3)*n2) + 4*d1*kw2*(n2 - 
                n3)) - c2*d1*g*(m2 + m3)*(n2 - n3) + g*l2*(m2 + m3)*n3)^2/
          (c2*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) + (g*(m2 + m3)*(d1^2 + c2*d1*l2 + n2*n3))/
          (c2*l2)))/(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), 0, (-4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
          4*kblz*n2*(n2 - n3)) - d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 
        c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
            kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) + 
        c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
          4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3))))/
       (c2*l2^3*m2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I2xy*I2yz - I2y*I2zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I2xy*I2z - I2yz*I2zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I2yz^2 - I2y*I2z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 0, 0, 0}, 
     {-((g*(m2 + m3))/(c2*l2*m1)), 0, 0, (d1*g*(I1x*I1yz - I1xy*I1zx)*
        (m2 + m3))/(c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 
         2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2), 
      (d1*g*(-(I1x*I1z) + I1zx^2)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), (d1*g*(I1xy*I1z - I1yz*I1zx)*(m2 + m3))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2), ((g*m3)/(c3*l3) + (g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/
          (c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
        I2y*I2zx^2), ((-(I2x*I2z) + I2zx^2)*(-((d3*g*m3)/(c3*l3)) + 
         (d2*g*(m2 + m3))/(c2*l2)))/(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
        2*I2xy*I2yz*I2zx + I2y*I2zx^2), ((I2xy*I2z - I2yz*I2zx)*
        (-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2)))/
       (I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + I2y*I2zx^2), 
      -(g/(c3*l3)), 0, 0, -((d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), (d4*g*(I3x*I3z - I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -((d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3))}, {0, (-4*c2^3*g*kw2*l2^3*(m2 + m3) - 
        g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 4*c2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
        c2^2*l2^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
         d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
          (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
          (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
           4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 4*kblz*n2*(n2 - n3)) + 
          d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - c2*g*l2*(m2 + m3)*
           (-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            g*(m2 + m3)*(n2 - n3)^2) - c2^2*l2^2*
           (d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(4*c2^3*kw2*l2^3*(d1*g*(m2 + m3) + 
            4*kblz*n2*(n2 - n3)) + d1*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) - 
          c2*g*l2*(m2 + m3)*(-4*d1*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + g*(m2 + m3)*(n2 - n3)^2) - 
          c2^2*l2^2*(d1*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
            4*g*(m2 + m3)*(n2 - n3)*(kblz*n2 + kw2*(-n2 + n3)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, ((2*g*m3)/(c3*l3) + 
        (2*g*(m2 + m3))/(c2*l2) + (8*kw2*(n2 - n3)^2)/l2^2 - 
        (2*g*(m2 + m3)*(n2 - n3)^2)/(c2*l2^3) - 
        (2*c2*(-4*c2*kw2*l2 + g*(m2 + m3))^2*(n2 - n3)^2)/
         (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))) + (8*kw3*(n4 - n5)^2)/l3^2 - 
        (2*g*m3*(n4 - n5)^2)/(c3*l3^3))/(2*m2), 0, 
      -(((I2xy*I2yz - I2y*I2zx)*(-(c3*d2*g^2*l3^3*(m2 + m3)^2*
            (l2^2 - (n2 - n3)^2)) + 4*c2^4*kw2*l2^4*
           (d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
            c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - c2*g*l2*(m2 + m3)*
           (d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 4*c3^2*kw3*l2^2*l3^2*n4*
             (-n4 + n5) + c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + 
                kw2*(n2 - n3)^2) + l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) - c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*
             (l3^2 - (n4 - n5)^2) + 4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*
             (n4 - n5) + c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(
                n2 - n3)*n3 - g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*
                 (-n4 + n5)))) + c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*
             (l3^2 - (n4 - n5)^2) + 16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
            c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
              4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                    (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (-(c3*d2*g^2*l3^3*(m2 + m3)^2*(l2^2 - (n2 - n3)^2)) + 
         4*c2^4*kw2*l2^4*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*
              (n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5)) - 
         c2*g*l2*(m2 + m3)*(d3*g*l2^2*m3*(-l3^2 + (n4 - n5)^2) + 
           4*c3^2*kw3*l2^2*l3^2*n4*(-n4 + n5) + 
           c3*l3*(4*d2*l3^2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) - 
         c2^3*l2^3*(d3*g^2*m3*(m2 + m3)*(l3^2 - (n4 - n5)^2) + 
           4*c3^2*g*kw3*l3^2*(m2 + m3)*n4*(n4 - n5) + 
           c3*l3*(4*d2*g*kw2*l3^2*(m2 + m3) - 16*kblz*kw2*l3^2*(n2 - n3)*n3 - 
             g*(m2 + m3)*(n4 - n5)*(g*m3*n4 + 4*d3*kw3*(-n4 + n5)))) + 
         c2^2*l2^2*(4*d3*g*kblz*l2^2*m3*(l3^2 - (n4 - n5)^2) + 
           16*c3^2*kblz*kw3*l2^2*l3^2*n4*(n4 - n5) + 
           c3*l3*(d2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) + 
             4*kblz*(4*d3*kw3*l2^2*(n4 - n5)^2 + g*(-(l3^2*(m2 + m3)*
                   (n2 - n3)*n3) + l2^2*m3*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, (g*m3*(-l3^2 + (n4 - n5)^2) - 
        4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, (-4*kblz*(4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3)))/(m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, 0, 0, 
      (4*c2^2*kw2 + 4*c3^2*kw3 + (g*m3)/(c3*l3) - (c3*g*m3)/l3 + 
        (g*(m2 + m3))/(c2*l2) - (c2*g*(m2 + m3))/l2 - 
        (4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))^2/
         (c2*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
           c2^2*g*(m2 + m3))))/m2, 0, 0, 0, 0, 0, -(g/(c3*l3)) + (c3*g)/l3 - 
       (4*c3^2*kw3)/m3, 0, 0, 0}, {0, 0, 0, 
      -(((I1xy^2 - I1x*I1y)*(4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + 
          g^2*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), -(((I1x*I1yz - I1xy*I1zx)*
         (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
          c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
             (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
            kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I1xy*I1yz - I1y*I1zx)*
        (4*c2^3*g*kw2*l2^3*(m2 + m3)*(n2*n3 + si^2) + g^2*(m2 + m3)^2*
          (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) - 
         c2^2*l2^2*(-16*kblz*kw2*(n2 - n3)^2*si^2 + g^2*(m2 + m3)^2*
            (n2*n3 + si^2)) + 4*c2*g*l2*(m2 + m3)*(kw2*(n2 - n3)^2*si^2 + 
           kblz*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 0, 0, ((I2xy^2 - I2x*I2y)*
        (c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      ((I2x*I2yz - I2xy*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*(-((n2 - n3)^2*si^2) + 
           l2^2*(n2*n3 + si^2)) + c2^3*g*l2^3*(m2 + m3)*
          (4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - kw3*(n4 - n5)^2*sl^2) + 
           g*m3*((n4 - n5)^2*sl^2 - l3^2*(n4*n5 + sl^2))) + 
         4*c2^4*kw2*l2^4*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
           g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))) + 
         c2*g*l2*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + 
             kblz*l3^2*(-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
             kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
             l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
            (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
           c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 
             16*kblz*(kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*
                sl^2)))))/(c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 
         4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3))), 
      -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (-((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
          c2^3*g*l2^3*(m2 + m3)*(4*c3*l3*(kw2*l3^2*(n2*n3 + si^2) - 
              kw3*(n4 - n5)^2*sl^2) + g*m3*((n4 - n5)^2*sl^2 - 
              l3^2*(n4*n5 + sl^2))) + 4*c2^4*kw2*l2^4*
           (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) + c2*g*l2*(m2 + m3)*
           (4*c3*l3*(kw2*l3^2*(n2 - n3)^2*si^2 + kblz*l3^2*(
                -((n2 - n3)^2*si^2) + l2^2*(n2*n3 + si^2)) + 
              kw3*l2^2*(n4 - n5)^2*sl^2) + g*l2^2*m3*(-((n4 - n5)^2*sl^2) + 
              l3^2*(n4*n5 + sl^2))) - c2^2*l2^2*(-4*g*kblz*l2^2*m3*
             (-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2)) + 
            c3*l3*(g^2*l3^2*(m2 + m3)^2*(n2*n3 + si^2) - 16*kblz*(
                kw2*l3^2*(n2 - n3)^2*si^2 + kw3*l2^2*(n4 - n5)^2*sl^2)))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 0, 0, 
      -(((I3xy^2 - I3x*I3y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), -(((I3x*I3yz - I3xy*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3)), 
      ((I3xy*I3yz - I3y*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {-((d2*g*(m2 + m3))/(c2*l2*m1)), 0, 0, 
      -(((I1x*I1yz - I1xy*I1zx)*(-(d1*d2*g^2*(m2 + m3)^2) + 
          c2^2*d1*d2*g^2*(m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 
          4*c2*g*kblz*l2*(m2 + m3)*(d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*
           (d1*d2*kw2 + kblz*si^2)))/(c2*(I1xy^2*I1z + 
          I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + I1y*I1zx^2)*l2*
         (4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - c2^2*g*(m2 + m3)))), 
      ((I1x*I1z - I1zx^2)*(-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*
          (m2 + m3)^2 + 16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
          (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (-(d1*d2*g^2*(m2 + m3)^2) + c2^2*d1*d2*g^2*(m2 + m3)^2 + 
          16*c2^4*kblz*kw2*l2^2*si^2 - 4*c2*g*kblz*l2*(m2 + m3)*
           (d1*d2 - si^2) - 4*c2^3*g*l2*(m2 + m3)*(d1*d2*kw2 + kblz*si^2)))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), (-((d3*g*m3)/(c3*l3)) + 
        (d2*g*(m2 + m3))/(c2*l2))/m2, 0, 0, 
      ((I2x*I2yz - I2xy*I2zx)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
         4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 
      -(((I2x*I2z - I2zx^2)*(c3*d2^2*g^2*l3*(m2 + m3)^2 + 
          4*c2^4*kw2*l2^2*(c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
              4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
            g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
           (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
            4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
          c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
               d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
            4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*d2^2*g^2*l3*(m2 + m3)^2 + 4*c2^4*kw2*l2^2*
          (c3*l3*(d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2*g*l2*(m2 + m3)*(c3*l3*(4*d2^2*kblz + d3*g*m3 + d2*g*(m2 + m3) + 
             4*kblz*si^2) + 4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + 
           g*m3*(d3^2 + sl^2)) - c2^3*g*l2*(m2 + m3)*
          (c3*l3*(-4*d2^2*kw2 + d3*g*m3 + d2*g*(m2 + m3) + 4*kblz*si^2) + 
           4*c3^3*kw3*l3*sl^2 - c3^2*g*m3*sl^2 + g*m3*(d3^2 + sl^2)) + 
         c2^2*(-(c3*g*l3*(-4*d3*kblz*l2^2*m3 - 4*d2*kblz*l2^2*(m2 + m3) + 
              d2^2*g*(m2 + m3)^2)) + 16*c3^3*kblz*kw3*l2^2*l3*sl^2 - 
           4*c3^2*g*kblz*l2^2*m3*sl^2 + 4*g*kblz*l2^2*m3*(d3^2 + sl^2))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2*l3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), (d3*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3x*I3z - I3zx^2)*(-(d3*d4*g*m3) + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3), 
      ((I3xy*I3z - I3yz*I3zx)*(d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + 
           c3^2*g*m3)*sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, 
     {0, (d2*g^2*(m2 + m3)^2*(l2^2 - (n2 - n3)^2) + 4*c2*d2*g*l2*(m2 + m3)*
         (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) - 
        c2^2*l2^2*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
          4*g*kblz*(m2 + m3)*(n2 - n3)*n3) + 4*c2^3*kw2*l2^3*
         (d2*g*(m2 + m3) + 4*kblz*n3*(-n2 + n3)))/
       (c2*l2^3*m1*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, ((I1xy*I1yz - I1y*I1zx)*
        (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
          (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
           d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
         g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
         4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
            (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
             4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
          (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
             4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
            (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
       (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
         I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), -(((I1xy*I1z - I1yz*I1zx)*
         (16*c2^4*kblz*kw2*l2^4*n2*n3 + c2*g*l2*(m2 + m3)*
           (-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
            d2*g*(m2 + m3)*(n2 - n3)^2 + 4*kblz*l2^2*n2*n3) - 
          g^2*(m2 + m3)^2*(d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 
      -(((I1yz^2 - I1y*I1z)*(16*c2^4*kblz*kw2*l2^4*n2*n3 + 
          c2*g*l2*(m2 + m3)*(-4*d1*d2*(kblz*(l2^2 - (n2 - n3)^2) + 
              kw2*(n2 - n3)^2) + d2*g*(m2 + m3)*(n2 - n3)^2 + 
            4*kblz*l2^2*n2*n3) - g^2*(m2 + m3)^2*
           (d1*d2*(l2^2 - (n2 - n3)^2) + l2^2*n3*(-n2 + n3)) - 
          4*c2^3*l2^3*(4*d2*kblz*kw2*n2*(n2 - n3) + g*(m2 + m3)*n3*
             (kblz*n2 - kw2*n2 + kw2*n3) + d1*kw2*(d2*g*(m2 + m3) + 
              4*kblz*n3*(-n2 + n3))) + c2^2*l2^2*
           (d1*(d2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2) - 
              4*g*kblz*(m2 + m3)*(n2 - n3)*n3) - g*(m2 + m3)*(n2 - n3)*
             (g*(m2 + m3)*n3 - 4*d2*(kblz*n2 + kw2*(-n2 + n3))))))/
        (c2*(I1xy^2*I1z + I1x*(I1yz^2 - I1y*I1z) - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), 0, 
      -((-((d3*g*m3)/(c3*l3)) + (d2*g*(m2 + m3))/(c2*l2) - 
         (4*kw2*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/l2^2 + 
         (g*(m2 + m3)*(n2 - n3)*(c2*l2*n3 + d2*(-n2 + n3)))/(c2*l2^3) + 
         ((4*c2*kw2*l2 - g*(m2 + m3))*(n2 - n3)*(c2*d2*g*(m2 + m3)*
             (n2 - n3) + 4*c2^3*kw2*l2^2*n3 + g*l2*(m2 + m3)*n3 - 
            c2^2*l2*(4*d2*kw2*(n2 - n3) + g*(m2 + m3)*n3)))/
          (l2^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
            c2^2*g*(m2 + m3))) - (4*kw3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/
          l3^2 + (g*m3*(c3*l3*n4 + d3*(n4 - n5))*(n4 - n5))/(c3*l3^3))/m2), 
      0, -(((I2xy*I2yz - I2y*I2zx)*(c3*g^2*l3^3*(m2 + m3)^2*
           (d2^2*(l2^2 - (n2 - n3)^2) + l2^2*(n2 - n3)*n3) + 
          4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + c3^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
            g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
              4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
              g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*(
                l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
              4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
          c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
             (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
            c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*(
                kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
              l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5))))) - 
          c2^3*l2^3*(4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
             (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
             n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
            c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
                32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                 (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + 
                d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))))))/
        (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
          c2^2*g*(m2 + m3)))), ((I2xy*I2z - I2yz*I2zx)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), ((I2yz^2 - I2y*I2z)*
        (c3*g^2*l3^3*(m2 + m3)^2*(d2^2*(l2^2 - (n2 - n3)^2) + 
           l2^2*(n2 - n3)*n3) + 4*c2^4*kw2*l2^4*(4*c3^3*kw3*l3^3*n4^2 + 
           c3^2*l3^2*n4*(-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + 
           g*m3*(d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l3^2*(m2 + m3) + 4*kblz*l3^2*n3^2 + 
             4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2^2*l2^2*(16*c3^3*kblz*kw3*l2^2*l3^3*n4^2 + 4*g*kblz*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - 4*c3^2*kblz*l2^2*l3^2*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-(d2^2*l3^2*(g^2*(m2 + m3)^2 - 16*kblz*kw2*(n2 - n3)^2)) - 
             g^2*l3^2*(m2 + m3)^2*(n2 - n3)*n3 + 4*d2*g*kblz*l3^2*(m2 + m3)*
              (l2^2 + 2*(n2 - n3)*n3) + 16*d3^2*kblz*kw3*l2^2*(n4 - n5)^2 + 
             4*d3*g*kblz*l2^2*m3*(l3^2 + 2*n4*(-n4 + n5)))) + 
         c2*g*l2*(m2 + m3)*(4*c3^3*kw3*l2^2*l3^3*n4^2 + c3^2*l2^2*l3^2*n4*
            (-(g*m3*n4) + 8*d3*kw3*(n4 - n5)) + g*l2^2*m3*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) + 
           c3*l3*(d2*g*l2^2*l3^2*(m2 + m3) + 4*d2^2*l3^2*
              (kblz*(l2^2 - (n2 - n3)^2) + kw2*(n2 - n3)^2) + 
             l2^2*(4*kblz*l3^2*n2*n3 + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5))))) - c2^3*l2^3*
          (4*c3^3*g*kw3*l3^3*(m2 + m3)*n4^2 + g^2*m3*(m2 + m3)*
            (d3^2*(l3^2 - (n4 - n5)^2) + l3^2*n4*n5) - c3^2*g*l3^2*(m2 + m3)*
            n4*(g*m3*n4 + 8*d3*kw3*(-n4 + n5)) + 
           c3*l3*(-4*d2^2*g*kw2*l3^2*(m2 + m3) + d2*l3^2*(g^2*(m2 + m3)^2 + 
               32*kblz*kw2*(n2 - n3)*n3) + g*(m2 + m3)*(4*l3^2*n3*
                (kblz*n3 + kw2*(-n2 + n3)) + 4*d3^2*kw3*(n4 - n5)^2 + d3*g*m3*
                (l3^2 + 2*n4*(-n4 + n5)))))))/
       (c2*c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l2^3*l3^3*(4*c2*kblz*l2 + 4*c2^3*kw2*l2 + g*(m2 + m3) - 
         c2^2*g*(m2 + m3))), 0, 
      (d3*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*n4*(n4 - n5))/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, -((g*m3)/(c3*l3*m2)), 0, 0, 
      (d3*g*(I2x*I2yz - I2xy*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(-(I2x*I2z) + I2zx^2)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d3*g*(I2xy*I2z - I2yz*I2zx)*m3)/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), g/(c3*l3), 0, 0, (d4*g*(I3x*I3yz - I3xy*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(-(I3x*I3z) + I3zx^2)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), (d4*g*(I3xy*I3z - I3yz*I3zx)*m3)/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
          (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
         2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3), 
      -(((I2xy*I2z - I2yz*I2zx)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      -(((I2yz^2 - I2y*I2z)*(d3*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*n4*
           (n4 - n5)))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 0, 
      (g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2)/(c3*l3^3*m3), 0, 
      ((I3xy*I3yz - I3y*I3zx)*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 
           4*c3*kw3*l3*(n4 - n5)^2) - c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
          n5))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3xy*I3z - I3yz*I3zx)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
         c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}, {0, 0, 0, 0, 0, 0, 0, 0, 
      (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)/(c3*l3*m2), 0, 0, 0, 0, 0, 
      g/(c3*l3) - (c3*g)/l3 + (4*c3^2*kw3)/m3, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0, 0, 0, 0, 
      -(((I2xy^2 - I2x*I2y)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
          g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
        (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
          I2y*I2zx^2)*l3^3)), -(((I2x*I2yz - I2xy*I2zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 
          2*I2xy*I2yz*I2zx + I2y*I2zx^2)*l3^3)), 
      ((I2xy*I2yz - I2y*I2zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 0, 0, ((I3xy^2 - I3x*I3y)*
        (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
           l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3), 
      ((I3x*I3yz - I3xy*I3zx)*(4*c3*kw3*l3*(n4 - n5)^2*sl^2 + 
         g*m3*(-((n4 - n5)^2*sl^2) + l3^2*(n4*n5 + sl^2))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), -(((I3xy*I3yz - I3y*I3zx)*
         (4*c3*kw3*l3*(n4 - n5)^2*sl^2 + g*m3*(-((n4 - n5)^2*sl^2) + 
            l3^2*(n4*n5 + sl^2))))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
          2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3^3))}, {0, 0, 0, 0, 0, 0, 
      -((d4*g*m3)/(c3*l3*m2)), 0, 0, ((I2x*I2yz - I2xy*I2zx)*
        (d3*d4*g*m3 + (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2x*I2z - I2zx^2)*(-(d3*d4*g*m3) + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), ((I2xy*I2z - I2yz*I2zx)*(d3*d4*g*m3 + 
         (-4*c3^3*kw3*l3 - g*m3 + c3^2*g*m3)*sl^2))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3), (d4*g)/(c3*l3), 0, 0, 
      ((I3x*I3yz - I3xy*I3zx)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
         (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3), -(((I3x*I3z - I3zx^2)*(d4^2*g*m3 + c3*d4*g*l3*m3 + 
          (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*sl^2))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*g*m3 + c3*d4*g*l3*m3 + (4*c3^3*kw3*l3 + g*m3 - c3^2*g*m3)*
          sl^2))/(c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 
         2*I3xy*I3yz*I3zx + I3y*I3zx^2)*l3)}, {0, 0, 0, 0, 0, 0, 0, 
      (d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m2), 0, 
      ((I2xy*I2yz - I2y*I2zx)*(d3*(d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 
             4*c3*kw3*l3*(n4 - n5)^2) + c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*
            n5) + l3*n4*(c3*d4*g*m3*(n4 - n5) + 4*c3^3*kw3*l3^2*n5 + 
           g*l3*m3*n5 - c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2xy*I2z - I2yz*I2zx)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), ((I2yz^2 - I2y*I2z)*
        (d3*(d4*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) - 
           c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5) + 
         l3*n4*(-4*c3^3*kw3*l3^2*n5 - g*l3*m3*n5 + c3*d4*g*m3*(-n4 + n5) + 
           c3^2*l3*(4*d4*kw3*(n4 - n5) + g*m3*n5))))/
       (c3*(I2xy^2*I2z + I2x*(I2yz^2 - I2y*I2z) - 2*I2xy*I2yz*I2zx + 
         I2y*I2zx^2)*l3^3), 0, 
      (d4*(g*m3*(-l3^2 + (n4 - n5)^2) - 4*c3*kw3*l3*(n4 - n5)^2) + 
        c3*l3*(4*c3*kw3*l3 - g*m3)*(n4 - n5)*n5)/(c3*l3^3*m3), 0, 
      -(((I3xy*I3yz - I3y*I3zx)*(d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 
            4*c3*kw3*l3*(n4 - n5)^2) + l3^2*n5*(4*c3^3*kw3*l3*n5 + 
            g*m3*(n4 - c3^2*n5)) + c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
            g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
        (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
          I3y*I3zx^2)*l3^3)), ((I3xy*I3z - I3yz*I3zx)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3), ((I3yz^2 - I3y*I3z)*
        (d4^2*(g*m3*(l3^2 - (n4 - n5)^2) + 4*c3*kw3*l3*(n4 - n5)^2) + 
         l3^2*n5*(4*c3^3*kw3*l3*n5 + g*m3*(n4 - c3^2*n5)) + 
         c3*d4*l3*(8*c3*kw3*l3*n5*(-n4 + n5) + 
           g*m3*(l3^2 + 2*(n4 - n5)*n5))))/
       (c3*(I3xy^2*I3z + I3x*(I3yz^2 - I3y*I3z) - 2*I3xy*I3yz*I3zx + 
         I3y*I3zx^2)*l3^3)}}
 
cxsm = {{-((g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, -((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
        (c1*l1^3)), 0, 0, 0, -(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*
         (n0 - n1))/l1^2)}, {0, 0, -2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
       (c1*g*(m1 + m2 + m3))/l1, 0, 0, 0}, 
     {0, 0, 0, -((g*(m1 + m2 + m3)*n0*n1)/(c1*l1)), 0, 0}, 
     {-((d0*g*(m1 + m2 + m3))/(c1*l1)), 0, 0, 0, 0, 0}, 
     {0, (d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
           (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
         n1)/(c1*l1^3), 0, 0, 0, (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 
         2*c1^3*kw1*l1^2*n1 - g*l1*(m1 + m2 + m3)*n1 + 
         c1^2*l1*(2*d0*kw1*(n0 - n1) + g*(m1 + m2 + m3)*n1)))/(c1*l1^2)}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}}
 
bm = {{-((g*(m1 + m2 + m3))/(c1*l1*m1)), 0, 0, 0, 0, 0}, 
     {0, (-((g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*(n0 - n1)^2)/
          (c1*l1^3)) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*
          ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (n0 - n1))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
            (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*((c1*kw1*(-n0 + n1))/l1 - 
           (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 
      (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           ((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-(((2*c1*kw1*l1 - g*(m1 + m2 + m3))*n0*(n0 - n1))/l1^2) - 
        (((c1*kw1*(n0 - n1))/l1 - (g*(m1 + m2 + m3)*(n0 - n1))/(2*l1^2))*
          (-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
            n1))/(2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
          ((c1*kw1*(-n0 + n1))/l1 - (g*(m1 + m2 + m3)*(-n0 + n1))/(2*l1^2)))/
         (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1}, 
     {0, 0, (-2*c1^2*kw1 - (g*(m1 + m2 + m3))/(c1*l1) + 
        (c1*g*(m1 + m2 + m3))/l1 - ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - 
           c1^2*g*(m1 + m2 + m3))*(-(c1^2*kw1) - (g*(m1 + m2 + m3))/
            (2*c1*l1) + (c1*g*(m1 + m2 + m3))/(2*l1)))/
         (c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
           (c1*g*(m1 + m2 + m3))/(2*l1))))/m1, 0, 0, 
      (-((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
             (2*l1))*(-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - 
            g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
        ((-(c1^2*kw1) - (g*(m1 + m2 + m3))/(2*c1*l1) + (c1*g*(m1 + m2 + m3))/
            (2*l1))*(2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + 
           g*(m1 + m2 + m3)*n1))/(2*c1*l1*(kbuz + c1^2*kw1 + 
           (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))))/
       m1}, {-((d0*g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((-(I1xy*I1yz) + I1y*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1xy^2 - I1x*I1y)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((-(I1xy*I1yz) + I1y*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(-(I1x*I1z) + I1zx^2)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1xy*I1z - I1yz*I1zx)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1xy*I1z - I1yz*I1zx)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(I1x*I1yz - I1xy*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1xy*I1z - I1yz*I1zx)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {-((d0*g*(I1xy*I1z - I1yz*I1zx)*(m1 + m2 + m3))/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), ((I1yz^2 - I1y*I1z)*
        ((d0*(g*(m1 + m2 + m3)*(l1^2 - (n0 - n1)^2) + 2*c1*kw1*l1*
              (n0 - n1)^2) - c1*l1*(2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
            n1)/(c1*l1^3) + ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*
                l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*
                n1))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/
             (2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1*kw1*l1 - g*(m1 + m2 + m3))*(n0 - n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*l1^2*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), ((I1yz^2 - I1y*I1z)*
        (-((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
            ((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(2*l1) - (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 
                2*c1*l1*n1))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1))) - 
         ((2*c1^3*kw1*l1 + g*(m1 + m2 + m3) - c1^2*g*(m1 + m2 + m3))*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2), -((g*(-(I1xy*I1yz) + I1y*I1zx)*(m1 + m2 + m3)*n0*n1)/
        (c1*(I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
          I1y*I1zx^2)*l1)), 0, ((I1yz^2 - I1y*I1z)*
        (-((-2*c1^3*kw1*l1*n0 + c1^2*g*(m1 + m2 + m3)*n0 - g*(m1 + m2 + m3)*
              n1)*((g*(m1 + m2 + m3)*n1)/(2*c1*l1) + 
             (c1*kw1*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(2*l1) - 
             (g*(m1 + m2 + m3)*(-2*d0*(n0 - n1) + 2*c1*l1*n1))/(4*l1^2)))/
          (2*c1*l1*(kbuz + c1^2*kw1 + (g*(m1 + m2 + m3))/(2*c1*l1) - 
            (c1*g*(m1 + m2 + m3))/(2*l1))) + 
         (n0*(-(c1*d0*g*(m1 + m2 + m3)*(n0 - n1)) - 2*c1^3*kw1*l1^2*n1 - 
            g*l1*(m1 + m2 + m3)*n1 + c1^2*l1*(2*d0*kw1*(n0 - n1) + 
              g*(m1 + m2 + m3)*n1)))/(c1*l1^2) - 
         ((2*c1^3*kw1*l1*n0 - c1^2*g*(m1 + m2 + m3)*n0 + g*(m1 + m2 + m3)*n1)*
           (-(g*(m1 + m2 + m3)*n1)/(2*c1*l1) + (c1*kw1*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(2*l1) - (g*(m1 + m2 + m3)*(-2*c1*l1*n1 - 2*d0*
                (-n0 + n1)))/(4*l1^2)))/(2*c1*l1*(kbuz + c1^2*kw1 + 
            (g*(m1 + m2 + m3))/(2*c1*l1) - (c1*g*(m1 + m2 + m3))/(2*l1)))))/
       (I1x*I1yz^2 + I1xy^2*I1z - I1x*I1y*I1z - 2*I1xy*I1yz*I1zx + 
        I1y*I1zx^2)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, 
     {0, 0, 0, 0, 0, 0}}
